Class: Aws::Batch::Types::ArrayPropertiesSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

An object that represents the array properties of a job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#indexInteger

The job index within the array that’s associated with this job. This parameter is returned for children of array jobs.



84
85
86
87
88
89
90
91
# File 'lib/aws-sdk-batch/types.rb', line 84

class ArrayPropertiesSummary < Struct.new(
  :size,
  :index,
  :status_summary,
  :status_summary_last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#sizeInteger

The size of the array job. This parameter is returned for parent array jobs.



84
85
86
87
88
89
90
91
# File 'lib/aws-sdk-batch/types.rb', line 84

class ArrayPropertiesSummary < Struct.new(
  :size,
  :index,
  :status_summary,
  :status_summary_last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#status_summaryHash<String,Integer>

A summary of the number of array job children in each available job status. This parameter is returned for parent array jobs.



84
85
86
87
88
89
90
91
# File 'lib/aws-sdk-batch/types.rb', line 84

class ArrayPropertiesSummary < Struct.new(
  :size,
  :index,
  :status_summary,
  :status_summary_last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#status_summary_last_updated_atInteger

The Unix timestamp (in milliseconds) for when the statusSummary was last updated.



84
85
86
87
88
89
90
91
# File 'lib/aws-sdk-batch/types.rb', line 84

class ArrayPropertiesSummary < Struct.new(
  :size,
  :index,
  :status_summary,
  :status_summary_last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end