Class: Aws::Batch::Types::CancelJobsErrorDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

An object that contains the details of a job that couldn't be cancelled by a CancelJobs operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

An error code that identifies the reason the job couldn't be cancelled. Valid values are:

  • ValidationException – A job identifier in the request is malformed or isn't valid.

  • ClientException – The request failed because of a client error.

  • ThrottlingException – The request was throttled. Retry the request.

  • ServerException – An internal error occurred. Retry the request.

  • AccessDenied – The caller isn't authorized to perform the action on the specified job.

Returns:



305
306
307
308
309
310
311
# File 'lib/aws-sdk-batch/types.rb', line 305

class CancelJobsErrorDetail < Struct.new(
  :job,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#jobString

The Batch job ID of the job that couldn't be cancelled.

Returns:



305
306
307
308
309
310
311
# File 'lib/aws-sdk-batch/types.rb', line 305

class CancelJobsErrorDetail < Struct.new(
  :job,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message that describes the reason the job couldn't be cancelled.

Returns:



305
306
307
308
309
310
311
# File 'lib/aws-sdk-batch/types.rb', line 305

class CancelJobsErrorDetail < Struct.new(
  :job,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end