Class: Aws::Batch::Types::CapacityLimit
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::CapacityLimit
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Defines the type and maximum quantity of resources that can be allocated to service jobs in a service environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_unit ⇒ String
The unit of measure for the capacity limit, which defines how ‘maxCapacity` is interpreted.
-
#max_capacity ⇒ Integer
The maximum capacity available for the service environment.
Instance Attribute Details
#capacity_unit ⇒ String
The unit of measure for the capacity limit, which defines how ‘maxCapacity` is interpreted. For `SAGEMAKER_TRAINING` jobs in a quota management enabled service environment, specify the [instance type] (for example, `ml.m5.large`). Otherwise, use `NUM_INSTANCES`.
309 310 311 312 313 314 |
# File 'lib/aws-sdk-batch/types.rb', line 309 class CapacityLimit < Struct.new( :max_capacity, :capacity_unit) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Integer
The maximum capacity available for the service environment. For a quota management enabled service environment, this value represents the maximum quantity of a particular resource type (specified by ‘capacityUnit`) that can be allocated to service jobs. For other service environments, this value represents the maximum quantity of all resources that can be allocated to service jobs.
For example, if ‘maxCapacity=50` and `capacityUnit=NUM_INSTANCES`, you can run up to 50 instances concurrently. If you run 5 SageMaker Training jobs that each use 10 instances, a subsequent job requiring 10 instances waits in the queue until capacity is available. In a quota management enabled service environment with `capacityUnit=ml.m5.large`, only `ml.m5.large` instances count against this limit, and jobs requiring other instance types wait until a matching capacity limit is configured.
309 310 311 312 313 314 |
# File 'lib/aws-sdk-batch/types.rb', line 309 class CapacityLimit < Struct.new( :max_capacity, :capacity_unit) SENSITIVE = [] include Aws::Structure end |