Class: Aws::Batch::Types::ContainerDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ContainerDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that represents the details of a container that’s part of a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command ⇒ Array<String>
The command that’s passed to the container.
-
#container_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the container instance that the container is running on.
-
#enable_execute_command ⇒ Boolean
Determines whether execute command functionality is turned on for this task.
-
#environment ⇒ Array<Types::KeyValuePair>
The environment variables to pass to a container.
-
#ephemeral_storage ⇒ Types::EphemeralStorage
The amount of ephemeral storage allocated for the task.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the execution role that Batch can assume.
-
#exit_code ⇒ Integer
The exit code returned upon completion.
-
#fargate_platform_configuration ⇒ Types::FargatePlatformConfiguration
The platform configuration for jobs that are running on Fargate resources.
-
#image ⇒ String
The image used to start the container.
-
#instance_type ⇒ String
The instance type of the underlying host infrastructure of a multi-node parallel job.
-
#job_role_arn ⇒ String
The Amazon Resource Name (ARN) that’s associated with the job when run.
-
#linux_parameters ⇒ Types::LinuxParameters
Linux-specific modifications that are applied to the container, such as details for device mappings.
-
#log_configuration ⇒ Types::LogConfiguration
The log configuration specification for the container.
-
#log_stream_name ⇒ String
The name of the Amazon CloudWatch Logs log stream that’s associated with the container.
-
#memory ⇒ Integer
For jobs running on Amazon EC2 resources that didn’t specify memory requirements using
resourceRequirements, the number of MiB of memory reserved for the job. -
#mount_points ⇒ Array<Types::MountPoint>
The mount points for data volumes in your container.
-
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for jobs that are running on Fargate resources.
-
#network_interfaces ⇒ Array<Types::NetworkInterface>
The network interfaces that are associated with the job.
-
#privileged ⇒ Boolean
When this parameter is true, the container is given elevated permissions on the host container instance (similar to the
rootuser). -
#readonly_root_filesystem ⇒ Boolean
When this parameter is true, the container is given read-only access to its root file system.
-
#reason ⇒ String
A short (255 max characters) human-readable string to provide additional details for a running or stopped container.
-
#repository_credentials ⇒ Types::RepositoryCredentials
The private repository authentication credentials to use.
-
#resource_requirements ⇒ Array<Types::ResourceRequirement>
The type and amount of resources to assign to a container.
-
#runtime_platform ⇒ Types::RuntimePlatform
An object that represents the compute environment architecture for Batch jobs on Fargate.
-
#secrets ⇒ Array<Types::Secret>
The secrets to pass to the container.
-
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon ECS task that’s associated with the container job.
-
#ulimits ⇒ Array<Types::Ulimit>
A list of
ulimitvalues to set in the container. -
#user ⇒ String
The user name to use inside the container.
-
#vcpus ⇒ Integer
The number of vCPUs reserved for the container.
-
#volumes ⇒ Array<Types::Volume>
A list of volumes that are associated with the job.
Instance Attribute Details
#command ⇒ Array<String>
The command that’s passed to the container.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#container_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the container instance that the container is running on.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#enable_execute_command ⇒ Boolean
Determines whether execute command functionality is turned on for this task. If true, execute command functionality is turned on all the containers in the task.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Array<Types::KeyValuePair>
The environment variables to pass to a container.
<note markdown=“1”> Environment variables cannot start with “AWS_BATCH”. This naming convention is reserved for variables that Batch sets.
</note>
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#ephemeral_storage ⇒ Types::EphemeralStorage
The amount of ephemeral storage allocated for the task. This parameter is used to expand the total amount of ephemeral storage available, beyond the default amount, for tasks hosted on Fargate.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the execution role that Batch can assume. For more information, see [Batch execution IAM role] in the *Batch User Guide*.
[1]: docs.aws.amazon.com/batch/latest/userguide/execution-IAM-role.html
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#exit_code ⇒ Integer
The exit code returned upon completion.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#fargate_platform_configuration ⇒ Types::FargatePlatformConfiguration
The platform configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources must not specify this parameter.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#image ⇒ String
The image used to start the container.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type of the underlying host infrastructure of a multi-node parallel job.
<note markdown=“1”> This parameter isn’t applicable to jobs that are running on Fargate resources.
</note>
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#job_role_arn ⇒ String
The Amazon Resource Name (ARN) that’s associated with the job when run.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#linux_parameters ⇒ Types::LinuxParameters
Linux-specific modifications that are applied to the container, such as details for device mappings.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#log_configuration ⇒ Types::LogConfiguration
The log configuration specification for the container.
This parameter maps to LogConfig in the [Create a container] section of the [Docker Remote API] and the --log-driver option to [docker run]. By default, containers use the same logging driver that the Docker daemon uses. However, the container might use a different logging driver than the Docker daemon by specifying a log driver with this parameter in the container definition. To use a different logging driver for a container, the log system must be configured properly on the container instance. Or, alternatively, it must be configured on a different log server for remote logging options. For more information on the options for different supported log drivers, see [Configure logging drivers] in the Docker documentation.
<note markdown=“1”> Batch currently supports a subset of the logging drivers available to the Docker daemon (shown in the [LogConfiguration] data type). Additional log drivers might be available in future releases of the Amazon ECS container agent.
</note>
This parameter requires version 1.18 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: ‘sudo docker version | grep “Server API version”`
<note markdown=“1”> The Amazon ECS container agent running on a container instance must register the logging drivers available on that instance with the ECS_AVAILABLE_LOGGING_DRIVERS environment variable before containers placed on that instance can use these log configuration options. For more information, see [Amazon ECS container agent configuration] in the *Amazon Elastic Container Service Developer Guide*.
</note>
[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/ [4]: docs.docker.com/engine/admin/logging/overview/ [5]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-batch-jobdefinition-containerproperties-logconfiguration.html [6]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#log_stream_name ⇒ String
The name of the Amazon CloudWatch Logs log stream that’s associated with the container. The log group for Batch jobs is /aws/batch/job. Each container attempt receives a log stream name when they reach the RUNNING status.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ Integer
For jobs running on Amazon EC2 resources that didn’t specify memory requirements using resourceRequirements, the number of MiB of memory reserved for the job. For other jobs, including all run on Fargate resources, see resourceRequirements.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#mount_points ⇒ Array<Types::MountPoint>
The mount points for data volumes in your container.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources must not specify this parameter.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#network_interfaces ⇒ Array<Types::NetworkInterface>
The network interfaces that are associated with the job.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#privileged ⇒ Boolean
When this parameter is true, the container is given elevated permissions on the host container instance (similar to the root user). The default value is false.
<note markdown=“1”> This parameter isn’t applicable to jobs that are running on Fargate resources and shouldn’t be provided, or specified as false.
</note>
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#readonly_root_filesystem ⇒ Boolean
When this parameter is true, the container is given read-only access to its root file system. This parameter maps to ReadonlyRootfs in the [Create a container] section of the [Docker Remote API] and the --read-only option to [ ‘docker run` ][3].
[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/commandline/run/
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A short (255 max characters) human-readable string to provide additional details for a running or stopped container.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#repository_credentials ⇒ Types::RepositoryCredentials
The private repository authentication credentials to use.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#resource_requirements ⇒ Array<Types::ResourceRequirement>
The type and amount of resources to assign to a container. The supported resources include GPU, MEMORY, and VCPU.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#runtime_platform ⇒ Types::RuntimePlatform
An object that represents the compute environment architecture for Batch jobs on Fargate.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#secrets ⇒ Array<Types::Secret>
The secrets to pass to the container. For more information, see
- Specifying sensitive data][1
-
in the *Batch User Guide*.
[1]: docs.aws.amazon.com/batch/latest/userguide/specifying-sensitive-data.html
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon ECS task that’s associated with the container job. Each container attempt receives a task ARN when they reach the STARTING status.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#ulimits ⇒ Array<Types::Ulimit>
A list of ulimit values to set in the container. This parameter maps to Ulimits in the [Create a container] section of the
- Docker Remote API][2
-
and the
--ulimitoption to [docker run].
<note markdown=“1”> This parameter isn’t applicable to jobs that are running on Fargate resources.
</note>
[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#user ⇒ String
The user name to use inside the container. This parameter maps to User in the [Create a container] section of the [Docker Remote API] and the --user option to [docker run].
[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#vcpus ⇒ Integer
The number of vCPUs reserved for the container. For jobs that run on Amazon EC2 resources, you can specify the vCPU requirement for the job using resourceRequirements, but you can’t specify the vCPU requirements in both the vcpus and resourceRequirements object. This parameter maps to CpuShares in the [Create a container] section of the [Docker Remote API] and the --cpu-shares option to [docker run]. Each vCPU is equivalent to 1,024 CPU shares. You must specify at least one vCPU. This is required but can be specified in several places. It must be specified for each node at least once.
<note markdown=“1”> This parameter isn’t applicable to jobs that run on Fargate resources. For jobs that run on Fargate resources, you must specify the vCPU requirement for the job using resourceRequirements.
</note>
[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#volumes ⇒ Array<Types::Volume>
A list of volumes that are associated with the job.
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-batch/types.rb', line 1859 class ContainerDetail < Struct.new( :image, :vcpus, :memory, :command, :job_role_arn, :execution_role_arn, :volumes, :environment, :mount_points, :readonly_root_filesystem, :ulimits, :privileged, :user, :exit_code, :reason, :container_instance_arn, :task_arn, :log_stream_name, :instance_type, :network_interfaces, :resource_requirements, :linux_parameters, :log_configuration, :secrets, :network_configuration, :fargate_platform_configuration, :ephemeral_storage, :runtime_platform, :repository_credentials, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |