Class: Aws::Batch::Types::ContainerProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Container properties are used for Amazon ECS based job definitions. These properties to describe the container that’s launched as part of a job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commandArray<String>

The command that’s passed to the container. This parameter maps to Cmd in the [Create a container] section of the [Docker Remote API] and the COMMAND parameter to [docker run]. For more information, see [docs.docker.com/engine/reference/builder/#cmd][4].

[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/ [4]: docs.docker.com/engine/reference/builder/#cmd

Returns:

  • (Array<String>)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#enable_execute_commandBoolean

Determines whether execute command functionality is turned on for this task. If true, execute command functionality is turned on all the containers in the task.

Returns:

  • (Boolean)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#environmentArray<Types::KeyValuePair>

The environment variables to pass to a container. This parameter maps to Env in the [Create a container] section of the [Docker Remote API] and the --env option to [docker run].

We don’t recommend using plaintext environment variables for sensitive information, such as credential data.

<note markdown=“1”> Environment variables cannot start with “AWS_BATCH”. This naming convention is reserved for variables that Batch sets.

</note>

[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/

Returns:



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#ephemeral_storageTypes::EphemeralStorage

The amount of ephemeral storage to allocate for the task. This parameter is used to expand the total amount of ephemeral storage available, beyond the default amount, for tasks hosted on Fargate.



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the execution role that Batch can assume. For jobs that run on Fargate resources, you must provide an execution role. For more information, see [Batch execution IAM role] in the *Batch User Guide*.

[1]: docs.aws.amazon.com/batch/latest/userguide/execution-IAM-role.html

Returns:

  • (String)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#fargate_platform_configurationTypes::FargatePlatformConfiguration

The platform configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources must not specify this parameter.



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#imageString

Required. The image used to start a container. This string is passed directly to the Docker daemon. Images in the Docker Hub registry are available by default. Other repositories are specified with ‘ repository-url/image:tag `. It can be 255 characters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), underscores (_), colons (:), periods (.), forward slashes (/), and number signs (#). This parameter maps to Image in the [Create a container] section of the [Docker Remote API] and the IMAGE parameter of [docker run].

<note markdown=“1”> Docker image architecture must match the processor architecture of the compute resources that they’re scheduled on. For example, ARM-based Docker images can only run on ARM-based compute resources.

</note>
  • Images in Amazon ECR Public repositories use the full registry/repository[:tag] or ‘registry/repository` naming conventions. For example, `public.ecr.aws/registry_alias/my-web-app:latest `.

  • Images in Amazon ECR repositories use the full registry and repository URI (for example, ‘123456789012.dkr.ecr.<region-name>.amazonaws.com/<repository-name>`).

  • Images in official repositories on Docker Hub use a single name (for example, ubuntu or mongo).

  • Images in other repositories on Docker Hub are qualified with an organization name (for example, amazon/amazon-ecs-agent).

  • Images in other online repositories are qualified further by a domain name (for example, quay.io/assemblyline/ubuntu).

[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/

Returns:

  • (String)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type to use for a multi-node parallel job. All node groups in a multi-node parallel job must use the same instance type.

<note markdown=“1”> This parameter isn’t applicable to single-node container jobs or jobs that run on Fargate resources, and shouldn’t be provided.

</note>

Returns:

  • (String)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#job_role_arnString

The Amazon Resource Name (ARN) of the IAM role that the container can assume for Amazon Web Services permissions. For more information, see [IAM roles for tasks] in the *Amazon Elastic Container Service Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html

Returns:

  • (String)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#linux_parametersTypes::LinuxParameters

Linux-specific modifications that are applied to the container, such as details for device mappings.



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#log_configurationTypes::LogConfiguration

The log configuration specification for the container.

This parameter maps to LogConfig in the [Create a container] section of the [Docker Remote API] and the --log-driver option to [docker run]. By default, containers use the same logging driver that the Docker daemon uses. However the container might use a different logging driver than the Docker daemon by specifying a log driver with this parameter in the container definition. To use a different logging driver for a container, the log system must be configured properly on the container instance (or on a different log server for remote logging options). For more information on the options for different supported log drivers, see [Configure logging drivers] in the Docker documentation.

<note markdown=“1”> Batch currently supports a subset of the logging drivers available to the Docker daemon (shown in the [LogConfiguration] data type).

</note>

This parameter requires version 1.18 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: ‘sudo docker version | grep “Server API version”`

<note markdown=“1”> The Amazon ECS container agent running on a container instance must register the logging drivers available on that instance with the ECS_AVAILABLE_LOGGING_DRIVERS environment variable before containers placed on that instance can use these log configuration options. For more information, see [Amazon ECS container agent configuration] in the *Amazon Elastic Container Service Developer Guide*.

</note>

[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/ [4]: docs.docker.com/engine/admin/logging/overview/ [5]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-batch-jobdefinition-containerproperties-logconfiguration.html [6]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#memoryInteger

This parameter is deprecated, use resourceRequirements to specify the memory requirements for the job definition. It’s not supported for jobs running on Fargate resources. For jobs that run on Amazon EC2 resources, it specifies the memory hard limit (in MiB) for a container. If your container attempts to exceed the specified number, it’s terminated. You must specify at least 4 MiB of memory for a job using this parameter. The memory hard limit can be specified in several places. It must be specified for each node at least once.

Returns:

  • (Integer)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#mount_pointsArray<Types::MountPoint>

The mount points for data volumes in your container. This parameter maps to Volumes in the [Create a container] section of the

Docker Remote API][2

and the --volume option to [docker run].

[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/

Returns:



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::NetworkConfiguration

The network configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources must not specify this parameter.



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#privilegedBoolean

When this parameter is true, the container is given elevated permissions on the host container instance (similar to the root user). This parameter maps to Privileged in the [Create a container] section of the [Docker Remote API] and the --privileged option to [docker run]. The default value is false.

<note markdown=“1”> This parameter isn’t applicable to jobs that are running on Fargate resources and shouldn’t be provided, or specified as false.

</note>

[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/

Returns:

  • (Boolean)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#readonly_root_filesystemBoolean

When this parameter is true, the container is given read-only access to its root file system. This parameter maps to ReadonlyRootfs in the [Create a container] section of the [Docker Remote API] and the --read-only option to ‘docker run`.

[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/

Returns:

  • (Boolean)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#repository_credentialsTypes::RepositoryCredentials

The private repository authentication credentials to use.



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#resource_requirementsArray<Types::ResourceRequirement>

The type and amount of resources to assign to a container. The supported resources include GPU, MEMORY, and VCPU.

Returns:



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_platformTypes::RuntimePlatform

An object that represents the compute environment architecture for Batch jobs on Fargate.



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#secretsArray<Types::Secret>

The secrets for the container. For more information, see [Specifying sensitive data] in the *Batch User Guide*.

[1]: docs.aws.amazon.com/batch/latest/userguide/specifying-sensitive-data.html

Returns:



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#ulimitsArray<Types::Ulimit>

A list of ulimits to set in the container. This parameter maps to Ulimits in the [Create a container] section of the [Docker Remote API] and the --ulimit option to [docker run].

<note markdown=“1”> This parameter isn’t applicable to jobs that are running on Fargate resources and shouldn’t be provided.

</note>

[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/

Returns:



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#userString

The user name to use inside the container. This parameter maps to User in the [Create a container] section of the [Docker Remote API] and the --user option to [docker run].

[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/

Returns:

  • (String)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#vcpusInteger

This parameter is deprecated, use resourceRequirements to specify the vCPU requirements for the job definition. It’s not supported for jobs running on Fargate resources. For jobs running on Amazon EC2 resources, it specifies the number of vCPUs reserved for the job.

Each vCPU is equivalent to 1,024 CPU shares. This parameter maps to CpuShares in the [Create a container] section of the [Docker Remote API] and the --cpu-shares option to [docker run]. The number of vCPUs must be specified but can be specified in several places. You must specify it at least once for each node.

[1]: docs.docker.com/engine/api/v1.23/#create-a-container [2]: docs.docker.com/engine/api/v1.23/ [3]: docs.docker.com/engine/reference/run/

Returns:

  • (Integer)


2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#volumesArray<Types::Volume>

A list of data volumes used in a job.

Returns:



2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'lib/aws-sdk-batch/types.rb', line 2312

class ContainerProperties < Struct.new(
  :image,
  :vcpus,
  :memory,
  :command,
  :job_role_arn,
  :execution_role_arn,
  :volumes,
  :environment,
  :mount_points,
  :readonly_root_filesystem,
  :privileged,
  :ulimits,
  :user,
  :instance_type,
  :resource_requirements,
  :linux_parameters,
  :log_configuration,
  :secrets,
  :network_configuration,
  :fargate_platform_configuration,
  :enable_execute_command,
  :ephemeral_storage,
  :runtime_platform,
  :repository_credentials)
  SENSITIVE = []
  include Aws::Structure
end