Class: Aws::Batch::Types::CreateSchedulingPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Contains the parameters for CreateSchedulingPolicy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fairshare_policyTypes::FairsharePolicy

The fair-share scheduling policy details. Only one of fairsharePolicy or quotaSharePolicy can be set. Once set, this policy type cannot be removed or changed to a quotaSharePolicy.



2956
2957
2958
2959
2960
2961
2962
2963
# File 'lib/aws-sdk-batch/types.rb', line 2956

class CreateSchedulingPolicyRequest < Struct.new(
  :name,
  :quota_share_policy,
  :fairshare_policy,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the fair-share scheduling policy. It can be up to 128 letters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), and underscores (_).

Returns:

  • (String)


2956
2957
2958
2959
2960
2961
2962
2963
# File 'lib/aws-sdk-batch/types.rb', line 2956

class CreateSchedulingPolicyRequest < Struct.new(
  :name,
  :quota_share_policy,
  :fairshare_policy,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#quota_share_policyTypes::QuotaSharePolicy

The quota share scheduling policy details. Only one of fairsharePolicy or quotaSharePolicy can be set. Once set, this policy type cannot be removed or changed to a fairSharePolicy.



2956
2957
2958
2959
2960
2961
2962
2963
# File 'lib/aws-sdk-batch/types.rb', line 2956

class CreateSchedulingPolicyRequest < Struct.new(
  :name,
  :quota_share_policy,
  :fairshare_policy,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags that you apply to the scheduling policy to help you categorize and organize your resources. Each tag consists of a key and an optional value. For more information, see Tagging Amazon Web Services Resources in Amazon Web Services General Reference.

These tags can be updated or removed using the TagResource and UntagResource API operations.

Returns:

  • (Hash<String,String>)


2956
2957
2958
2959
2960
2961
2962
2963
# File 'lib/aws-sdk-batch/types.rb', line 2956

class CreateSchedulingPolicyRequest < Struct.new(
  :name,
  :quota_share_policy,
  :fairshare_policy,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end