Class: Aws::Batch::Types::DescribeJobDefinitionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_definitionsArray<Types::JobDefinition>

The list of job definitions.



3551
3552
3553
3554
3555
3556
# File 'lib/aws-sdk-batch/types.rb', line 3551

class DescribeJobDefinitionsResponse < Struct.new(
  :job_definitions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value to include in a future DescribeJobDefinitions request. When the results of a DescribeJobDefinitions request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.



3551
3552
3553
3554
3555
3556
# File 'lib/aws-sdk-batch/types.rb', line 3551

class DescribeJobDefinitionsResponse < Struct.new(
  :job_definitions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end