Class: Aws::Batch::Types::DescribeJobQueuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::DescribeJobQueuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Contains the parameters for DescribeJobQueues.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_queues ⇒ Array<String>
A list of up to 100 queue names or full queue Amazon Resource Name (ARN) entries.
-
#max_results ⇒ Integer
The maximum number of results returned by
DescribeJobQueuesin paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedDescribeJobQueuesrequest wheremaxResultswas used and the results exceeded the value of that parameter.
Instance Attribute Details
#job_queues ⇒ Array<String>
A list of up to 100 queue names or full queue Amazon Resource Name (ARN) entries.
3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-batch/types.rb', line 3204 class DescribeJobQueuesRequest < Struct.new( :job_queues, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results returned by DescribeJobQueues in paginated output. When this parameter is used, DescribeJobQueues only returns maxResults results in a single page and a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeJobQueues request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn’t used, then DescribeJobQueues returns up to 100 results and a nextToken value if applicable.
3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-batch/types.rb', line 3204 class DescribeJobQueuesRequest < Struct.new( :job_queues, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated DescribeJobQueues request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.
<note markdown=“1”> Treat this token as an opaque identifier that’s only used to retrieve the next items in a list and not for other programmatic purposes.
</note>
3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-batch/types.rb', line 3204 class DescribeJobQueuesRequest < Struct.new( :job_queues, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |