Class: Aws::Batch::Types::DescribeQuotaShareResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::DescribeQuotaShareResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_limits ⇒ Array<Types::QuotaShareCapacityLimit>
A list that specifies the quantity and type of compute capacity allocated to the quota share.
-
#job_queue_arn ⇒ String
The ARN of the job queue associated with the quota share.
-
#preemption_configuration ⇒ Types::QuotaSharePreemptionConfiguration
Specifies the preemption behavior for jobs in a quota share.
-
#quota_share_arn ⇒ String
The Amazon Resource Name (ARN) of the quota share.
-
#quota_share_name ⇒ String
The name of the quota share.
-
#resource_sharing_configuration ⇒ Types::QuotaShareResourceSharingConfiguration
Specifies whether a quota share reserves, lends, or both lends and borrows idle compute capacity.
-
#state ⇒ String
The state of the quota share.
-
#status ⇒ String
The current status of the quota share.
-
#tags ⇒ Hash<String,String>
The tags applied to the quota share.
Instance Attribute Details
#capacity_limits ⇒ Array<Types::QuotaShareCapacityLimit>
A list that specifies the quantity and type of compute capacity allocated to the quota share.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 |
# File 'lib/aws-sdk-batch/types.rb', line 3529 class DescribeQuotaShareResponse < Struct.new( :quota_share_name, :quota_share_arn, :job_queue_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#job_queue_arn ⇒ String
The ARN of the job queue associated with the quota share.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 |
# File 'lib/aws-sdk-batch/types.rb', line 3529 class DescribeQuotaShareResponse < Struct.new( :quota_share_name, :quota_share_arn, :job_queue_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#preemption_configuration ⇒ Types::QuotaSharePreemptionConfiguration
Specifies the preemption behavior for jobs in a quota share.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 |
# File 'lib/aws-sdk-batch/types.rb', line 3529 class DescribeQuotaShareResponse < Struct.new( :quota_share_name, :quota_share_arn, :job_queue_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#quota_share_arn ⇒ String
The Amazon Resource Name (ARN) of the quota share.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 |
# File 'lib/aws-sdk-batch/types.rb', line 3529 class DescribeQuotaShareResponse < Struct.new( :quota_share_name, :quota_share_arn, :job_queue_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#quota_share_name ⇒ String
The name of the quota share.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 |
# File 'lib/aws-sdk-batch/types.rb', line 3529 class DescribeQuotaShareResponse < Struct.new( :quota_share_name, :quota_share_arn, :job_queue_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_sharing_configuration ⇒ Types::QuotaShareResourceSharingConfiguration
Specifies whether a quota share reserves, lends, or both lends and borrows idle compute capacity.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 |
# File 'lib/aws-sdk-batch/types.rb', line 3529 class DescribeQuotaShareResponse < Struct.new( :quota_share_name, :quota_share_arn, :job_queue_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the quota share.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 |
# File 'lib/aws-sdk-batch/types.rb', line 3529 class DescribeQuotaShareResponse < Struct.new( :quota_share_name, :quota_share_arn, :job_queue_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the quota share.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 |
# File 'lib/aws-sdk-batch/types.rb', line 3529 class DescribeQuotaShareResponse < Struct.new( :quota_share_name, :quota_share_arn, :job_queue_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags applied to the quota share.
3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 |
# File 'lib/aws-sdk-batch/types.rb', line 3529 class DescribeQuotaShareResponse < Struct.new( :quota_share_name, :quota_share_arn, :job_queue_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state, :status, :tags) SENSITIVE = [] include Aws::Structure end |