Class: Aws::Batch::Types::DescribeServiceEnvironmentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::DescribeServiceEnvironmentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results returned by
DescribeServiceEnvironmentsin paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedDescribeServiceEnvironmentsrequest wheremaxResultswas used and the results exceeded the value of that parameter. -
#service_environments ⇒ Array<String>
An array of service environment names or ARN entries.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results returned by DescribeServiceEnvironments in paginated output. When this parameter is used, DescribeServiceEnvironments only returns maxResults results in a single page and a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeServiceEnvironments request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn’t used, then DescribeServiceEnvironments returns up to 100 results and a nextToken value if applicable.
3319 3320 3321 3322 3323 3324 3325 |
# File 'lib/aws-sdk-batch/types.rb', line 3319 class DescribeServiceEnvironmentsRequest < Struct.new( :service_environments, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated DescribeServiceEnvironments request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.
<note markdown=“1”> Treat this token as an opaque identifier that’s only used to retrieve the next items in a list and not for other programmatic purposes.
</note>
3319 3320 3321 3322 3323 3324 3325 |
# File 'lib/aws-sdk-batch/types.rb', line 3319 class DescribeServiceEnvironmentsRequest < Struct.new( :service_environments, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_environments ⇒ Array<String>
An array of service environment names or ARN entries.
3319 3320 3321 3322 3323 3324 3325 |
# File 'lib/aws-sdk-batch/types.rb', line 3319 class DescribeServiceEnvironmentsRequest < Struct.new( :service_environments, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |