Class: Aws::Batch::Types::Device
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::Device
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that represents a container instance host device.
<note markdown=“1”> This object isn’t applicable to jobs that are running on Fargate resources and shouldn’t be provided.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_path ⇒ String
The path inside the container that’s used to expose the host device.
-
#host_path ⇒ String
The path for the device on the host container instance.
-
#permissions ⇒ Array<String>
The explicit permissions to provide to the container for the device.
Instance Attribute Details
#container_path ⇒ String
The path inside the container that’s used to expose the host device. By default, the hostPath value is used.
3514 3515 3516 3517 3518 3519 3520 |
# File 'lib/aws-sdk-batch/types.rb', line 3514 class Device < Struct.new( :host_path, :container_path, :permissions) SENSITIVE = [] include Aws::Structure end |
#host_path ⇒ String
The path for the device on the host container instance.
3514 3515 3516 3517 3518 3519 3520 |
# File 'lib/aws-sdk-batch/types.rb', line 3514 class Device < Struct.new( :host_path, :container_path, :permissions) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<String>
The explicit permissions to provide to the container for the device. By default, the container has permissions for read, write, and mknod for the device.
3514 3515 3516 3517 3518 3519 3520 |
# File 'lib/aws-sdk-batch/types.rb', line 3514 class Device < Struct.new( :host_path, :container_path, :permissions) SENSITIVE = [] include Aws::Structure end |