Class: Aws::Batch::Types::EFSAuthorizationConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The authorization configuration details for the Amazon EFS file system.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_point_idString

The Amazon EFS access point ID to use. If an access point is specified, the root directory value specified in the EFSVolumeConfiguration must either be omitted or set to / which enforces the path set on the EFS access point. If an access point is used, transit encryption must be enabled in the EFSVolumeConfiguration. For more information, see [Working with Amazon EFS access points] in the *Amazon Elastic File System User Guide*.

[1]: docs.aws.amazon.com/efs/latest/ug/efs-access-points.html

Returns:



3506
3507
3508
3509
3510
3511
# File 'lib/aws-sdk-batch/types.rb', line 3506

class EFSAuthorizationConfig < Struct.new(
  :access_point_id,
  :iam)
  SENSITIVE = []
  include Aws::Structure
end

#iamString

Whether or not to use the Batch job IAM role defined in a job definition when mounting the Amazon EFS file system. If enabled, transit encryption must be enabled in the EFSVolumeConfiguration. If this parameter is omitted, the default value of DISABLED is used. For more information, see [Using Amazon EFS access points] in the *Batch User Guide*. EFS IAM authorization requires that TransitEncryption be ENABLED and that a JobRoleArn is specified.

[1]: docs.aws.amazon.com/batch/latest/userguide/efs-volumes.html#efs-volume-accesspoints

Returns:



3506
3507
3508
3509
3510
3511
# File 'lib/aws-sdk-batch/types.rb', line 3506

class EFSAuthorizationConfig < Struct.new(
  :access_point_id,
  :iam)
  SENSITIVE = []
  include Aws::Structure
end