Class: Aws::Batch::Types::EcsTaskDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The details of a task definition that describes the container and volume definitions of an Amazon ECS task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_instance_arnString

The Amazon Resource Name (ARN) of the container instance that hosts the task.



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#containersArray<Types::TaskContainerDetails>

A list of containers that are included in the taskProperties list.



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#enable_execute_commandBoolean

Determines whether execute command functionality is turned on for this task. If true, execute command functionality is turned on all the containers in the task.



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#ephemeral_storageTypes::EphemeralStorage

The amount of ephemeral storage allocated for the task.



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the execution role that Batch can assume. For more information, see [Batch execution IAM role][1] in the *Batch User Guide*.

[1]: docs.aws.amazon.com/batch/latest/userguide/execution-IAM-role.html



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#ipc_modeString

The IPC resource namespace to use for the containers in the task. The valid values are host, task, or none. For more information see ipcMode in [EcsTaskProperties][1].

[1]: docs.aws.amazon.com/batch/latest/APIReference/API_EcsTaskProperties.html



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::NetworkConfiguration

The network configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources must not specify this parameter.



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#pid_modeString

The process namespace to use for the containers in the task. The valid values are host, or task. For more information see pidMode in [EcsTaskProperties][1].

[1]: docs.aws.amazon.com/batch/latest/APIReference/API_EcsTaskProperties.html



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#platform_versionString

The Fargate platform version where the jobs are running.



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_platformTypes::RuntimePlatform

An object that represents the compute environment architecture for Batch jobs on Fargate.



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#task_arnString

The ARN of the Amazon ECS task.



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#task_role_arnString

The Amazon Resource Name (ARN) of the IAM role that the container can assume for Amazon Web Services permissions. For more information, see [IAM roles for tasks][1] in the *Amazon Elastic Container Service Developer Guide*.

<note markdown=“1”> This is object is comparable to [ContainerProperties:jobRoleArn][2].

</note>

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html [2]: docs.aws.amazon.com/batch/latest/APIReference/API_ContainerProperties.html



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#volumesArray<Types::Volume>

A list of data volumes used in a job.



4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-batch/types.rb', line 4176

class EcsTaskDetails < Struct.new(
  :containers,
  :container_instance_arn,
  :task_arn,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end