Class: Aws::Batch::Types::EcsTaskProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The properties for a task definition that describes the container and volume definitions of an Amazon ECS task. You can specify which Docker images to use, the required resources, and other configurations related to launching the task definition through an Amazon ECS service or task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#containersArray<Types::TaskContainerProperties>

This object is a list of containers.

Returns:



4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#enable_execute_commandBoolean

Determines whether execute command functionality is turned on for this task. If true, execute command functionality is turned on all the containers in the task.

Returns:

  • (Boolean)


4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#ephemeral_storageTypes::EphemeralStorage

The amount of ephemeral storage to allocate for the task. This parameter is used to expand the total amount of ephemeral storage available, beyond the default amount, for tasks hosted on Fargate.



4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the execution role that Batch can assume. For jobs that run on Fargate resources, you must provide an execution role. For more information, see Batch execution IAM role in the Batch User Guide.

Returns:

  • (String)


4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#ipc_modeString

The IPC resource namespace to use for the containers in the task. The valid values are host, task, or none.

If host is specified, all containers within the tasks that specified the host IPC mode on the same container instance share the same IPC resources with the host Amazon EC2 instance.

If task is specified, all containers within the specified task share the same IPC resources.

If none is specified, the IPC resources within the containers of a task are private, and are not shared with other containers in a task or on the container instance.

If no value is specified, then the IPC resource namespace sharing depends on the Docker daemon setting on the container instance. For more information, see IPC settings in the Docker run reference.

This parameter is not supported for jobs that run on Fargate resources.

Returns:

  • (String)


4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::NetworkConfiguration

The network configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources or Amazon ECS Managed Instances must not specify this parameter.



4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#network_modeString

The network mode to use for the task. Valid values: host. When not specified, the default is host.

With host mode, the container shares the host instance's network stack directly. When running tasks that use the host network mode, do not run containers using the root user (UID 0). Running as root grants unrestricted access to host resources and increases the attack surface.

This parameter only applies to jobs running on Amazon ECS Managed Instances (MANAGED_INSTANCES platform capability). It cannot be specified for Fargate or Amazon EC2 platform job definitions.

Returns:

  • (String)


4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#pid_modeString

The process namespace to use for the containers in the task. The valid values are host or task. For example, monitoring sidecars might need pidMode to access information about other containers running in the same task.

If host is specified, all containers within the tasks that specified the host PID mode on the same container instance share the process namespace with the host Amazon EC2 instance.

If task is specified, all containers within the specified task share the same process namespace.

If no value is specified, the default is a private namespace for each container. For more information, see PID settings in the Docker run reference.

Returns:

  • (String)


4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#platform_versionString

The Fargate platform version where the jobs are running. A platform version is specified only for jobs that are running on Fargate resources. If one isn't specified, the LATEST platform version is used by default. This uses a recent, approved version of the Fargate platform for compute resources. For more information, see Fargate platform versions in the Amazon Elastic Container Service Developer Guide.

Returns:

  • (String)


4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_platformTypes::RuntimePlatform

An object that represents the compute environment architecture for Batch jobs on Fargate or Amazon ECS Managed Instances. Use this to specify the operating system family (operatingSystemFamily) and CPU architecture (cpuArchitecture).

For Amazon ECS Managed Instances, the valid value for operatingSystemFamily is LINUX (default). The valid values for cpuArchitecture are X86_64 and ARM64.



4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#task_role_arnString

The Amazon Resource Name (ARN) that's associated with the Amazon ECS task.

This is object is comparable to ContainerProperties:jobRoleArn.

Returns:

  • (String)


4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end

#volumesArray<Types::Volume>

A list of volumes that are associated with the job.

Returns:



4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
# File 'lib/aws-sdk-batch/types.rb', line 4578

class EcsTaskProperties < Struct.new(
  :containers,
  :ephemeral_storage,
  :execution_role_arn,
  :platform_version,
  :ipc_mode,
  :task_role_arn,
  :pid_mode,
  :network_configuration,
  :runtime_platform,
  :volumes,
  :enable_execute_command,
  :network_mode)
  SENSITIVE = []
  include Aws::Structure
end