Class: Aws::Batch::Types::EksConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Configuration for the Amazon EKS cluster that supports the Batch compute environment. The cluster must exist before the compute environment can be created.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eks_cluster_arnString

The Amazon Resource Name (ARN) of the Amazon EKS cluster. An example is arn:aws:eks:us-east-1:123456789012:cluster/ClusterForBatch .

Returns:

  • (String)


4713
4714
4715
4716
4717
4718
# File 'lib/aws-sdk-batch/types.rb', line 4713

class EksConfiguration < Struct.new(
  :eks_cluster_arn,
  :kubernetes_namespace)
  SENSITIVE = []
  include Aws::Structure
end

#kubernetes_namespaceString

The namespace of the Amazon EKS cluster. Batch manages pods in this namespace. The value can't left empty or null. It must be fewer than 64 characters long, can't be set to default, can't start with "kube-," and must match this regular expression: ^[a-z0-9]([-a-z0-9]*[a-z0-9])?$. For more information, see Namespaces in the Kubernetes documentation.

Returns:

  • (String)


4713
4714
4715
4716
4717
4718
# File 'lib/aws-sdk-batch/types.rb', line 4713

class EksConfiguration < Struct.new(
  :eks_cluster_arn,
  :kubernetes_namespace)
  SENSITIVE = []
  include Aws::Structure
end