Class: Aws::Batch::Types::EksContainerOverride

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Object representing any Kubernetes overrides to a job definition that’s used in a [SubmitJob] API operation.

[1]: docs.aws.amazon.com/batch/latest/APIReference/API_SubmitJob.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#argsArray<String>

The arguments to the entrypoint to send to the container that overrides the default arguments from the Docker image or the job definition. For more information, see [Dockerfile reference: CMD] and [Define a command an arguments for a pod] in the *Kubernetes documentation*.

[1]: docs.docker.com/engine/reference/builder/#cmd [2]: kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/

Returns:

  • (Array<String>)


4811
4812
4813
4814
4815
4816
4817
4818
4819
4820
# File 'lib/aws-sdk-batch/types.rb', line 4811

class EksContainerOverride < Struct.new(
  :name,
  :image,
  :command,
  :args,
  :env,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#commandArray<String>

The command to send to the container that overrides the default command from the Docker image or the job definition.

Returns:

  • (Array<String>)


4811
4812
4813
4814
4815
4816
4817
4818
4819
4820
# File 'lib/aws-sdk-batch/types.rb', line 4811

class EksContainerOverride < Struct.new(
  :name,
  :image,
  :command,
  :args,
  :env,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#envArray<Types::EksContainerEnvironmentVariable>

The environment variables to send to the container. You can add new environment variables, which are added to the container at launch. Or, you can override the existing environment variables from the Docker image or the job definition.

<note markdown=“1”> Environment variables cannot start with “‘AWS_BATCH`”. This naming convention is reserved for variables that Batch sets.

</note>


4811
4812
4813
4814
4815
4816
4817
4818
4819
4820
# File 'lib/aws-sdk-batch/types.rb', line 4811

class EksContainerOverride < Struct.new(
  :name,
  :image,
  :command,
  :args,
  :env,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#imageString

The override of the Docker image that’s used to start the container.

Returns:

  • (String)


4811
4812
4813
4814
4815
4816
4817
4818
4819
4820
# File 'lib/aws-sdk-batch/types.rb', line 4811

class EksContainerOverride < Struct.new(
  :name,
  :image,
  :command,
  :args,
  :env,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A pointer to the container that you want to override. The name must match a unique container name that you wish to override.

Returns:

  • (String)


4811
4812
4813
4814
4815
4816
4817
4818
4819
4820
# File 'lib/aws-sdk-batch/types.rb', line 4811

class EksContainerOverride < Struct.new(
  :name,
  :image,
  :command,
  :args,
  :env,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#resourcesTypes::EksContainerResourceRequirements

The type and amount of resources to assign to a container. These override the settings in the job definition. The supported resources include ‘memory`, `cpu`, and `nvidia.com/gpu`. For more information, see [Resource management for pods and containers] in the *Kubernetes documentation*.

[1]: kubernetes.io/docs/concepts/configuration/manage-resources-containers/



4811
4812
4813
4814
4815
4816
4817
4818
4819
4820
# File 'lib/aws-sdk-batch/types.rb', line 4811

class EksContainerOverride < Struct.new(
  :name,
  :image,
  :command,
  :args,
  :env,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end