Class: Aws::Batch::Types::EksHostPath
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::EksHostPath
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Specifies the configuration of a Kubernetes hostPath volume. A
hostPath volume mounts an existing file or directory from the host
node's filesystem into your pod. For more information, see
hostPath in the Kubernetes documentation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#path ⇒ String
The path of the file or directory on the host to mount into containers on the pod.
Instance Attribute Details
#path ⇒ String
The path of the file or directory on the host to mount into containers on the pod.
5451 5452 5453 5454 5455 |
# File 'lib/aws-sdk-batch/types.rb', line 5451 class EksHostPath < Struct.new( :path) SENSITIVE = [] include Aws::Structure end |