Class: Aws::Batch::Types::EksPersistentVolumeClaim

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

A persistentVolumeClaim volume is used to mount a

PersistentVolume][1

into a Pod. PersistentVolumeClaims are a way for

users to “claim” durable storage without knowing the details of the particular cloud environment. See the information about

PersistentVolumes][1

in the *Kubernetes documentation*.

[1]: kubernetes.io/docs/concepts/storage/persistent-volumes/

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#claim_nameString

The name of the persistentVolumeClaim bounded to a persistentVolume. For more information, see [ Persistent Volume Claims] in the *Kubernetes documentation*.

[1]: kubernetes.io/docs/concepts/storage/persistent-volumes/#persistentvolumeclaims

Returns:

  • (String)


4978
4979
4980
4981
4982
4983
# File 'lib/aws-sdk-batch/types.rb', line 4978

class EksPersistentVolumeClaim < Struct.new(
  :claim_name,
  :read_only)
  SENSITIVE = []
  include Aws::Structure
end

#read_onlyBoolean

An optional boolean value indicating if the mount is read only. Default is false. For more information, see [ Read Only Mounts] in the *Kubernetes documentation*.

[1]: kubernetes.io/docs/concepts/storage/volumes/#read-only-mounts

Returns:

  • (Boolean)


4978
4979
4980
4981
4982
4983
# File 'lib/aws-sdk-batch/types.rb', line 4978

class EksPersistentVolumeClaim < Struct.new(
  :claim_name,
  :read_only)
  SENSITIVE = []
  include Aws::Structure
end