Class: Aws::Batch::Types::EksPodPropertiesOverride

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

An object that contains overrides for the Kubernetes pod properties of a job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#containersArray<Types::EksContainerOverride>

The overrides for the container that's used on the Amazon EKS pod.

Returns:



5763
5764
5765
5766
5767
5768
5769
# File 'lib/aws-sdk-batch/types.rb', line 5763

class EksPodPropertiesOverride < Struct.new(
  :containers,
  :init_containers,
  :metadata)
  SENSITIVE = []
  include Aws::Structure
end

#init_containersArray<Types::EksContainerOverride>

The overrides for the initContainers defined in the Amazon EKS pod. These containers run before application containers, always run to completion, and must complete successfully before the next container starts. These containers are registered with the Amazon EKS Connector agent and persists the registration information in the Kubernetes backend data store. For more information, see Init Containers in the Kubernetes documentation.

Returns:



5763
5764
5765
5766
5767
5768
5769
# File 'lib/aws-sdk-batch/types.rb', line 5763

class EksPodPropertiesOverride < Struct.new(
  :containers,
  :init_containers,
  :metadata)
  SENSITIVE = []
  include Aws::Structure
end

#metadataTypes::EksMetadata

Metadata about the overrides for the container that's used on the Amazon EKS pod.

Returns:



5763
5764
5765
5766
5767
5768
5769
# File 'lib/aws-sdk-batch/types.rb', line 5763

class EksPodPropertiesOverride < Struct.new(
  :containers,
  :init_containers,
  :metadata)
  SENSITIVE = []
  include Aws::Structure
end