Class: Aws::Batch::Types::FrontOfQuotaShareJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

An object that represents summary details for the first ‘RUNNABLE` job in a quota share.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#earliest_time_at_positionInteger

The Unix timestamp (in milliseconds) for when the job transitioned to its current position in the quota share.

Returns:

  • (Integer)


5959
5960
5961
5962
5963
5964
# File 'lib/aws-sdk-batch/types.rb', line 5959

class FrontOfQuotaShareJobSummary < Struct.new(
  :job_arn,
  :earliest_time_at_position)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The ARN for a job in a named quota share.

Returns:

  • (String)


5959
5960
5961
5962
5963
5964
# File 'lib/aws-sdk-batch/types.rb', line 5959

class FrontOfQuotaShareJobSummary < Struct.new(
  :job_arn,
  :earliest_time_at_position)
  SENSITIVE = []
  include Aws::Structure
end