Class: Aws::Batch::Types::FrontOfQuotaSharesDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::FrontOfQuotaSharesDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that represents the details of the first ‘RUNNABLE` job in each named quota share associated with a single job queue.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_updated_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the first ‘RUNNABLE` job per quota share were all last updated.
-
#quota_shares ⇒ Hash<String,Array<Types::FrontOfQuotaShareJobSummary>>
Contains a list of the first ‘RUNNABLE` job in each named quota share.
Instance Attribute Details
#last_updated_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the first ‘RUNNABLE` job per quota share were all last updated.
5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-batch/types.rb', line 5981 class FrontOfQuotaSharesDetail < Struct.new( :quota_shares, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#quota_shares ⇒ Hash<String,Array<Types::FrontOfQuotaShareJobSummary>>
Contains a list of the first ‘RUNNABLE` job in each named quota share.
5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-batch/types.rb', line 5981 class FrontOfQuotaSharesDetail < Struct.new( :quota_shares, :last_updated_at) SENSITIVE = [] include Aws::Structure end |