Class: Aws::Batch::Types::InstanceLaunchTemplateUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The instance launch configuration for updating an Amazon ECS Managed Instances capacity provider. You cannot change capacityOptionType or fipsEnabled after the compute environment is created.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservationsTypes::CapacityReservationRequest

The updated capacity reservation configuration.



6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
# File 'lib/aws-sdk-batch/types.rb', line 6479

class InstanceLaunchTemplateUpdate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :instance_requirements,
  :storage_configuration,
  :monitoring,
  :capacity_reservations,
  :instance_metadata_tags_propagation,
  :local_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_instance_profile_arnString

The updated Amazon Resource Name (ARN) of the Amazon EC2 instance profile for the managed instances.

Returns:

  • (String)


6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
# File 'lib/aws-sdk-batch/types.rb', line 6479

class InstanceLaunchTemplateUpdate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :instance_requirements,
  :storage_configuration,
  :monitoring,
  :capacity_reservations,
  :instance_metadata_tags_propagation,
  :local_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_metadata_tags_propagationBoolean

Specifies whether instance tags are accessible from the instance metadata service (IMDS).

Returns:

  • (Boolean)


6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
# File 'lib/aws-sdk-batch/types.rb', line 6479

class InstanceLaunchTemplateUpdate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :instance_requirements,
  :storage_configuration,
  :monitoring,
  :capacity_reservations,
  :instance_metadata_tags_propagation,
  :local_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_requirementsTypes::InstanceRequirementsRequest

The updated instance type requirements for the capacity provider.



6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
# File 'lib/aws-sdk-batch/types.rb', line 6479

class InstanceLaunchTemplateUpdate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :instance_requirements,
  :storage_configuration,
  :monitoring,
  :capacity_reservations,
  :instance_metadata_tags_propagation,
  :local_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#local_storage_configurationTypes::ManagedInstancesLocalStorageConfiguration

The updated local storage configuration.



6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
# File 'lib/aws-sdk-batch/types.rb', line 6479

class InstanceLaunchTemplateUpdate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :instance_requirements,
  :storage_configuration,
  :monitoring,
  :capacity_reservations,
  :instance_metadata_tags_propagation,
  :local_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#monitoringString

The updated monitoring level. Valid values are BASIC and DETAILED.

Returns:

  • (String)


6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
# File 'lib/aws-sdk-batch/types.rb', line 6479

class InstanceLaunchTemplateUpdate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :instance_requirements,
  :storage_configuration,
  :monitoring,
  :capacity_reservations,
  :instance_metadata_tags_propagation,
  :local_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::ManagedInstancesNetworkConfiguration

The updated network configuration for the managed instances.



6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
# File 'lib/aws-sdk-batch/types.rb', line 6479

class InstanceLaunchTemplateUpdate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :instance_requirements,
  :storage_configuration,
  :monitoring,
  :capacity_reservations,
  :instance_metadata_tags_propagation,
  :local_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#storage_configurationTypes::ManagedInstancesStorageConfiguration

The updated storage configuration for the managed instances.



6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
# File 'lib/aws-sdk-batch/types.rb', line 6479

class InstanceLaunchTemplateUpdate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :instance_requirements,
  :storage_configuration,
  :monitoring,
  :capacity_reservations,
  :instance_metadata_tags_propagation,
  :local_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end