Class: Aws::Batch::Types::InstanceRequirementsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::InstanceRequirementsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The instance type requirements for the Amazon ECS Managed Instances capacity provider. Use this to specify which Amazon EC2 instance types or instance families Amazon ECS can launch.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_instance_types ⇒ Array<String>
A list of specific instance types or instance families that Amazon ECS can launch (for example,
m5.largeorg5).
Instance Attribute Details
#allowed_instance_types ⇒ Array<String>
A list of specific instance types or instance families that Amazon
ECS can launch (for example, m5.large or g5). When specified,
only these instance types are used.
6590 6591 6592 6593 6594 |
# File 'lib/aws-sdk-batch/types.rb', line 6590 class InstanceRequirementsRequest < Struct.new( :allowed_instance_types) SENSITIVE = [] include Aws::Structure end |