Class: Aws::Batch::Types::JobCapacityUsageSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The capacity usage for a job, including the unit of measure and quantity of resources being used.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_unitString

The unit of measure for the capacity usage. This is VCPU for Amazon EC2 and cpu for Amazon EKS.



5747
5748
5749
5750
5751
5752
# File 'lib/aws-sdk-batch/types.rb', line 5747

class JobCapacityUsageSummary < Struct.new(
  :capacity_unit,
  :quantity)
  SENSITIVE = []
  include Aws::Structure
end

#quantityFloat

The quantity of capacity being used by the job, measured in the units specified by capacityUnit.



5747
5748
5749
5750
5751
5752
# File 'lib/aws-sdk-batch/types.rb', line 5747

class JobCapacityUsageSummary < Struct.new(
  :capacity_unit,
  :quantity)
  SENSITIVE = []
  include Aws::Structure
end