Method: Aws::Batch::Types::JobDefinition#parameters

Defined in:
lib/aws-sdk-batch/types.rb

#parametersHash<String,String>

Default parameters or parameter substitution placeholders that are set in the job definition. Parameters are specified as a key-value pair mapping. Parameters in a SubmitJob request override any corresponding parameter defaults from the job definition. For more information about specifying parameters, see [Job definition parameters] in the *Batch User Guide*.

[1]: docs.aws.amazon.com/batch/latest/userguide/job_definition_parameters.html

Returns:

  • (Hash<String,String>)


5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
5893
5894
5895
5896
5897
5898
5899
5900
# File 'lib/aws-sdk-batch/types.rb', line 5879

class JobDefinition < Struct.new(
  :job_definition_name,
  :job_definition_arn,
  :revision,
  :status,
  :type,
  :scheduling_priority,
  :parameters,
  :retry_strategy,
  :container_properties,
  :timeout,
  :node_properties,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :ecs_properties,
  :eks_properties,
  :container_orchestration_type,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end