Class: Aws::Batch::Types::JobDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

An object that represents an Batch job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#array_propertiesTypes::ArrayPropertiesDetail

The array properties of the job, if it’s an array job.



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#attemptsArray<Types::AttemptDetail>

A list of job attempts that are associated with this job.

Returns:



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#consumable_resource_propertiesTypes::ConsumableResourceProperties

Contains a list of consumable resources required by the job.



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#containerTypes::ContainerDetail

An object that represents the details for the container that’s associated with the job. If the details are for a multiple-container job, this object will be empty.



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#created_atInteger

The Unix timestamp (in milliseconds) for when the job was created. For non-array jobs and parent array jobs, this is when the job entered the SUBMITTED state. This is specifically at the time

SubmitJob][1

was called. For array child jobs, this is when the

child job was spawned by its parent and entered the PENDING state.

[1]: docs.aws.amazon.com/batch/latest/APIReference/API_SubmitJob.html

Returns:

  • (Integer)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#depends_onArray<Types::JobDependency>

A list of job IDs that this job depends on.

Returns:



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#ecs_propertiesTypes::EcsPropertiesDetail

An object with properties that are specific to Amazon ECS-based jobs.



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#eks_attemptsArray<Types::EksAttemptDetail>

A list of job attempts that are associated with this job.

Returns:



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#eks_propertiesTypes::EksPropertiesDetail

An object with various properties that are specific to Amazon EKS based jobs.



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_cancelledBoolean

Indicates whether the job is canceled.

Returns:

  • (Boolean)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_terminatedBoolean

Indicates whether the job is terminated.

Returns:

  • (Boolean)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The Amazon Resource Name (ARN) of the job.

Returns:

  • (String)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#job_definitionString

The Amazon Resource Name (ARN) of the job definition that this job uses.

Returns:

  • (String)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID.

Returns:

  • (String)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The job name.

Returns:

  • (String)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#job_queueString

The Amazon Resource Name (ARN) of the job queue that the job is associated with.

Returns:

  • (String)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#node_detailsTypes::NodeDetails

An object that represents the details of a node that’s associated with a multi-node parallel job.

Returns:



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#node_propertiesTypes::NodeProperties

An object that represents the node properties of a multi-node parallel job.

<note markdown=“1”> This isn’t applicable to jobs that are running on Fargate resources.

</note>


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,String>

Additional parameters that are passed to the job that replace parameter substitution placeholders or override any corresponding parameter defaults from the job definition.

Returns:

  • (Hash<String,String>)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#platform_capabilitiesArray<String>

The platform capabilities required by the job definition. If no value is specified, it defaults to EC2. Jobs run on Fargate resources specify FARGATE.

Returns:

  • (Array<String>)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#propagate_tagsBoolean

Specifies whether to propagate the tags from the job or job definition to the corresponding Amazon ECS task. If no value is specified, the tags aren’t propagated. Tags can only be propagated to the tasks when the tasks are created. For tags with the same name, job tags are given priority over job definitions tags. If the total number of combined tags from the job and job definition is over 50, the job is moved to the FAILED state.

Returns:

  • (Boolean)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#retry_strategyTypes::RetryStrategy

The retry strategy to use for this job if an attempt fails.



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#scheduling_priorityInteger

The scheduling policy of the job definition. This only affects jobs in job queues with a fair-share policy. Jobs with a higher scheduling priority are scheduled before jobs with a lower scheduling priority.

Returns:

  • (Integer)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#share_identifierString

The share identifier for the job.

Returns:

  • (String)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#started_atInteger

The Unix timestamp (in milliseconds) for when the job was started. More specifically, it’s when the job transitioned from the STARTING state to the RUNNING state.

Returns:

  • (Integer)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status for the job.

<note markdown=“1”> If your jobs don’t progress to STARTING, see [Jobs stuck in RUNNABLE status] in the troubleshooting section of the *Batch User Guide*.

</note>

[1]: docs.aws.amazon.com/batch/latest/userguide/troubleshooting.html#job_stuck_in_runnable

Returns:

  • (String)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

A short, human-readable string to provide more details for the current status of the job.

  • CAPACITY:INSUFFICIENT_INSTANCE_CAPACITY - All compute environments have insufficient capacity to service the job.

  • MISCONFIGURATION:COMPUTE_ENVIRONMENT_MAX_RESOURCE - All compute environments have a maxVcpu setting that is smaller than the job requirements.

  • MISCONFIGURATION:JOB_RESOURCE_REQUIREMENT - All compute environments have no connected instances that meet the job requirements.

  • MISCONFIGURATION:SERVICE_ROLE_PERMISSIONS - All compute environments have problems with the service role permissions.

Returns:

  • (String)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atInteger

The Unix timestamp (in milliseconds) for when the job was stopped. More specifically, it’s when the job transitioned from the RUNNING state to a terminal state, such as SUCCEEDED or FAILED.

Returns:

  • (Integer)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags that are applied to the job.

Returns:

  • (Hash<String,String>)


6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutTypes::JobTimeout

The timeout configuration for the job.

Returns:



6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-batch/types.rb', line 6160

class JobDetail < Struct.new(
  :job_arn,
  :job_name,
  :job_id,
  :job_queue,
  :status,
  :share_identifier,
  :scheduling_priority,
  :attempts,
  :status_reason,
  :created_at,
  :retry_strategy,
  :started_at,
  :stopped_at,
  :depends_on,
  :job_definition,
  :parameters,
  :container,
  :node_details,
  :node_properties,
  :array_properties,
  :timeout,
  :tags,
  :propagate_tags,
  :platform_capabilities,
  :eks_properties,
  :eks_attempts,
  :ecs_properties,
  :is_cancelled,
  :is_terminated,
  :consumable_resource_properties)
  SENSITIVE = []
  include Aws::Structure
end