Class: Aws::Batch::Types::JobStateTimeLimitAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::JobStateTimeLimitAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Specifies an action that Batch will take after the job has remained at the head of the queue in the specified state for longer than the specified time.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to take when a job is at the head of the job queue in the specified state for the specified period of time.
-
#max_time_seconds ⇒ Integer
The approximate amount of time, in seconds, that must pass with the job in the specified state before the action is taken.
-
#reason ⇒ String
The reason to log for the action being taken.
-
#state ⇒ String
The state of the job needed to trigger the action.
Instance Attribute Details
#action ⇒ String
The action to take when a job is at the head of the job queue in the specified state for the specified period of time. For job queues connected to a ‘ECS`, `FARGATE` or `EKS` compute environment, the only supported value is `CANCEL`, which will cancel the job. For job queues connected to a `SAGEMAKER_TRAINING` service environment, the only supported value is `TERMINATE`, which will terminate the job.
6638 6639 6640 6641 6642 6643 6644 6645 |
# File 'lib/aws-sdk-batch/types.rb', line 6638 class JobStateTimeLimitAction < Struct.new( :reason, :state, :max_time_seconds, :action) SENSITIVE = [] include Aws::Structure end |
#max_time_seconds ⇒ Integer
The approximate amount of time, in seconds, that must pass with the job in the specified state before the action is taken. The minimum value is 600 (10 minutes) and the maximum value is 86,400 (24 hours).
6638 6639 6640 6641 6642 6643 6644 6645 |
# File 'lib/aws-sdk-batch/types.rb', line 6638 class JobStateTimeLimitAction < Struct.new( :reason, :state, :max_time_seconds, :action) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason to log for the action being taken.
6638 6639 6640 6641 6642 6643 6644 6645 |
# File 'lib/aws-sdk-batch/types.rb', line 6638 class JobStateTimeLimitAction < Struct.new( :reason, :state, :max_time_seconds, :action) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the job needed to trigger the action. The only supported value is ‘RUNNABLE`.
6638 6639 6640 6641 6642 6643 6644 6645 |
# File 'lib/aws-sdk-batch/types.rb', line 6638 class JobStateTimeLimitAction < Struct.new( :reason, :state, :max_time_seconds, :action) SENSITIVE = [] include Aws::Structure end |