Class: Aws::Batch::Types::JobTimeout
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::JobTimeout
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that represents a job timeout configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attempt_duration_seconds ⇒ Integer
The job timeout time (in seconds) that's measured from the job attempt's
startedAttimestamp.
Instance Attribute Details
#attempt_duration_seconds ⇒ Integer
The job timeout time (in seconds) that's measured from the job
attempt's startedAt timestamp. After this time passes, Batch
terminates your jobs if they aren't finished. The minimum value for
the timeout is 60 seconds.
For array jobs, the timeout applies to the child jobs, not to the parent array job.
For multi-node parallel (MNP) jobs, the timeout applies to the whole job, not to the individual nodes.
6921 6922 6923 6924 6925 |
# File 'lib/aws-sdk-batch/types.rb', line 6921 class JobTimeout < Struct.new( :attempt_duration_seconds) SENSITIVE = [] include Aws::Structure end |