Class: Aws::Batch::Types::LatestServiceJobAttempt

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Information about the latest attempt of a service job. A Service job can transition from SCHEDULED back to RUNNABLE state when they encounter capacity constraints.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#service_resource_idTypes::ServiceResourceId

The service resource identifier associated with the service job attempt.



6538
6539
6540
6541
6542
# File 'lib/aws-sdk-batch/types.rb', line 6538

class LatestServiceJobAttempt < Struct.new(
  :service_resource_id)
  SENSITIVE = []
  include Aws::Structure
end