Class: Aws::Batch::Types::ListConsumableResourcesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::KeyValuesPair>

The filters to apply to the consumable resource list query. If used, only those consumable resources that match the filter are listed. Filter names and values can be:

  • name: ‘CONSUMABLE_RESOURCE_NAME `

    values: case-insensitive matches for the consumable resource name. If a filter value ends with an asterisk (*), it matches any consumable resource name that begins with the string before the ‘*’.

Returns:



6949
6950
6951
6952
6953
6954
6955
# File 'lib/aws-sdk-batch/types.rb', line 6949

class ListConsumableResourcesRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results returned by ListConsumableResources in paginated output. When this parameter is used, ListConsumableResources only returns maxResults results in a single page and a nextToken response element. The remaining results of the initial request can be seen by sending another ListConsumableResources request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn’t used, then ListConsumableResources returns up to 100 results and a nextToken value if applicable.

Returns:

  • (Integer)


6949
6950
6951
6952
6953
6954
6955
# File 'lib/aws-sdk-batch/types.rb', line 6949

class ListConsumableResourcesRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value returned from a previous paginated ListConsumableResources request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

<note markdown=“1”> Treat this token as an opaque identifier that’s only used to retrieve the next items in a list and not for other programmatic purposes.

</note>

Returns:

  • (String)


6949
6950
6951
6952
6953
6954
6955
# File 'lib/aws-sdk-batch/types.rb', line 6949

class ListConsumableResourcesRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end