Class: Aws::Batch::Types::ListConsumableResourcesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ListConsumableResourcesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumable_resources ⇒ Array<Types::ConsumableResourceSummary>
A list of consumable resources that match the request.
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListConsumableResourcesrequest.
Instance Attribute Details
#consumable_resources ⇒ Array<Types::ConsumableResourceSummary>
A list of consumable resources that match the request.
7801 7802 7803 7804 7805 7806 |
# File 'lib/aws-sdk-batch/types.rb', line 7801 class ListConsumableResourcesResponse < Struct.new( :consumable_resources, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future
ListConsumableResources request. When the results of a
ListConsumableResources request exceed maxResults, this value
can be used to retrieve the next page of results. This value is
null when there are no more results to return.
7801 7802 7803 7804 7805 7806 |
# File 'lib/aws-sdk-batch/types.rb', line 7801 class ListConsumableResourcesResponse < Struct.new( :consumable_resources, :next_token) SENSITIVE = [] include Aws::Structure end |