Class: Aws::Batch::Types::ListJobsByConsumableResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumable_resourceString

The name or ARN of the consumable resource.

Returns:

  • (String)


7029
7030
7031
7032
7033
7034
7035
7036
# File 'lib/aws-sdk-batch/types.rb', line 7029

class ListJobsByConsumableResourceRequest < Struct.new(
  :consumable_resource,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::KeyValuesPair>

The filters to apply to the job list query. If used, only those jobs requiring the specified consumable resource (consumableResource) and that match the value of the filters are listed. The filter names and values can be:

  • name: JOB_STATUS

    values: ‘SUBMITTED | PENDING | RUNNABLE | STARTING | RUNNING | SUCCEEDED | FAILED`

  • name: ‘JOB_NAME `

    The values are case-insensitive matches for the job name. If a filter value ends with an asterisk (*), it matches any job name that begins with the string before the ‘*’.

Returns:



7029
7030
7031
7032
7033
7034
7035
7036
# File 'lib/aws-sdk-batch/types.rb', line 7029

class ListJobsByConsumableResourceRequest < Struct.new(
  :consumable_resource,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results returned by ListJobsByConsumableResource in paginated output. When this parameter is used, ListJobsByConsumableResource only returns maxResults results in a single page and a nextToken response element. The remaining results of the initial request can be seen by sending another ListJobsByConsumableResource request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn’t used, then ListJobsByConsumableResource returns up to 100 results and a nextToken value if applicable.

Returns:

  • (Integer)


7029
7030
7031
7032
7033
7034
7035
7036
# File 'lib/aws-sdk-batch/types.rb', line 7029

class ListJobsByConsumableResourceRequest < Struct.new(
  :consumable_resource,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value returned from a previous paginated ListJobsByConsumableResource request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

<note markdown=“1”> Treat this token as an opaque identifier that’s only used to retrieve the next items in a list and not for other programmatic purposes.

</note>

Returns:

  • (String)


7029
7030
7031
7032
7033
7034
7035
7036
# File 'lib/aws-sdk-batch/types.rb', line 7029

class ListJobsByConsumableResourceRequest < Struct.new(
  :consumable_resource,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end