Class: Aws::Batch::Types::ListJobsByConsumableResourceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#jobsArray<Types::ListJobsByConsumableResourceSummary>

The list of jobs that require the specified consumable resources.



7347
7348
7349
7350
7351
7352
# File 'lib/aws-sdk-batch/types.rb', line 7347

class ListJobsByConsumableResourceResponse < Struct.new(
  :jobs,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value to include in a future ListJobsByConsumableResource request. When the results of a ListJobsByConsumableResource request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.



7347
7348
7349
7350
7351
7352
# File 'lib/aws-sdk-batch/types.rb', line 7347

class ListJobsByConsumableResourceResponse < Struct.new(
  :jobs,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end