Class: Aws::Batch::Types::ListJobsByConsumableResourceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ListJobsByConsumableResourceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Current information about a consumable resource required by a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumable_resource_properties ⇒ Types::ConsumableResourceProperties
Contains a list of consumable resources required by the job.
-
#created_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the consumable resource was created.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
-
#job_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the job definition.
-
#job_name ⇒ String
The name of the job.
-
#job_queue_arn ⇒ String
The Amazon Resource Name (ARN) of the job queue.
-
#job_status ⇒ String
The status of the job.
-
#quantity ⇒ Integer
The total amount of the consumable resource that is available.
-
#share_identifier ⇒ String
The fair-share scheduling identifier for the job.
-
#started_at ⇒ Integer
The Unix timestamp for when the job was started.
-
#status_reason ⇒ String
A short, human-readable string to provide more details for the current status of the job.
Instance Attribute Details
#consumable_resource_properties ⇒ Types::ConsumableResourceProperties
Contains a list of consumable resources required by the job.
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the consumable resource was created.
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |
#job_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the job definition.
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the job.
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |
#job_queue_arn ⇒ String
The Amazon Resource Name (ARN) of the job queue.
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The status of the job. Can be one of:
-
SUBMITTED -
PENDING -
RUNNABLE -
STARTING -
RUNNING -
SUCCEEDED -
FAILED
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Integer
The total amount of the consumable resource that is available.
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |
#share_identifier ⇒ String
The fair-share scheduling identifier for the job.
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Integer
The Unix timestamp for when the job was started. More specifically,
it's when the job transitioned from the STARTING state to the
RUNNING state.
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A short, human-readable string to provide more details for the current status of the job.
7955 7956 7957 7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 7968 7969 |
# File 'lib/aws-sdk-batch/types.rb', line 7955 class ListJobsByConsumableResourceSummary < Struct.new( :job_arn, :job_queue_arn, :job_name, :job_definition_arn, :share_identifier, :job_status, :quantity, :status_reason, :started_at, :created_at, :consumable_resource_properties) SENSITIVE = [] include Aws::Structure end |