Class: Aws::Batch::Types::ListSchedulingPoliciesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ListSchedulingPoliciesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListSchedulingPoliciesrequest. -
#scheduling_policies ⇒ Array<Types::SchedulingPolicyListingDetail>
A list of scheduling policies that match the request.
Instance Attribute Details
#next_token ⇒ String
The nextToken value to include in a future
ListSchedulingPolicies request. When the results of a
ListSchedulingPolicies request exceed maxResults, this value can
be used to retrieve the next page of results. This value is null
when there are no more results to return.
8248 8249 8250 8251 8252 8253 |
# File 'lib/aws-sdk-batch/types.rb', line 8248 class ListSchedulingPoliciesResponse < Struct.new( :scheduling_policies, :next_token) SENSITIVE = [] include Aws::Structure end |
#scheduling_policies ⇒ Array<Types::SchedulingPolicyListingDetail>
A list of scheduling policies that match the request.
8248 8249 8250 8251 8252 8253 |
# File 'lib/aws-sdk-batch/types.rb', line 8248 class ListSchedulingPoliciesResponse < Struct.new( :scheduling_policies, :next_token) SENSITIVE = [] include Aws::Structure end |