Class: Aws::Batch::Types::ListServiceJobsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::KeyValuesPair>

The filter to apply to the query. Only one filter can be used at a time. When the filter is used, jobStatus is ignored with the exception that SHARE_IDENTIFIER or QUOTA_SHARE_NAME and jobStatus can be used together. The results are sorted by the createdAt field, with the most recent jobs being first.

The SHARE_IDENTIFIER or QUOTA_SHARE_NAME filter and the jobStatus field can be used together to filter results.

JOB_NAME

: The value of the filter is a case-insensitive match for the job name. If the value ends with an asterisk (), the filter matches any job name that begins with the string before the ''. This corresponds to the jobName value. For example, test1 matches both Test1 and test1, and test1* matches both test1 and Test10. When the JOB_NAME filter is used, the results are grouped by the job name and version.

BEFORE_CREATED_AT

: The value for the filter is the time that's before the job was created. This corresponds to the createdAt value. The value is a string representation of the number of milliseconds since 00:00:00 UTC (midnight) on January 1, 1970.

AFTER_CREATED_AT

: The value for the filter is the time that's after the job was created. This corresponds to the createdAt value. The value is a string representation of the number of milliseconds since 00:00:00 UTC (midnight) on January 1, 1970.

SHARE_IDENTIFIER

: The value for the filter is the fairshare scheduling share identifier.

QUOTA_SHARE_NAME

: The value for the filter is the quota management share name.

Returns:



8347
8348
8349
8350
8351
8352
8353
8354
8355
# File 'lib/aws-sdk-batch/types.rb', line 8347

class ListServiceJobsRequest < Struct.new(
  :job_queue,
  :job_status,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#job_queueString

The name or ARN of the job queue with which to list service jobs.

Returns:

  • (String)


8347
8348
8349
8350
8351
8352
8353
8354
8355
# File 'lib/aws-sdk-batch/types.rb', line 8347

class ListServiceJobsRequest < Struct.new(
  :job_queue,
  :job_status,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The job status used to filter service jobs in the specified queue. If the filters parameter is specified, the jobStatus parameter is ignored and jobs with any status are returned. The exceptions are the SHARE_IDENTIFIER filter and QUOTA_SHARE_NAME filter, which can be used with jobStatus. If you don't specify a status, only RUNNING jobs are returned.

The SHARE_IDENTIFIER filter or QUOTA_SHARE_NAME filter can be used with the jobStatus field to filter results.

Returns:

  • (String)


8347
8348
8349
8350
8351
8352
8353
8354
8355
# File 'lib/aws-sdk-batch/types.rb', line 8347

class ListServiceJobsRequest < Struct.new(
  :job_queue,
  :job_status,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results returned by ListServiceJobs in paginated output. When this parameter is used, ListServiceJobs only returns maxResults results in a single page and a nextToken response element. The remaining results of the initial request can be seen by sending another ListServiceJobs request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn't used, then ListServiceJobs returns up to 100 results and a nextToken value if applicable.

Returns:

  • (Integer)


8347
8348
8349
8350
8351
8352
8353
8354
8355
# File 'lib/aws-sdk-batch/types.rb', line 8347

class ListServiceJobsRequest < Struct.new(
  :job_queue,
  :job_status,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value returned from a previous paginated ListServiceJobs request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

Treat this token as an opaque identifier that's only used to retrieve the next items in a list and not for other programmatic purposes.

Returns:

  • (String)


8347
8348
8349
8350
8351
8352
8353
8354
8355
# File 'lib/aws-sdk-batch/types.rb', line 8347

class ListServiceJobsRequest < Struct.new(
  :job_queue,
  :job_status,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end