Class: Aws::Batch::Types::ListServiceJobsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_summary_listArray<Types::ServiceJobSummary>

A list of service job summaries.



7836
7837
7838
7839
7840
7841
# File 'lib/aws-sdk-batch/types.rb', line 7836

class ListServiceJobsResponse < Struct.new(
  :job_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value to include in a future ListServiceJobs request. When the results of a ListServiceJobs request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.



7836
7837
7838
7839
7840
7841
# File 'lib/aws-sdk-batch/types.rb', line 7836

class ListServiceJobsResponse < Struct.new(
  :job_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end