Class: Aws::Batch::Types::ListTagsForResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Contains the parameters for ‘ListTagsForResource`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) that identifies the resource that tags are listed for. Batch resources that support tags are compute environments, jobs, job definitions, job queues, and scheduling policies. ARNs for child jobs of array and multi-node parallel (MNP) jobs aren’t supported.

Returns:

  • (String)


7253
7254
7255
7256
7257
# File 'lib/aws-sdk-batch/types.rb', line 7253

class ListTagsForResourceRequest < Struct.new(
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end