Class: Aws::Batch::Types::ManagedInstancesProvider

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The configuration for an Amazon ECS Managed Instances capacity provider. This object is required when creating a compute environment with computeResources.type set to ECS_MANAGED_INSTANCES.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#infrastructure_optimizationTypes::InfrastructureOptimization

The infrastructure optimization configuration for the capacity provider. Specifies the idle-instance scale-in behavior.



8507
8508
8509
8510
8511
8512
8513
8514
# File 'lib/aws-sdk-batch/types.rb', line 8507

class ManagedInstancesProvider < Struct.new(
  :propagate_tags,
  :infrastructure_role_arn,
  :instance_launch_template,
  :infrastructure_optimization)
  SENSITIVE = []
  include Aws::Structure
end

#infrastructure_role_arnString

The Amazon Resource Name (ARN) of the IAM role that Amazon ECS assumes to manage Amazon EC2 instances on your behalf. This role must have a trust policy for ecs.amazonaws.com. You must have the iam:PassRole permission for this role with the condition iam:PassedToService: ecs.amazonaws.com.

Returns:

  • (String)


8507
8508
8509
8510
8511
8512
8513
8514
# File 'lib/aws-sdk-batch/types.rb', line 8507

class ManagedInstancesProvider < Struct.new(
  :propagate_tags,
  :infrastructure_role_arn,
  :instance_launch_template,
  :infrastructure_optimization)
  SENSITIVE = []
  include Aws::Structure
end

#instance_launch_templateTypes::InstanceLaunchTemplate

The instance launch configuration for the Amazon ECS Managed Instances capacity provider. Contains networking, instance profile, instance requirements, capacity type, storage, and monitoring configuration.



8507
8508
8509
8510
8511
8512
8513
8514
# File 'lib/aws-sdk-batch/types.rb', line 8507

class ManagedInstancesProvider < Struct.new(
  :propagate_tags,
  :infrastructure_role_arn,
  :instance_launch_template,
  :infrastructure_optimization)
  SENSITIVE = []
  include Aws::Structure
end

#propagate_tagsString

Specifies whether tags on the capacity provider are propagated to the Amazon EC2 instances it launches. Valid values:

  • CAPACITY_PROVIDER — Propagates tags to instances.

  • NONE (default) — Does not propagate tags to instances.

Returns:

  • (String)


8507
8508
8509
8510
8511
8512
8513
8514
# File 'lib/aws-sdk-batch/types.rb', line 8507

class ManagedInstancesProvider < Struct.new(
  :propagate_tags,
  :infrastructure_role_arn,
  :instance_launch_template,
  :infrastructure_optimization)
  SENSITIVE = []
  include Aws::Structure
end