Class: Aws::Batch::Types::QueueSnapshotUtilizationDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The job queue utilization at a specific point in time, including total capacity usage and fairshare utilization breakdown.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fairshare_utilizationTypes::FairshareUtilizationDetail

The utilization information for a fairshare scheduling job queues, including active share count and top capacity utilization by share.



7949
7950
7951
7952
7953
7954
7955
# File 'lib/aws-sdk-batch/types.rb', line 7949

class QueueSnapshotUtilizationDetail < Struct.new(
  :total_capacity_usage,
  :fairshare_utilization,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atInteger

The Unix timestamp (in milliseconds) for when the queue utilization information was last updated.

Returns:

  • (Integer)


7949
7950
7951
7952
7953
7954
7955
# File 'lib/aws-sdk-batch/types.rb', line 7949

class QueueSnapshotUtilizationDetail < Struct.new(
  :total_capacity_usage,
  :fairshare_utilization,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#total_capacity_usageArray<Types::QueueSnapshotCapacityUsage>

The total capacity usage for the entire job queue, for both first-in, first-out (FIFO) and fairshare scheduling job queue.



7949
7950
7951
7952
7953
7954
7955
# File 'lib/aws-sdk-batch/types.rb', line 7949

class QueueSnapshotUtilizationDetail < Struct.new(
  :total_capacity_usage,
  :fairshare_utilization,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end