Class: Aws::Batch::Types::QuotaShareCapacityLimit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Defines the capacity limit for a quota share, or the type and maximum quantity of a particular resource that can be allocated to jobs in the quota share without borrowing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_unitString

The unit of compute capacity for the capacityLimit. For example, ml.m5.large.



8393
8394
8395
8396
8397
8398
# File 'lib/aws-sdk-batch/types.rb', line 8393

class QuotaShareCapacityLimit < Struct.new(
  :max_capacity,
  :capacity_unit)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityInteger

The maximum capacity available for the quota share. This value represents the maximum quantity of a resource that can be allocated to jobs in the quota share without borrowing.



8393
8394
8395
8396
8397
8398
# File 'lib/aws-sdk-batch/types.rb', line 8393

class QuotaShareCapacityLimit < Struct.new(
  :max_capacity,
  :capacity_unit)
  SENSITIVE = []
  include Aws::Structure
end