Class: Aws::Batch::Types::QuotaShareCapacityUsage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::QuotaShareCapacityUsage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The capacity usage for a quota share, including units of compute capacity and quantity of resources being used.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_unit ⇒ String
The unit of compute capacity for the capacity usage.
-
#quantity ⇒ Float
The quantity of capacity being used.
Instance Attribute Details
#capacity_unit ⇒ String
The unit of compute capacity for the capacity usage.
8413 8414 8415 8416 8417 8418 |
# File 'lib/aws-sdk-batch/types.rb', line 8413 class QuotaShareCapacityUsage < Struct.new( :capacity_unit, :quantity) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Float
The quantity of capacity being used.
8413 8414 8415 8416 8417 8418 |
# File 'lib/aws-sdk-batch/types.rb', line 8413 class QuotaShareCapacityUsage < Struct.new( :capacity_unit, :quantity) SENSITIVE = [] include Aws::Structure end |