Class: Aws::Batch::Types::QuotaShareCapacityUtilization
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::QuotaShareCapacityUtilization
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The capacity utilization for a specific quota share, including the quota share name and its current usage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_usage ⇒ Array<Types::QuotaShareCapacityUsage>
The capacity usage information for this quota share, including the units of compute capacity and quantity being used.
-
#quota_share_name ⇒ String
The name of the quota share.
Instance Attribute Details
#capacity_usage ⇒ Array<Types::QuotaShareCapacityUsage>
The capacity usage information for this quota share, including the units of compute capacity and quantity being used.
8434 8435 8436 8437 8438 8439 |
# File 'lib/aws-sdk-batch/types.rb', line 8434 class QuotaShareCapacityUtilization < Struct.new( :quota_share_name, :capacity_usage) SENSITIVE = [] include Aws::Structure end |
#quota_share_name ⇒ String
The name of the quota share.
8434 8435 8436 8437 8438 8439 |
# File 'lib/aws-sdk-batch/types.rb', line 8434 class QuotaShareCapacityUtilization < Struct.new( :quota_share_name, :capacity_usage) SENSITIVE = [] include Aws::Structure end |