Class: Aws::Batch::Types::QuotaSharePolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::QuotaSharePolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The quota share scheduling policy details for a job queue.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#idle_resource_assignment_strategy ⇒ String
The strategy that determines how idle resources are assigned to quota shares that are borrowing capacity.
Instance Attribute Details
#idle_resource_assignment_strategy ⇒ String
The strategy that determines how idle resources are assigned to quota shares that are borrowing capacity. Currently, only ‘FIFO` is supported.
8505 8506 8507 8508 8509 |
# File 'lib/aws-sdk-batch/types.rb', line 8505 class QuotaSharePolicy < Struct.new( :idle_resource_assignment_strategy) SENSITIVE = [] include Aws::Structure end |