Class: Aws::Batch::Types::QuotaShareResourceSharingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Specifies whether a quota share reserves, lends, or both lends and borrows idle compute capacity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#borrow_limitInteger

The maximum percentage of additional capacity that the quota share can borrow from other shares. borrowLimit can only be applied to quota shares with a strategy of LEND_AND_BORROW. This value is expressed as a percentage of the quota share’s configured [CapacityLimits][1].

The borrowLimit is applied uniformly across all capacity units. For example, if the borrowLimit is 200, the quota share can borrow up to 200% of its configured maxCapacity for each capacity unit. The default borrowLimit is -1, which indicates unlimited borrowing.

[1]: docs.aws.amazon.com/batch/latest/APIReference/API_QuotaShareCapacityLimit.html



8557
8558
8559
8560
8561
8562
# File 'lib/aws-sdk-batch/types.rb', line 8557

class QuotaShareResourceSharingConfiguration < Struct.new(
  :strategy,
  :borrow_limit)
  SENSITIVE = []
  include Aws::Structure
end

#strategyString

The resource sharing strategy for the quota share. The RESERVE strategy allows a quota share to reserve idle capacity for itself. LEND configures the share to lend its idle capacity to another share in need of capacity. The LEND_AND_BORROW strategy configures the share to borrow idle capacity from an underutilized share, as well as lend to another share.



8557
8558
8559
8560
8561
8562
# File 'lib/aws-sdk-batch/types.rb', line 8557

class QuotaShareResourceSharingConfiguration < Struct.new(
  :strategy,
  :borrow_limit)
  SENSITIVE = []
  include Aws::Structure
end