Class: Aws::Batch::Types::RetryStrategy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::RetryStrategy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The retry strategy that’s associated with a job. For more information, see [Automated job retries] in the *Batch User Guide*.
[1]: docs.aws.amazon.com/batch/latest/userguide/job_retries.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attempts ⇒ Integer
The number of times to move a job to the
RUNNABLEstatus. -
#evaluate_on_exit ⇒ Array<Types::EvaluateOnExit>
Array of up to 5 objects that specify the conditions where jobs are retried or failed.
Instance Attribute Details
#attempts ⇒ Integer
The number of times to move a job to the RUNNABLE status. You can specify between 1 and 10 attempts. If the value of attempts is greater than one, the job is retried on failure the same number of attempts as the value.
8369 8370 8371 8372 8373 8374 |
# File 'lib/aws-sdk-batch/types.rb', line 8369 class RetryStrategy < Struct.new( :attempts, :evaluate_on_exit) SENSITIVE = [] include Aws::Structure end |
#evaluate_on_exit ⇒ Array<Types::EvaluateOnExit>
Array of up to 5 objects that specify the conditions where jobs are retried or failed. If this parameter is specified, then the attempts parameter must also be specified. If none of the listed conditions match, then the job is retried.
8369 8370 8371 8372 8373 8374 |
# File 'lib/aws-sdk-batch/types.rb', line 8369 class RetryStrategy < Struct.new( :attempts, :evaluate_on_exit) SENSITIVE = [] include Aws::Structure end |