Class: Aws::Batch::Types::S3FilesVolumeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

This is used when you’re using an S3Files file system for job storage.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_point_arnString

The Amazon Resource Name (ARN) of the S3Files access point to use.

Returns:

  • (String)


9083
9084
9085
9086
9087
9088
9089
9090
# File 'lib/aws-sdk-batch/types.rb', line 9083

class S3FilesVolumeConfiguration < Struct.new(
  :file_system_arn,
  :root_directory,
  :transit_encryption_port,
  :access_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_arnString

The Amazon Resource Name (ARN) of the S3Files file system to use.

Returns:

  • (String)


9083
9084
9085
9086
9087
9088
9089
9090
# File 'lib/aws-sdk-batch/types.rb', line 9083

class S3FilesVolumeConfiguration < Struct.new(
  :file_system_arn,
  :root_directory,
  :transit_encryption_port,
  :access_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#root_directoryString

The directory within the S3Files file system to mount as the root directory.

Returns:

  • (String)


9083
9084
9085
9086
9087
9088
9089
9090
# File 'lib/aws-sdk-batch/types.rb', line 9083

class S3FilesVolumeConfiguration < Struct.new(
  :file_system_arn,
  :root_directory,
  :transit_encryption_port,
  :access_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#transit_encryption_portInteger

The port to use when sending encrypted data between the Amazon ECS host and the S3Files file system server.

Returns:

  • (Integer)


9083
9084
9085
9086
9087
9088
9089
9090
# File 'lib/aws-sdk-batch/types.rb', line 9083

class S3FilesVolumeConfiguration < Struct.new(
  :file_system_arn,
  :root_directory,
  :transit_encryption_port,
  :access_point_arn)
  SENSITIVE = []
  include Aws::Structure
end