Class: Aws::Batch::Types::SchedulingPolicyDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::SchedulingPolicyDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that represents a scheduling policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the scheduling policy.
-
#fairshare_policy ⇒ Types::FairsharePolicy
The fair-share scheduling policy details.
-
#name ⇒ String
The name of the fair-share scheduling policy.
-
#quota_share_policy ⇒ Types::QuotaSharePolicy
The quota share scheduling policy details.
-
#tags ⇒ Hash<String,String>
The tags that you apply to the fair-share scheduling policy to categorize and organize your resources.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the scheduling policy. An example is ‘arn:aws:batch:us-east-1:123456789012:scheduling-policy/HighPriority `.
9126 9127 9128 9129 9130 9131 9132 9133 9134 |
# File 'lib/aws-sdk-batch/types.rb', line 9126 class SchedulingPolicyDetail < Struct.new( :name, :arn, :quota_share_policy, :fairshare_policy, :tags) SENSITIVE = [] include Aws::Structure end |
#fairshare_policy ⇒ Types::FairsharePolicy
The fair-share scheduling policy details.
9126 9127 9128 9129 9130 9131 9132 9133 9134 |
# File 'lib/aws-sdk-batch/types.rb', line 9126 class SchedulingPolicyDetail < Struct.new( :name, :arn, :quota_share_policy, :fairshare_policy, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the fair-share scheduling policy.
9126 9127 9128 9129 9130 9131 9132 9133 9134 |
# File 'lib/aws-sdk-batch/types.rb', line 9126 class SchedulingPolicyDetail < Struct.new( :name, :arn, :quota_share_policy, :fairshare_policy, :tags) SENSITIVE = [] include Aws::Structure end |
#quota_share_policy ⇒ Types::QuotaSharePolicy
The quota share scheduling policy details.
9126 9127 9128 9129 9130 9131 9132 9133 9134 |
# File 'lib/aws-sdk-batch/types.rb', line 9126 class SchedulingPolicyDetail < Struct.new( :name, :arn, :quota_share_policy, :fairshare_policy, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags that you apply to the fair-share scheduling policy to categorize and organize your resources. Each tag consists of a key and an optional value. For more information, see [Tagging Amazon Web Services resources] in *Amazon Web Services General Reference*.
9126 9127 9128 9129 9130 9131 9132 9133 9134 |
# File 'lib/aws-sdk-batch/types.rb', line 9126 class SchedulingPolicyDetail < Struct.new( :name, :arn, :quota_share_policy, :fairshare_policy, :tags) SENSITIVE = [] include Aws::Structure end |