Class: Aws::Batch::Types::Secret
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::Secret
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that represents the secret to expose to your container. Secrets can be exposed to a container in the following ways:
-
To inject sensitive data into your containers as environment variables, use the
secretscontainer definition parameter. -
To reference sensitive information in the log configuration of a container, use the
secretOptionscontainer definition parameter.
For more information, see [Specifying sensitive data][1] in the *Batch User Guide*.
[1]: docs.aws.amazon.com/batch/latest/userguide/specifying-sensitive-data.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the secret.
-
#value_from ⇒ String
The secret to expose to the container.
Instance Attribute Details
#name ⇒ String
The name of the secret.
9155 9156 9157 9158 9159 9160 |
# File 'lib/aws-sdk-batch/types.rb', line 9155 class Secret < Struct.new( :name, :value_from) SENSITIVE = [] include Aws::Structure end |
#value_from ⇒ String
The secret to expose to the container. The supported values are either the full Amazon Resource Name (ARN) of the Secrets Manager secret or the full ARN of the parameter in the Amazon Web Services Systems Manager Parameter Store.
<note markdown=“1”> If the Amazon Web Services Systems Manager Parameter Store parameter exists in the same Region as the job you’re launching, then you can use either the full Amazon Resource Name (ARN) or name of the parameter. If the parameter exists in a different Region, then the full ARN must be specified.
</note>
9155 9156 9157 9158 9159 9160 |
# File 'lib/aws-sdk-batch/types.rb', line 9155 class Secret < Struct.new( :name, :value_from) SENSITIVE = [] include Aws::Structure end |