Class: Aws::Batch::Types::ServiceJobCapacityUsageSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The capacity usage for a service job, including the unit of measure and quantity of resources being used.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_unitString

The unit of measure for the service job capacity usage. For service jobs, this is the instance type.



8746
8747
8748
8749
8750
8751
# File 'lib/aws-sdk-batch/types.rb', line 8746

class ServiceJobCapacityUsageSummary < Struct.new(
  :capacity_unit,
  :quantity)
  SENSITIVE = []
  include Aws::Structure
end

#quantityFloat

The quantity of capacity being used by the service job, measured in the units specified by capacityUnit.



8746
8747
8748
8749
8750
8751
# File 'lib/aws-sdk-batch/types.rb', line 8746

class ServiceJobCapacityUsageSummary < Struct.new(
  :capacity_unit,
  :quantity)
  SENSITIVE = []
  include Aws::Structure
end