Class: Aws::Batch::Types::ServiceJobPreemptedAttempt

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Detailed information about a preempted attempt of a service job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#service_resource_idTypes::ServiceResourceId

The service resource identifier associated with the service job attempt.



9379
9380
9381
9382
9383
9384
9385
9386
# File 'lib/aws-sdk-batch/types.rb', line 9379

class ServiceJobPreemptedAttempt < Struct.new(
  :service_resource_id,
  :started_at,
  :stopped_at,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#started_atInteger

The Unix timestamp (in milliseconds) for when the service job attempt was started.



9379
9380
9381
9382
9383
9384
9385
9386
# File 'lib/aws-sdk-batch/types.rb', line 9379

class ServiceJobPreemptedAttempt < Struct.new(
  :service_resource_id,
  :started_at,
  :stopped_at,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

A string that provides additional details for the current status of the service job attempt.



9379
9380
9381
9382
9383
9384
9385
9386
# File 'lib/aws-sdk-batch/types.rb', line 9379

class ServiceJobPreemptedAttempt < Struct.new(
  :service_resource_id,
  :started_at,
  :stopped_at,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atInteger

The Unix timestamp (in milliseconds) for when the service job attempt stopped running.



9379
9380
9381
9382
9383
9384
9385
9386
# File 'lib/aws-sdk-batch/types.rb', line 9379

class ServiceJobPreemptedAttempt < Struct.new(
  :service_resource_id,
  :started_at,
  :stopped_at,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end