Class: Aws::Batch::Types::ServiceJobPreemptionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Summarizes the preemptions of the service job. This field appears on a service job when it has been preempted.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#preempted_attempt_countInteger

The total number of times the service job has been preempted.

Returns:

  • (Integer)


9418
9419
9420
9421
9422
9423
# File 'lib/aws-sdk-batch/types.rb', line 9418

class ServiceJobPreemptionSummary < Struct.new(
  :preempted_attempt_count,
  :recent_preempted_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#recent_preempted_attemptsArray<Types::ServiceJobPreemptedAttempt>

A list of the most recent preemption attempts for the service job.



9418
9419
9420
9421
9422
9423
# File 'lib/aws-sdk-batch/types.rb', line 9418

class ServiceJobPreemptionSummary < Struct.new(
  :preempted_attempt_count,
  :recent_preempted_attempts)
  SENSITIVE = []
  include Aws::Structure
end