Method: Aws::Batch::Types::SubmitJobRequest#array_properties

Defined in:
lib/aws-sdk-batch/types.rb

#array_propertiesTypes::ArrayProperties

The array properties for the submitted job, such as the size of the array. The array size can be between 2 and 10,000. If you specify array properties for a job, it becomes an array job. For more information, see [Array Jobs] in the *Batch User Guide*.

[1]: docs.aws.amazon.com/batch/latest/userguide/array_jobs.html



7066
7067
7068
7069
7070
7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
# File 'lib/aws-sdk-batch/types.rb', line 7066

class SubmitJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :share_identifier,
  :scheduling_priority_override,
  :array_properties,
  :depends_on,
  :job_definition,
  :parameters,
  :container_overrides,
  :node_overrides,
  :retry_strategy,
  :propagate_tags,
  :timeout,
  :tags,
  :eks_properties_override,
  :ecs_properties_override)
  SENSITIVE = []
  include Aws::Structure
end