Class: Aws::Batch::Types::TagResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Contains the parameters for ‘TagResource`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the resource that tags are added to. Batch resources that support tags are compute environments, jobs, job definitions, job queues, and scheduling policies. ARNs for child jobs of array and multi-node parallel (MNP) jobs aren’t supported.

Returns:

  • (String)


8945
8946
8947
8948
8949
8950
# File 'lib/aws-sdk-batch/types.rb', line 8945

class TagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags that you apply to the resource to help you categorize and organize your resources. Each tag consists of a key and an optional value. For more information, see [Tagging Amazon Web Services Resources] in *Amazon Web Services General Reference*.

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:

  • (Hash<String,String>)


8945
8946
8947
8948
8949
8950
# File 'lib/aws-sdk-batch/types.rb', line 8945

class TagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end