Class: Aws::Batch::Types::TaskContainerOverrides

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The overrides that should be sent to a container.

For information about using Batch overrides when you connect event sources to targets, see [BatchContainerOverrides].

[1]: docs.aws.amazon.com/eventbridge/latest/pipes-reference/API_BatchContainerOverrides.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commandArray<String>

The command to send to the container that overrides the default command from the Docker image or the job definition.

<note markdown=“1”> This parameter can’t contain an empty string.

</note>

Returns:

  • (Array<String>)


9718
9719
9720
9721
9722
9723
9724
9725
# File 'lib/aws-sdk-batch/types.rb', line 9718

class TaskContainerOverrides < Struct.new(
  :command,
  :environment,
  :name,
  :resource_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#environmentArray<Types::KeyValuePair>

The environment variables to send to the container. You can add new environment variables, which are added to the container at launch, or you can override the existing environment variables from the Docker image or the job definition.

<note markdown=“1”> Environment variables cannot start with AWS_BATCH. This naming convention is reserved for variables that Batch sets.

</note>

Returns:



9718
9719
9720
9721
9722
9723
9724
9725
# File 'lib/aws-sdk-batch/types.rb', line 9718

class TaskContainerOverrides < Struct.new(
  :command,
  :environment,
  :name,
  :resource_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A pointer to the container that you want to override. The container’s name provides a unique identifier for the container being used.

Returns:

  • (String)


9718
9719
9720
9721
9722
9723
9724
9725
# File 'lib/aws-sdk-batch/types.rb', line 9718

class TaskContainerOverrides < Struct.new(
  :command,
  :environment,
  :name,
  :resource_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#resource_requirementsArray<Types::ResourceRequirement>

The type and amount of resources to assign to a container. This overrides the settings in the job definition. The supported resources include GPU, MEMORY, and VCPU.

Returns:



9718
9719
9720
9721
9722
9723
9724
9725
# File 'lib/aws-sdk-batch/types.rb', line 9718

class TaskContainerOverrides < Struct.new(
  :command,
  :environment,
  :name,
  :resource_requirements)
  SENSITIVE = []
  include Aws::Structure
end