Class: Aws::Batch::Types::TerminateServiceJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::TerminateServiceJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The service job ID of the service job to terminate.
-
#reason ⇒ String
A message to attach to the service job that explains the reason for terminating it.
Instance Attribute Details
#job_id ⇒ String
The service job ID of the service job to terminate.
11578 11579 11580 11581 11582 11583 |
# File 'lib/aws-sdk-batch/types.rb', line 11578 class TerminateServiceJobRequest < Struct.new( :job_id, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A message to attach to the service job that explains the reason for
terminating it. This message is returned by DescribeServiceJob
operations on the service job.
11578 11579 11580 11581 11582 11583 |
# File 'lib/aws-sdk-batch/types.rb', line 11578 class TerminateServiceJobRequest < Struct.new( :job_id, :reason) SENSITIVE = [] include Aws::Structure end |