Class: Aws::Batch::Types::TerminateServiceJobsErrorDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

An object that contains the details of a service job that couldn't be terminated by a TerminateServiceJobs operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

An error code that identifies the reason the service job couldn't be terminated. Valid values are:

  • ValidationException – A service job identifier in the request is malformed or isn't valid.

  • ClientException – The request failed because of a client error.

  • ThrottlingException – The request was throttled. Retry the request.

  • ServerException – An internal error occurred. Retry the request.

  • AccessDenied – The caller isn't authorized to perform the action on the specified service job.

Returns:

  • (String)


11621
11622
11623
11624
11625
11626
11627
# File 'lib/aws-sdk-batch/types.rb', line 11621

class TerminateServiceJobsErrorDetail < Struct.new(
  :job,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#jobString

The service job ID of the service job that couldn't be terminated.

Returns:

  • (String)


11621
11622
11623
11624
11625
11626
11627
# File 'lib/aws-sdk-batch/types.rb', line 11621

class TerminateServiceJobsErrorDetail < Struct.new(
  :job,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message that describes the reason the service job couldn't be terminated.

Returns:

  • (String)


11621
11622
11623
11624
11625
11626
11627
# File 'lib/aws-sdk-batch/types.rb', line 11621

class TerminateServiceJobsErrorDetail < Struct.new(
  :job,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end