Class: Aws::Batch::Types::UpdateQuotaShareRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::UpdateQuotaShareRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_limits ⇒ Array<Types::QuotaShareCapacityLimit>
A list that specifies the quantity and type of compute capacity allocated to the quota share.
-
#preemption_configuration ⇒ Types::QuotaSharePreemptionConfiguration
Specifies the preemption behavior for jobs in a quota share.
-
#quota_share_arn ⇒ String
The Amazon Resource Name (ARN) of the quota share to update.
-
#resource_sharing_configuration ⇒ Types::QuotaShareResourceSharingConfiguration
Specifies whether a quota share reserves, lends, or both lends and borrows idle compute capacity.
-
#state ⇒ String
The state of the quota share.
Instance Attribute Details
#capacity_limits ⇒ Array<Types::QuotaShareCapacityLimit>
A list that specifies the quantity and type of compute capacity allocated to the quota share.
11240 11241 11242 11243 11244 11245 11246 11247 11248 |
# File 'lib/aws-sdk-batch/types.rb', line 11240 class UpdateQuotaShareRequest < Struct.new( :quota_share_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state) SENSITIVE = [] include Aws::Structure end |
#preemption_configuration ⇒ Types::QuotaSharePreemptionConfiguration
Specifies the preemption behavior for jobs in a quota share.
11240 11241 11242 11243 11244 11245 11246 11247 11248 |
# File 'lib/aws-sdk-batch/types.rb', line 11240 class UpdateQuotaShareRequest < Struct.new( :quota_share_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state) SENSITIVE = [] include Aws::Structure end |
#quota_share_arn ⇒ String
The Amazon Resource Name (ARN) of the quota share to update.
11240 11241 11242 11243 11244 11245 11246 11247 11248 |
# File 'lib/aws-sdk-batch/types.rb', line 11240 class UpdateQuotaShareRequest < Struct.new( :quota_share_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state) SENSITIVE = [] include Aws::Structure end |
#resource_sharing_configuration ⇒ Types::QuotaShareResourceSharingConfiguration
Specifies whether a quota share reserves, lends, or both lends and borrows idle compute capacity.
11240 11241 11242 11243 11244 11245 11246 11247 11248 |
# File 'lib/aws-sdk-batch/types.rb', line 11240 class UpdateQuotaShareRequest < Struct.new( :quota_share_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the quota share. If the quota share is ENABLED, it is able to accept jobs. If the quota share is DISABLED, new jobs won’t be accepted but jobs already submitted can finish.
11240 11241 11242 11243 11244 11245 11246 11247 11248 |
# File 'lib/aws-sdk-batch/types.rb', line 11240 class UpdateQuotaShareRequest < Struct.new( :quota_share_arn, :capacity_limits, :resource_sharing_configuration, :preemption_configuration, :state) SENSITIVE = [] include Aws::Structure end |