Class: Aws::Batch::Types::Volume
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::Volume
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
A data volume that’s used in a job’s container properties.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#efs_volume_configuration ⇒ Types::EFSVolumeConfiguration
This parameter is specified when you’re using an Amazon Elastic File System file system for job storage.
-
#host ⇒ Types::Host
The contents of the
hostparameter determine whether your data volume persists on the host container instance and where it’s stored. -
#name ⇒ String
The name of the volume.
Instance Attribute Details
#efs_volume_configuration ⇒ Types::EFSVolumeConfiguration
This parameter is specified when you’re using an Amazon Elastic File System file system for job storage. Jobs that are running on Fargate resources must specify a platformVersion of at least 1.4.0.
11418 11419 11420 11421 11422 11423 11424 |
# File 'lib/aws-sdk-batch/types.rb', line 11418 class Volume < Struct.new( :host, :name, :efs_volume_configuration) SENSITIVE = [] include Aws::Structure end |
#host ⇒ Types::Host
The contents of the host parameter determine whether your data volume persists on the host container instance and where it’s stored. If the host parameter is empty, then the Docker daemon assigns a host path for your data volume. However, the data isn’t guaranteed to persist after the containers that are associated with it stop running.
<note markdown=“1”> This parameter isn’t applicable to jobs that are running on Fargate resources and shouldn’t be provided.
</note>
11418 11419 11420 11421 11422 11423 11424 |
# File 'lib/aws-sdk-batch/types.rb', line 11418 class Volume < Struct.new( :host, :name, :efs_volume_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the volume. It can be up to 255 characters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), and underscores (_). This name is referenced in the sourceVolume parameter of container definition mountPoints.
11418 11419 11420 11421 11422 11423 11424 |
# File 'lib/aws-sdk-batch/types.rb', line 11418 class Volume < Struct.new( :host, :name, :efs_volume_configuration) SENSITIVE = [] include Aws::Structure end |