Method: Aws::Batch::Types::JobQueueDetail#priority
- Defined in:
- lib/aws-sdk-batch/types.rb
#priority ⇒ Integer
The priority of the job queue. Job queue priority determines the order that job queues are evaluated when multiple queues dispatch jobs within a shared compute environment. A higher value for priority indicates a higher priority. Queues are evaluated in cycles, in descending order by priority. For example, a job queue with a priority value of 10 is evaluated before a queue with a priority value of 1. All of the compute environments must be either Amazon EC2 (EC2 or SPOT) or Fargate (FARGATE or FARGATE_SPOT). Amazon EC2 and Fargate compute environments can’t be mixed.
<note markdown=“1”> Job queue priority doesn’t guarantee that a particular job executes before a job in a lower priority queue. Jobs added to higher priority queues during the queue evaluation cycle might not be evaluated until the next cycle. A job is dispatched from a queue only if resources are available when the queue is evaluated. If there are insufficient resources available at that time, the cycle proceeds to the next queue. This means that jobs added to higher priority queues might have to wait for jobs in multiple lower priority queues to complete before they are dispatched. You can use job dependencies to control the order for jobs from queues with different priorities. For more information, see [Job Dependencies] in the *Batch User Guide*.
</note>
[1]: docs.aws.amazon.com/batch/latest/userguide/job_dependencies.html
6246 6247 6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 |
# File 'lib/aws-sdk-batch/types.rb', line 6246 class JobQueueDetail < Struct.new( :job_queue_name, :job_queue_arn, :state, :scheduling_policy_arn, :status, :status_reason, :priority, :compute_environment_order, :service_environment_order, :job_queue_type, :tags, :job_state_time_limit_actions) SENSITIVE = [] include Aws::Structure end |