Class: Aws::Batch::Types::CancelJobsErrorDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::CancelJobsErrorDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that contains the details of a job that couldn't be
cancelled by a CancelJobs operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
An error code that identifies the reason the job couldn't be cancelled.
-
#job ⇒ String
The Batch job ID of the job that couldn't be cancelled.
-
#message ⇒ String
A message that describes the reason the job couldn't be cancelled.
Instance Attribute Details
#code ⇒ String
An error code that identifies the reason the job couldn't be cancelled. Valid values are:
-
ValidationException– A job identifier in the request is malformed or isn't valid. -
ClientException– The request failed because of a client error. -
ThrottlingException– The request was throttled. Retry the request. -
ServerException– An internal error occurred. Retry the request. -
AccessDenied– The caller isn't authorized to perform the action on the specified job.
305 306 307 308 309 310 311 |
# File 'lib/aws-sdk-batch/types.rb', line 305 class CancelJobsErrorDetail < Struct.new( :job, :code, :message) SENSITIVE = [] include Aws::Structure end |
#job ⇒ String
The Batch job ID of the job that couldn't be cancelled.
305 306 307 308 309 310 311 |
# File 'lib/aws-sdk-batch/types.rb', line 305 class CancelJobsErrorDetail < Struct.new( :job, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message that describes the reason the job couldn't be cancelled.
305 306 307 308 309 310 311 |
# File 'lib/aws-sdk-batch/types.rb', line 305 class CancelJobsErrorDetail < Struct.new( :job, :code, :message) SENSITIVE = [] include Aws::Structure end |