Method: Aws::Batch::Types::ComputeResource#image_id
- Defined in:
- lib/aws-sdk-batch/types.rb
#image_id ⇒ String
The Amazon Machine Image (AMI) ID used for instances launched in the compute environment. This parameter is overridden by the imageIdOverride member of the Ec2Configuration structure.
<note markdown=“1”> This parameter isn’t applicable to jobs that are running on Fargate resources. Don’t specify it.
</note>
<note markdown=“1”> The AMI that you choose for a compute environment must match the architecture of the instance types that you intend to use for that compute environment. For example, if your compute environment uses A1 instance types, the compute resource AMI that you choose must support ARM instances. Amazon ECS vends both x86 and ARM versions of the Amazon ECS-optimized Amazon Linux 2 AMI. For more information, see [Amazon ECS-optimized Amazon Linux 2 AMI] in the *Amazon Elastic Container Service Developer Guide*.
</note>
920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 |
# File 'lib/aws-sdk-batch/types.rb', line 920 class ComputeResource < Struct.new( :type, :allocation_strategy, :minv_cpus, :maxv_cpus, :desiredv_cpus, :instance_types, :image_id, :subnets, :security_group_ids, :ec2_key_pair, :instance_role, :tags, :placement_group, :bid_percentage, :spot_iam_fleet_role, :launch_template, :ec2_configuration) SENSITIVE = [] include Aws::Structure end |