Method: Aws::Batch::Types::ComputeResourceUpdate#type
- Defined in:
- lib/aws-sdk-batch/types.rb
#type ⇒ String
The type of compute environment: EC2, SPOT, FARGATE, or FARGATE_SPOT. For more information, see [Compute environments] in the *Batch User Guide*.
If you choose SPOT, you must also specify an Amazon EC2 Spot Fleet role with the spotIamFleetRole parameter. For more information, see [Amazon EC2 spot fleet role] in the *Batch User Guide*.
When updating a compute environment, changing the type of a compute environment requires an infrastructure update of the compute environment. For more information, see [Updating compute environments] in the *Batch User Guide*.
[1]: docs.aws.amazon.com/batch/latest/userguide/compute_environments.html [2]: docs.aws.amazon.com/batch/latest/userguide/spot_fleet_IAM_role.html [3]: docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html
1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 |
# File 'lib/aws-sdk-batch/types.rb', line 1442 class ComputeResourceUpdate < Struct.new( :minv_cpus, :maxv_cpus, :desiredv_cpus, :subnets, :security_group_ids, :allocation_strategy, :instance_types, :ec2_key_pair, :instance_role, :tags, :placement_group, :bid_percentage, :launch_template, :ec2_configuration, :update_to_latest_image_version, :type, :image_id) SENSITIVE = [] include Aws::Structure end |