Class: Aws::Batch::Types::ComputeScalingPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ComputeScalingPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that represents a scaling policy for a compute environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#min_scale_down_delay_minutes ⇒ Integer
The minimum time (in minutes) that Batch keeps instances running in the compute environment after their jobs complete.
Instance Attribute Details
#min_scale_down_delay_minutes ⇒ Integer
The minimum time (in minutes) that Batch keeps instances running in the compute environment after their jobs complete. For each instance, the delay period begins when the last job finishes. If no new jobs are placed on the instance during this delay, Batch terminates the instance once the delay expires.
Valid Range: Minimum value of 20. Maximum value of 10080. Use 0 to unset and disable the scale down delay.
<note markdown=“1”> The scale down delay does not apply to:
* Instances being replaced during infrastructure updates
-
Newly launched instances that have not yet run any jobs
-
Spot instances reclaimed due to interruption
</note>
1524 1525 1526 1527 1528 |
# File 'lib/aws-sdk-batch/types.rb', line 1524 class ComputeScalingPolicy < Struct.new( :min_scale_down_delay_minutes) SENSITIVE = [] include Aws::Structure end |