Class: Aws::Batch::Types::CreateQuotaShareRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_limitsArray<Types::QuotaShareCapacityLimit>

A list that specifies the quantity and type of compute capacity allocated to the quota share.

Returns:



2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-batch/types.rb', line 2786

class CreateQuotaShareRequest < Struct.new(
  :quota_share_name,
  :job_queue,
  :capacity_limits,
  :resource_sharing_configuration,
  :preemption_configuration,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#job_queueString

The Batch job queue associated with the quota share. This can be the job queue name or ARN. A job queue must be in the ‘VALID` state before you can associate it with a quota share.

Returns:

  • (String)


2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-batch/types.rb', line 2786

class CreateQuotaShareRequest < Struct.new(
  :quota_share_name,
  :job_queue,
  :capacity_limits,
  :resource_sharing_configuration,
  :preemption_configuration,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#preemption_configurationTypes::QuotaSharePreemptionConfiguration

Specifies the preemption behavior for jobs in a quota share.



2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-batch/types.rb', line 2786

class CreateQuotaShareRequest < Struct.new(
  :quota_share_name,
  :job_queue,
  :capacity_limits,
  :resource_sharing_configuration,
  :preemption_configuration,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#quota_share_nameString

The name of the quota share. It can be up to 128 characters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), and underscores (_).

Returns:

  • (String)


2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-batch/types.rb', line 2786

class CreateQuotaShareRequest < Struct.new(
  :quota_share_name,
  :job_queue,
  :capacity_limits,
  :resource_sharing_configuration,
  :preemption_configuration,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_sharing_configurationTypes::QuotaShareResourceSharingConfiguration

Specifies whether a quota share reserves, lends, or both lends and borrows idle compute capacity.



2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-batch/types.rb', line 2786

class CreateQuotaShareRequest < Struct.new(
  :quota_share_name,
  :job_queue,
  :capacity_limits,
  :resource_sharing_configuration,
  :preemption_configuration,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the quota share. If the quota share is ‘ENABLED`, it is able to accept jobs. If the quota share is `DISABLED`, new jobs won’t be accepted but jobs already submitted can finish. The default state is ‘ENABLED`.

Returns:

  • (String)


2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-batch/types.rb', line 2786

class CreateQuotaShareRequest < Struct.new(
  :quota_share_name,
  :job_queue,
  :capacity_limits,
  :resource_sharing_configuration,
  :preemption_configuration,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags that you apply to the quota share to help you categorize and organize your resources. Each tag consists of a key and an optional value. For more information, see [Tagging your Batch resources] in *Batch User Guide*.

[1]: docs.aws.amazon.com/batch/latest/userguide/using-tags.html

Returns:

  • (Hash<String,String>)


2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-batch/types.rb', line 2786

class CreateQuotaShareRequest < Struct.new(
  :quota_share_name,
  :job_queue,
  :capacity_limits,
  :resource_sharing_configuration,
  :preemption_configuration,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end