Class: Aws::Batch::Types::DescribeServiceEnvironmentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::DescribeServiceEnvironmentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureDescribeServiceEnvironmentsrequest. -
#service_environments ⇒ Array<Types::ServiceEnvironmentDetail>
The list of service environments that match the request.
Instance Attribute Details
#next_token ⇒ String
The nextToken value to include in a future
DescribeServiceEnvironments request. When the results of a
DescribeServiceEnvironments request exceed maxResults, this
value can be used to retrieve the next page of results. This value
is null when there are no more results to return.
3710 3711 3712 3713 3714 3715 |
# File 'lib/aws-sdk-batch/types.rb', line 3710 class DescribeServiceEnvironmentsResponse < Struct.new( :service_environments, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_environments ⇒ Array<Types::ServiceEnvironmentDetail>
The list of service environments that match the request.
3710 3711 3712 3713 3714 3715 |
# File 'lib/aws-sdk-batch/types.rb', line 3710 class DescribeServiceEnvironmentsResponse < Struct.new( :service_environments, :next_token) SENSITIVE = [] include Aws::Structure end |