Class: Aws::Batch::Types::DescribeServiceJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::DescribeServiceJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attempts ⇒ Array<Types::ServiceJobAttemptDetail>
A list of job attempts associated with the service job.
-
#capacity_usage ⇒ Array<Types::ServiceJobCapacityUsageDetail>
The configured capacity for the service job, such as the number of instances.
-
#created_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was created.
-
#is_terminated ⇒ Boolean
Indicates whether the service job has been terminated.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the service job.
-
#job_id ⇒ String
The job ID for the service job.
-
#job_name ⇒ String
The name of the service job.
-
#job_queue ⇒ String
The ARN of the job queue that the service job is associated with.
-
#latest_attempt ⇒ Types::LatestServiceJobAttempt
The latest attempt associated with the service job.
-
#preemption_configuration ⇒ Types::ServiceJobPreemptionConfiguration
Specifies the service job behavior when preempted.
-
#preemption_summary ⇒ Types::ServiceJobPreemptionSummary
Summarizes the preemptions of the service job.
-
#quota_share_name ⇒ String
The name of the quota share that the service job is associated with.
-
#retry_strategy ⇒ Types::ServiceJobRetryStrategy
The retry strategy to use for failed service jobs that are submitted with this service job.
-
#scheduled_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was scheduled.
-
#scheduling_priority ⇒ Integer
The scheduling priority of the service job.
-
#service_job_type ⇒ String
The type of service job.
-
#service_request_payload ⇒ String
The request, in JSON, for the service that the
SubmitServiceJoboperation is queueing. -
#share_identifier ⇒ String
The share identifier for the service job.
-
#started_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was started.
-
#status ⇒ String
The current status of the service job.
-
#status_reason ⇒ String
A short, human-readable string to provide more details for the current status of the service job.
-
#stopped_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job stopped running.
-
#tags ⇒ Hash<String,String>
The tags that are associated with the service job.
-
#timeout_config ⇒ Types::ServiceJobTimeout
The timeout configuration for the service job.
Instance Attribute Details
#attempts ⇒ Array<Types::ServiceJobAttemptDetail>
A list of job attempts associated with the service job.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#capacity_usage ⇒ Array<Types::ServiceJobCapacityUsageDetail>
The configured capacity for the service job, such as the number of
instances. The number of instances should be the same value as the
serviceRequestPayload.InstanceCount field.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was created.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#is_terminated ⇒ Boolean
Indicates whether the service job has been terminated.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the service job.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID for the service job.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the service job.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#job_queue ⇒ String
The ARN of the job queue that the service job is associated with.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#latest_attempt ⇒ Types::LatestServiceJobAttempt
The latest attempt associated with the service job.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#preemption_configuration ⇒ Types::ServiceJobPreemptionConfiguration
Specifies the service job behavior when preempted.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#preemption_summary ⇒ Types::ServiceJobPreemptionSummary
Summarizes the preemptions of the service job. This field appears on a service job when it has been preempted.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#quota_share_name ⇒ String
The name of the quota share that the service job is associated with.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#retry_strategy ⇒ Types::ServiceJobRetryStrategy
The retry strategy to use for failed service jobs that are submitted with this service job.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#scheduled_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was
scheduled. This represents when the service job was dispatched to
SageMaker and the service job transitioned to the SCHEDULED state.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#scheduling_priority ⇒ Integer
The scheduling priority of the service job.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#service_job_type ⇒ String
The type of service job. For SageMaker Training jobs, this value is
SAGEMAKER_TRAINING.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#service_request_payload ⇒ String
The request, in JSON, for the service that the SubmitServiceJob
operation is queueing.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#share_identifier ⇒ String
The share identifier for the service job. This is used for fair-share scheduling.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was started.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the service job.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A short, human-readable string to provide more details for the current status of the service job.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job stopped running.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags that are associated with the service job. Each tag consists of a key and an optional value. For more information, see Tagging your Batch resources.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#timeout_config ⇒ Types::ServiceJobTimeout
The timeout configuration for the service job.
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-batch/types.rb', line 3846 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :preemption_summary, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |