Class: Aws::Batch::Types::DescribeServiceJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attemptsArray<Types::ServiceJobAttemptDetail>

A list of job attempts associated with the service job.

Returns:



3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_usageArray<Types::ServiceJobCapacityUsageDetail>

The configured capacity for the service job, such as the number of instances. The number of instances should be the same value as the ‘serviceRequestPayload.InstanceCount` field.



3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#created_atInteger

The Unix timestamp (in milliseconds) for when the service job was created.

Returns:

  • (Integer)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#is_terminatedBoolean

Indicates whether the service job has been terminated.

Returns:

  • (Boolean)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The Amazon Resource Name (ARN) of the service job.

Returns:

  • (String)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID for the service job.

Returns:

  • (String)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the service job.

Returns:

  • (String)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#job_queueString

The ARN of the job queue that the service job is associated with.

Returns:

  • (String)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#latest_attemptTypes::LatestServiceJobAttempt

The latest attempt associated with the service job.



3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#preemption_configurationTypes::ServiceJobPreemptionConfiguration

Specifies the service job behavior when preempted.



3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#preemption_summaryTypes::ServiceJobPreemptionSummary

Summarizes the preemptions of the service job. This field appears on a service job when it has been preempted.



3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#quota_share_nameString

The name of the quota share that the service job is associated with.

Returns:

  • (String)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#retry_strategyTypes::ServiceJobRetryStrategy

The retry strategy to use for failed service jobs that are submitted with this service job.



3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_atInteger

The Unix timestamp (in milliseconds) for when the service job was scheduled. This represents when the service job was dispatched to SageMaker and the service job transitioned to the ‘SCHEDULED` state.

Returns:

  • (Integer)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#scheduling_priorityInteger

The scheduling priority of the service job.

Returns:

  • (Integer)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#service_job_typeString

The type of service job. For SageMaker Training jobs, this value is ‘SAGEMAKER_TRAINING`.

Returns:

  • (String)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#service_request_payloadString

The request, in JSON, for the service that the ‘SubmitServiceJob` operation is queueing.

Returns:

  • (String)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#share_identifierString

The share identifier for the service job. This is used for fair-share scheduling.

Returns:

  • (String)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#started_atInteger

The Unix timestamp (in milliseconds) for when the service job was started.

Returns:

  • (Integer)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the service job.

Returns:

  • (String)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

A short, human-readable string to provide more details for the current status of the service job.

Returns:

  • (String)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atInteger

The Unix timestamp (in milliseconds) for when the service job stopped running.

Returns:

  • (Integer)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags that are associated with the service job. Each tag consists of a key and an optional value. For more information, see [Tagging your Batch resources].

[1]: docs.aws.amazon.com/batch/latest/userguide/using-tags.html

Returns:

  • (Hash<String,String>)


3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_configTypes::ServiceJobTimeout

The timeout configuration for the service job.



3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-batch/types.rb', line 3748

class DescribeServiceJobResponse < Struct.new(
  :attempts,
  :capacity_usage,
  :created_at,
  :is_terminated,
  :job_arn,
  :job_id,
  :job_name,
  :job_queue,
  :latest_attempt,
  :retry_strategy,
  :scheduled_at,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :preemption_summary,
  :started_at,
  :status,
  :status_reason,
  :stopped_at,
  :tags,
  :timeout_config)
  SENSITIVE = []
  include Aws::Structure
end