Class: Aws::Batch::Types::DescribeServiceJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::DescribeServiceJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attempts ⇒ Array<Types::ServiceJobAttemptDetail>
A list of job attempts associated with the service job.
-
#capacity_usage ⇒ Array<Types::ServiceJobCapacityUsageDetail>
The configured capacity for the service job, such as the number of instances.
-
#created_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was created.
-
#is_terminated ⇒ Boolean
Indicates whether the service job has been terminated.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the service job.
-
#job_id ⇒ String
The job ID for the service job.
-
#job_name ⇒ String
The name of the service job.
-
#job_queue ⇒ String
The ARN of the job queue that the service job is associated with.
-
#latest_attempt ⇒ Types::LatestServiceJobAttempt
The latest attempt associated with the service job.
-
#retry_strategy ⇒ Types::ServiceJobRetryStrategy
The retry strategy to use for failed service jobs that are submitted with this service job.
-
#scheduled_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was scheduled.
-
#scheduling_priority ⇒ Integer
The scheduling priority of the service job.
-
#service_job_type ⇒ String
The type of service job.
-
#service_request_payload ⇒ String
The request, in JSON, for the service that the
SubmitServiceJoboperation is queueing. -
#share_identifier ⇒ String
The share identifier for the service job.
-
#started_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was started.
-
#status ⇒ String
The current status of the service job.
-
#status_reason ⇒ String
A short, human-readable string to provide more details for the current status of the service job.
-
#stopped_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job stopped running.
-
#tags ⇒ Hash<String,String>
The tags that are associated with the service job.
-
#timeout_config ⇒ Types::ServiceJobTimeout
The timeout configuration for the service job.
Instance Attribute Details
#attempts ⇒ Array<Types::ServiceJobAttemptDetail>
A list of job attempts associated with the service job.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#capacity_usage ⇒ Array<Types::ServiceJobCapacityUsageDetail>
The configured capacity for the service job, such as the number of instances. The number of instances should be the same value as the serviceRequestPayload.InstanceCount field.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was created.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#is_terminated ⇒ Boolean
Indicates whether the service job has been terminated.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the service job.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID for the service job.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the service job.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#job_queue ⇒ String
The ARN of the job queue that the service job is associated with.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#latest_attempt ⇒ Types::LatestServiceJobAttempt
The latest attempt associated with the service job.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#retry_strategy ⇒ Types::ServiceJobRetryStrategy
The retry strategy to use for failed service jobs that are submitted with this service job.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#scheduled_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was scheduled. This represents when the service job was dispatched to SageMaker and the service job transitioned to the SCHEDULED state.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#scheduling_priority ⇒ Integer
The scheduling priority of the service job.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#service_job_type ⇒ String
The type of service job. For SageMaker Training jobs, this value is SAGEMAKER_TRAINING.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#service_request_payload ⇒ String
The request, in JSON, for the service that the SubmitServiceJob operation is queueing.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#share_identifier ⇒ String
The share identifier for the service job. This is used for fair-share scheduling.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was started.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the service job.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A short, human-readable string to provide more details for the current status of the service job.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job stopped running.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags that are associated with the service job. Each tag consists of a key and an optional value. For more information, see [Tagging your Batch resources].
[1]: docs.aws.amazon.com/batch/latest/userguide/using-tags.html
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |
#timeout_config ⇒ Types::ServiceJobTimeout
The timeout configuration for the service job.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 |
# File 'lib/aws-sdk-batch/types.rb', line 3464 class DescribeServiceJobResponse < Struct.new( :attempts, :capacity_usage, :created_at, :is_terminated, :job_arn, :job_id, :job_name, :job_queue, :latest_attempt, :retry_strategy, :scheduled_at, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :started_at, :status, :status_reason, :stopped_at, :tags, :timeout_config) SENSITIVE = [] include Aws::Structure end |