Class: Aws::Batch::Types::EFSAuthorizationConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::EFSAuthorizationConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The authorization configuration details for the Amazon EFS file system.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_point_id ⇒ String
The Amazon EFS access point ID to use.
-
#iam ⇒ String
Whether or not to use the Batch job IAM role defined in a job definition when mounting the Amazon EFS file system.
Instance Attribute Details
#access_point_id ⇒ String
The Amazon EFS access point ID to use. If an access point is
specified, the root directory value specified in the
EFSVolumeConfiguration must either be omitted or set to / which
enforces the path set on the EFS access point. If an access point is
used, transit encryption must be enabled in the
EFSVolumeConfiguration. For more information, see Working with
Amazon EFS access points in the Amazon Elastic File System User
Guide.
3857 3858 3859 3860 3861 3862 |
# File 'lib/aws-sdk-batch/types.rb', line 3857 class EFSAuthorizationConfig < Struct.new( :access_point_id, :iam) SENSITIVE = [] include Aws::Structure end |
#iam ⇒ String
Whether or not to use the Batch job IAM role defined in a job
definition when mounting the Amazon EFS file system. If enabled,
transit encryption must be enabled in the EFSVolumeConfiguration.
If this parameter is omitted, the default value of DISABLED is
used. For more information, see Using Amazon EFS access points
in the Batch User Guide. EFS IAM authorization requires that
TransitEncryption be ENABLED and that a JobRoleArn is
specified.
3857 3858 3859 3860 3861 3862 |
# File 'lib/aws-sdk-batch/types.rb', line 3857 class EFSAuthorizationConfig < Struct.new( :access_point_id, :iam) SENSITIVE = [] include Aws::Structure end |