Class: Aws::Batch::Types::Ec2Configuration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::Ec2Configuration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Provides information used to select Amazon Machine Images (AMIs) for
instances in the compute environment. If Ec2Configuration isn't
specified, the default is ECS_AL2023 (Amazon ECS-optimized Amazon
Linux 2023) for EC2 (ECS) compute environments and EKS_AL2023
(Amazon EKS-optimized Amazon Linux 2023 AMI) for EKS compute
environments.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_image_status ⇒ String
The status of the Batch-provided default AMIs associated with the
imageType. -
#image_id_override ⇒ String
The AMI ID used for instances launched in the compute environment that match the image type.
-
#image_kubernetes_version ⇒ String
The Kubernetes version for the compute environment.
-
#image_type ⇒ String
The image type to match with the instance type to select an AMI.
Instance Attribute Details
#batch_image_status ⇒ String
The status of the Batch-provided default AMIs associated with the
imageType.
The field only appears after the compute environment has begun
scaling instances using the imageType. The field is not present
when an image is specified in ComputeResources.imageId
(deprecated), the default launch template, or
Ec2Configuration.imageIdOverride. The field is also not present
when the compute environment has a launch template override. For
more information on image selection, see AMI selection order.
-
LATEST− Using the most recent AMI supported -
UPDATE_AVAILABLE− An updated AMI is available -
If a compute environment has multiple AMIs for the
imageTypeand any one AMI hasUPDATE_AVAILABLE, the status showsUPDATE_AVAILABLE. -
For compute environments that use
BEST_FITas their allocation strategy, you can perform a blue/green update to update the AMI. -
For all other compute environments, you can perform an AMI version update to update the AMI to the latest version.
4110 4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/aws-sdk-batch/types.rb', line 4110 class Ec2Configuration < Struct.new( :image_type, :image_id_override, :batch_image_status, :image_kubernetes_version) SENSITIVE = [] include Aws::Structure end |
#image_id_override ⇒ String
The AMI ID used for instances launched in the compute environment
that match the image type. This setting overrides the imageId set
in the computeResource object.
4110 4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/aws-sdk-batch/types.rb', line 4110 class Ec2Configuration < Struct.new( :image_type, :image_id_override, :batch_image_status, :image_kubernetes_version) SENSITIVE = [] include Aws::Structure end |
#image_kubernetes_version ⇒ String
The Kubernetes version for the compute environment. If you don't specify a value, the latest version that Batch supports is used.
4110 4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/aws-sdk-batch/types.rb', line 4110 class Ec2Configuration < Struct.new( :image_type, :image_id_override, :batch_image_status, :image_kubernetes_version) SENSITIVE = [] include Aws::Structure end |
#image_type ⇒ String
The image type to match with the instance type to select an AMI. The
supported values are different for ECS and EKS resources.
ECS
: If the imageIdOverride parameter isn't specified, then a recent
Amazon ECS-optimized Amazon Linux 2023 AMI (ECS_AL2023) is
used. If a new image type is specified in an update, but neither
an imageId nor a imageIdOverride parameter is specified, then
the latest Amazon ECS optimized AMI for that image type that's
supported by Batch is used.
Amazon Web Services is ending support for Amazon ECS Amazon Linux
2-optimized and accelerated AMIs on June 30, 2026. On January 12,
2026, Batch changed the default AMI for new Amazon ECS compute
environments from Amazon Linux 2 to Amazon Linux 2023. Effective
June 30, 2026, Batch will block creation of new Amazon ECS compute
environments using Batch-provided Amazon Linux 2 AMIs. We strongly
recommend migrating your existing Batch Amazon ECS compute
environments to Amazon Linux 2023 prior to June 30, 2026. For more
information on upgrading from AL2 to AL2023, see [How to migrate
from ECS AL2 to ECS AL2023][2] in the *Batch User Guide*.
ECS\_AL2
: [Amazon Linux 2][1]: Used for non-GPU instance families.
ECS\_AL2\_NVIDIA
: [Amazon Linux 2 (GPU)][3]: Used for GPU instance families (for
example `P4` and `G4`) and non Amazon Web Services
Graviton-based instance types.
ECS\_AL2023
: [Amazon Linux 2023][1]: Default for all non-GPU instance
families.
<note markdown="1"> Amazon Linux 2023 does not support `A1` instances.
</note>
ECS\_AL2023\_NVIDIA
: [Amazon Linux 2023 (GPU)][3]: Default for all GPU instance
families and can be used for all non Amazon Web Services
Graviton-based instance types.
<note markdown="1"> ECS\_AL2023\_NVIDIA doesn't support `p3` and `g3` instance
types.
</note>
EKS
: If the imageIdOverride parameter isn't specified, then a recent
Amazon EKS-optimized Amazon Linux 2023 AMI (EKS_AL2023) is
used. If a new image type is specified in an update, but neither
an imageId nor a imageIdOverride parameter is specified, then
the latest Amazon EKS optimized AMI for that image type that Batch
supports is used.
Amazon Linux 2023 AMIs are the default on Batch for Amazon EKS.
Amazon Web Services ended support for Amazon EKS AL2-optimized
and
AL2-accelerated AMIs on November 26, 2025. Batch Amazon EKS
compute environments using Amazon Linux 2 will no longer receive
software updates, security patches, or bug fixes from Amazon Web
Services. We recommend migrating to Amazon Linux 2023. For more
information on upgrading from AL2 to AL2023, see [How to upgrade
from EKS AL2 to EKS AL2023][5] in the *Batch User Guide*.
EKS\_AL2
: [Amazon Linux 2][4]: Used for non-GPU instance families.
EKS\_AL2\_NVIDIA
: [Amazon Linux 2 (accelerated)][4]: Used for GPU instance
families (for example, `P4` and `G4`) and can be used for all
non Amazon Web Services Graviton-based instance types.
EKS\_AL2023
: [Amazon Linux 2023][4]: Default for non-GPU instance families.
<note markdown="1"> Amazon Linux 2023 does not support `A1` instances.
</note>
EKS\_AL2023\_NVIDIA
: [Amazon Linux 2023 (accelerated)][4]: Default for GPU instance
families and can be used for all non Amazon Web Services
Graviton-based instance types.
4110 4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/aws-sdk-batch/types.rb', line 4110 class Ec2Configuration < Struct.new( :image_type, :image_id_override, :batch_image_status, :image_kubernetes_version) SENSITIVE = [] include Aws::Structure end |