Class: Aws::Batch::Types::Ec2Configuration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::Ec2Configuration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Provides information used to select Amazon Machine Images (AMIs) for instances in the compute environment. If ‘Ec2Configuration` isn’t specified, the default is ‘ECS_AL2023` ([Amazon ECS-optimized Amazon Linux 2023]) for EC2 (ECS) compute environments and `EKS_AL2023` ([Amazon EKS-optimized Amazon Linux 2023 AMI]) for EKS compute environments.
<note markdown=“1”> This object isn’t applicable to jobs that are running on Fargate resources.
</note>
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html [2]: docs.aws.amazon.com/eks/latest/userguide/eks-optimized-ami.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_image_status ⇒ String
The status of the Batch-provided default AMIs associated with the ‘imageType`.
-
#image_id_override ⇒ String
The AMI ID used for instances launched in the compute environment that match the image type.
-
#image_kubernetes_version ⇒ String
The Kubernetes version for the compute environment.
-
#image_type ⇒ String
The image type to match with the instance type to select an AMI.
Instance Attribute Details
#batch_image_status ⇒ String
The status of the Batch-provided default AMIs associated with the ‘imageType`.
The field only appears after the compute environment has begun scaling instances using the ‘imageType`. The field is not present when an image is specified in `ComputeResources.imageId` (deprecated), the default launch template, or `Ec2Configuration.imageIdOverride`. The field is also not present when the compute environment has a launch template override. For more information on image selection, see [AMI selection order].
<note markdown=“1”> This field is read-only and only appears in the
- DescribeComputeEnvironments][2
-
response.
</note>
-
‘LATEST` − Using the most recent AMI supported
-
‘UPDATE_AVAILABLE` − An updated AMI is available
-
If a compute environment has multiple AMIs for the ‘imageType` and any one AMI has `UPDATE_AVAILABLE`, the status shows `UPDATE_AVAILABLE`.
-
For compute environments that use ‘BEST_FIT` as their allocation strategy, you can perform a [blue/green update] to update the AMI.
-
For all other compute environments, you can perform an [AMI version update] to update the AMI to the latest version.
-
[1]: docs.aws.amazon.com/batch/latest/userguide/ami-selection-order.html [2]: docs.aws.amazon.com/batch/latest/APIReference/API_DescribeComputeEnvironments.html [3]: docs.aws.amazon.com/batch/latest/userguide/blue-green-updates.html [4]: docs.aws.amazon.com/batch/latest/userguide/managing-ami-versions.html#updating-ami-versions
4020 4021 4022 4023 4024 4025 4026 4027 |
# File 'lib/aws-sdk-batch/types.rb', line 4020 class Ec2Configuration < Struct.new( :image_type, :image_id_override, :batch_image_status, :image_kubernetes_version) SENSITIVE = [] include Aws::Structure end |
#image_id_override ⇒ String
The AMI ID used for instances launched in the compute environment that match the image type. This setting overrides the ‘imageId` set in the `computeResource` object.
<note markdown=“1”> The AMI that you choose for a compute environment must match the architecture of the instance types that you intend to use for that compute environment. For example, if your compute environment uses A1 instance types, the compute resource AMI that you choose must support ARM instances. Amazon ECS vends both x86 and ARM versions of the Amazon ECS-optimized Amazon Linux 2023 AMI. For more information, see [Amazon ECS-optimized Amazon Linux 2023 AMI] in the *Amazon Elastic Container Service Developer Guide*.
</note>
4020 4021 4022 4023 4024 4025 4026 4027 |
# File 'lib/aws-sdk-batch/types.rb', line 4020 class Ec2Configuration < Struct.new( :image_type, :image_id_override, :batch_image_status, :image_kubernetes_version) SENSITIVE = [] include Aws::Structure end |
#image_kubernetes_version ⇒ String
The Kubernetes version for the compute environment. If you don’t specify a value, the latest version that Batch supports is used.
4020 4021 4022 4023 4024 4025 4026 4027 |
# File 'lib/aws-sdk-batch/types.rb', line 4020 class Ec2Configuration < Struct.new( :image_type, :image_id_override, :batch_image_status, :image_kubernetes_version) SENSITIVE = [] include Aws::Structure end |
#image_type ⇒ String
The image type to match with the instance type to select an AMI. The supported values are different for ‘ECS` and `EKS` resources.
ECS
: If the ‘imageIdOverride` parameter isn’t specified, then a recent
[Amazon ECS-optimized Amazon Linux 2023 AMI][1] (`ECS_AL2023`) is
used. If a new image type is specified in an update, but neither
an `imageId` nor a `imageIdOverride` parameter is specified, then
the latest Amazon ECS optimized AMI for that image type that's
supported by Batch is used.
Amazon Web Services is ending support for Amazon ECS Amazon Linux
2-optimized and accelerated AMIs on June 30, 2026. On January 12,
2026, Batch changed the default AMI for new Amazon ECS compute
environments from Amazon Linux 2 to Amazon Linux 2023. Effective
June 30, 2026, Batch will block creation of new Amazon ECS compute
environments using Batch-provided Amazon Linux 2 AMIs. We strongly
recommend migrating your existing Batch Amazon ECS compute
environments to Amazon Linux 2023 prior to June 30, 2026. For more
information on upgrading from AL2 to AL2023, see [How to migrate
from ECS AL2 to ECS AL2023][2] in the *Batch User Guide*.
ECS\_AL2
: [Amazon Linux 2][1]: Used for non-GPU instance families.
ECS\_AL2\_NVIDIA
: [Amazon Linux 2 (GPU)][3]: Used for GPU instance families (for
example `P4` and `G4`) and non Amazon Web Services
Graviton-based instance types.
ECS\_AL2023
: [Amazon Linux 2023][1]: Default for all non-GPU instance
families.
<note markdown="1"> Amazon Linux 2023 does not support `A1` instances.
</note>
ECS\_AL2023\_NVIDIA
: [Amazon Linux 2023 (GPU)][3]: Default for all GPU instance
families and can be used for all non Amazon Web Services
Graviton-based instance types.
<note markdown="1"> ECS\_AL2023\_NVIDIA doesn't support `p3` and `g3` instance
types.
</note>
EKS
: If the ‘imageIdOverride` parameter isn’t specified, then a recent
[Amazon EKS-optimized Amazon Linux 2023 AMI][4] (`EKS_AL2023`) is
used. If a new image type is specified in an update, but neither
an `imageId` nor a `imageIdOverride` parameter is specified, then
the latest Amazon EKS optimized AMI for that image type that Batch
supports is used.
Amazon Linux 2023 AMIs are the default on Batch for Amazon EKS.
Amazon Web Services ended support for Amazon EKS AL2-optimized
and
AL2-accelerated AMIs on November 26, 2025. Batch Amazon EKS
compute environments using Amazon Linux 2 will no longer receive
software updates, security patches, or bug fixes from Amazon Web
Services. We recommend migrating to Amazon Linux 2023. For more
information on upgrading from AL2 to AL2023, see [How to upgrade
from EKS AL2 to EKS AL2023][5] in the *Batch User Guide*.
EKS\_AL2
: [Amazon Linux 2][4]: Used for non-GPU instance families.
EKS\_AL2\_NVIDIA
: [Amazon Linux 2 (accelerated)][4]: Used for GPU instance
families (for example, `P4` and `G4`) and can be used for all
non Amazon Web Services Graviton-based instance types.
EKS\_AL2023
: [Amazon Linux 2023][4]: Default for non-GPU instance families.
<note markdown="1"> Amazon Linux 2023 does not support `A1` instances.
</note>
EKS\_AL2023\_NVIDIA
: [Amazon Linux 2023 (accelerated)][4]: Default for GPU instance
families and can be used for all non Amazon Web Services
Graviton-based instance types.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html [2]: docs.aws.amazon.com/batch/latest/userguide/ecs-migration-2023.html [3]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html#gpuami [4]: docs.aws.amazon.com/eks/latest/userguide/eks-optimized-ami.html [5]: docs.aws.amazon.com/batch/latest/userguide/eks-migration-2023.html
4020 4021 4022 4023 4024 4025 4026 4027 |
# File 'lib/aws-sdk-batch/types.rb', line 4020 class Ec2Configuration < Struct.new( :image_type, :image_id_override, :batch_image_status, :image_kubernetes_version) SENSITIVE = [] include Aws::Structure end |