Class: Aws::Batch::Types::EcsSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::EcsSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The Amazon ECS settings for a compute environment, including the
CloudWatch Container Insights mode. Use this structure with
CreateComputeEnvironment and UpdateComputeEnvironment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_insights ⇒ String
Specifies the CloudWatch Container Insights mode for the compute environment.
Instance Attribute Details
#container_insights ⇒ String
Specifies the CloudWatch Container Insights mode for the compute environment. Valid values are:
ENABLED
: Turns on standard Container Insights, which collects CPU, memory, disk, and network utilization metrics for the compute environment.
ENHANCED
: Turns on enhanced Container Insights, which collects the standard metrics along with additional per-task observability metrics.
DISABLED
: Turns off Container Insights for the compute environment.
If you don't specify a value, the default is DISABLED. For more
information, see Container Insights in the Batch User Guide.
4219 4220 4221 4222 4223 |
# File 'lib/aws-sdk-batch/types.rb', line 4219 class EcsSettings < Struct.new( :container_insights) SENSITIVE = [] include Aws::Structure end |