Class: Aws::Batch::Types::EcsTaskDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::EcsTaskDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The details of a task definition that describes the container and volume definitions of an Amazon ECS task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the container instance that hosts the task.
-
#containers ⇒ Array<Types::TaskContainerDetails>
A list of containers that are included in the
taskPropertieslist. -
#enable_execute_command ⇒ Boolean
Determines whether execute command functionality is turned on for this task.
-
#ephemeral_storage ⇒ Types::EphemeralStorage
The amount of ephemeral storage allocated for the task.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the execution role that Batch can assume.
-
#ipc_mode ⇒ String
The IPC resource namespace to use for the containers in the task.
-
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for jobs that are running on Fargate resources.
-
#pid_mode ⇒ String
The process namespace to use for the containers in the task.
-
#platform_version ⇒ String
The Fargate platform version where the jobs are running.
-
#runtime_platform ⇒ Types::RuntimePlatform
An object that represents the compute environment architecture for Batch jobs on Fargate.
-
#task_arn ⇒ String
The ARN of the Amazon ECS task.
-
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that the container can assume for Amazon Web Services permissions.
-
#volumes ⇒ Array<Types::Volume>
A list of data volumes used in a job.
Instance Attribute Details
#container_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the container instance that hosts the task.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#containers ⇒ Array<Types::TaskContainerDetails>
A list of containers that are included in the taskProperties list.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#enable_execute_command ⇒ Boolean
Determines whether execute command functionality is turned on for
this task. If true, execute command functionality is turned on all
the containers in the task.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#ephemeral_storage ⇒ Types::EphemeralStorage
The amount of ephemeral storage allocated for the task.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the execution role that Batch can assume. For more information, see Batch execution IAM role in the Batch User Guide.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#ipc_mode ⇒ String
The IPC resource namespace to use for the containers in the task.
The valid values are host, task, or none. For more information
see ipcMode in EcsTaskProperties.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources must not specify this parameter.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#pid_mode ⇒ String
The process namespace to use for the containers in the task. The
valid values are host, or task. For more information see
pidMode in EcsTaskProperties.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#platform_version ⇒ String
The Fargate platform version where the jobs are running.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#runtime_platform ⇒ Types::RuntimePlatform
An object that represents the compute environment architecture for Batch jobs on Fargate.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#task_arn ⇒ String
The ARN of the Amazon ECS task.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that the container can assume for Amazon Web Services permissions. For more information, see IAM roles for tasks in the Amazon Elastic Container Service Developer Guide.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#volumes ⇒ Array<Types::Volume>
A list of data volumes used in a job.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 |
# File 'lib/aws-sdk-batch/types.rb', line 4318 class EcsTaskDetails < Struct.new( :containers, :container_instance_arn, :task_arn, :ephemeral_storage, :execution_role_arn, :platform_version, :ipc_mode, :task_role_arn, :pid_mode, :network_configuration, :runtime_platform, :volumes, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |