Class: Aws::Batch::Types::EksPersistentVolumeClaim
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::EksPersistentVolumeClaim
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
A persistentVolumeClaim volume is used to mount a
PersistentVolume into a Pod. PersistentVolumeClaims are a way for
users to "claim" durable storage without knowing the details of the
particular cloud environment. See the information about
PersistentVolumes in the Kubernetes documentation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#claim_name ⇒ String
The name of the
persistentVolumeClaimbounded to apersistentVolume. -
#read_only ⇒ Boolean
An optional boolean value indicating if the mount is read only.
Instance Attribute Details
#claim_name ⇒ String
The name of the persistentVolumeClaim bounded to a
persistentVolume. For more information, see Persistent Volume
Claims in the Kubernetes documentation.
5367 5368 5369 5370 5371 5372 |
# File 'lib/aws-sdk-batch/types.rb', line 5367 class EksPersistentVolumeClaim < Struct.new( :claim_name, :read_only) SENSITIVE = [] include Aws::Structure end |
#read_only ⇒ Boolean
An optional boolean value indicating if the mount is read only. Default is false. For more information, see Read Only Mounts in the Kubernetes documentation.
5367 5368 5369 5370 5371 5372 |
# File 'lib/aws-sdk-batch/types.rb', line 5367 class EksPersistentVolumeClaim < Struct.new( :claim_name, :read_only) SENSITIVE = [] include Aws::Structure end |