Class: Aws::Batch::Types::EksPodPropertiesOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::EksPodPropertiesOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that contains overrides for the Kubernetes pod properties of a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#containers ⇒ Array<Types::EksContainerOverride>
The overrides for the container that’s used on the Amazon EKS pod.
-
#init_containers ⇒ Array<Types::EksContainerOverride>
The overrides for the ‘initContainers` defined in the Amazon EKS pod.
-
#metadata ⇒ Types::EksMetadata
Metadata about the overrides for the container that’s used on the Amazon EKS pod.
Instance Attribute Details
#containers ⇒ Array<Types::EksContainerOverride>
The overrides for the container that’s used on the Amazon EKS pod.
5194 5195 5196 5197 5198 5199 5200 |
# File 'lib/aws-sdk-batch/types.rb', line 5194 class EksPodPropertiesOverride < Struct.new( :containers, :init_containers, :metadata) SENSITIVE = [] include Aws::Structure end |
#init_containers ⇒ Array<Types::EksContainerOverride>
The overrides for the ‘initContainers` defined in the Amazon EKS pod. These containers run before application containers, always run to completion, and must complete successfully before the next container starts. These containers are registered with the Amazon EKS Connector agent and persists the registration information in the Kubernetes backend data store. For more information, see [Init Containers] in the *Kubernetes documentation*.
[1]: kubernetes.io/docs/concepts/workloads/pods/init-containers/
5194 5195 5196 5197 5198 5199 5200 |
# File 'lib/aws-sdk-batch/types.rb', line 5194 class EksPodPropertiesOverride < Struct.new( :containers, :init_containers, :metadata) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Types::EksMetadata
Metadata about the overrides for the container that’s used on the Amazon EKS pod.
5194 5195 5196 5197 5198 5199 5200 |
# File 'lib/aws-sdk-batch/types.rb', line 5194 class EksPodPropertiesOverride < Struct.new( :containers, :init_containers, :metadata) SENSITIVE = [] include Aws::Structure end |