Class: Aws::Batch::Types::EphemeralStorage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::EphemeralStorage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The amount of ephemeral storage to allocate for the task. This parameter is used to expand the total amount of ephemeral storage available, beyond the default amount, for tasks hosted on Fargate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#size_in_gi_b ⇒ Integer
The total amount, in GiB, of ephemeral storage to set for the task.
Instance Attribute Details
#size_in_gi_b ⇒ Integer
The total amount, in GiB, of ephemeral storage to set for the task. The minimum supported value is ‘21` GiB and the maximum supported value is `200` GiB.
5750 5751 5752 5753 5754 |
# File 'lib/aws-sdk-batch/types.rb', line 5750 class EphemeralStorage < Struct.new( :size_in_gi_b) SENSITIVE = [] include Aws::Structure end |