Class: Aws::Batch::Types::FairshareCapacityUsage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The capacity usage for a fairshare scheduling job queue.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_unitString

The unit of measure for the capacity usage. For compute jobs, this is VCPU for Amazon EC2 and cpu for Amazon EKS. For service jobs, this is the instance type.

Returns:

  • (String)


5826
5827
5828
5829
5830
5831
# File 'lib/aws-sdk-batch/types.rb', line 5826

class FairshareCapacityUsage < Struct.new(
  :capacity_unit,
  :quantity)
  SENSITIVE = []
  include Aws::Structure
end

#quantityFloat

The quantity of capacity being used, measured in the units specified by capacityUnit.

Returns:

  • (Float)


5826
5827
5828
5829
5830
5831
# File 'lib/aws-sdk-batch/types.rb', line 5826

class FairshareCapacityUsage < Struct.new(
  :capacity_unit,
  :quantity)
  SENSITIVE = []
  include Aws::Structure
end