Class: Aws::Batch::Types::FairshareCapacityUsage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::FairshareCapacityUsage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The capacity usage for a fairshare scheduling job queue.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_unit ⇒ String
The unit of measure for the capacity usage.
-
#quantity ⇒ Float
The quantity of capacity being used, measured in the units specified by
capacityUnit.
Instance Attribute Details
#capacity_unit ⇒ String
The unit of measure for the capacity usage. For compute jobs, this
is VCPU for Amazon EC2 and cpu for Amazon EKS. For service jobs,
this is the instance type.
5821 5822 5823 5824 5825 5826 |
# File 'lib/aws-sdk-batch/types.rb', line 5821 class FairshareCapacityUsage < Struct.new( :capacity_unit, :quantity) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Float
The quantity of capacity being used, measured in the units specified
by capacityUnit.
5821 5822 5823 5824 5825 5826 |
# File 'lib/aws-sdk-batch/types.rb', line 5821 class FairshareCapacityUsage < Struct.new( :capacity_unit, :quantity) SENSITIVE = [] include Aws::Structure end |