Class: Aws::Batch::Types::FairshareCapacityUtilization

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The capacity utilization for a specific share in a fairshare scheduling job queue, including the share identifier and its current usage.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_usageArray<Types::FairshareCapacityUsage>

The capacity usage information for this share, including the unit of measure and quantity being used. This is VCPU for Amazon EC2 and cpu for Amazon EKS.



5460
5461
5462
5463
5464
5465
# File 'lib/aws-sdk-batch/types.rb', line 5460

class FairshareCapacityUtilization < Struct.new(
  :share_identifier,
  :capacity_usage)
  SENSITIVE = []
  include Aws::Structure
end

#share_identifierString

The share identifier for the fairshare scheduling job queue.



5460
5461
5462
5463
5464
5465
# File 'lib/aws-sdk-batch/types.rb', line 5460

class FairshareCapacityUtilization < Struct.new(
  :share_identifier,
  :capacity_usage)
  SENSITIVE = []
  include Aws::Structure
end