Class: Aws::Batch::Types::FrontOfQuotaShareJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::FrontOfQuotaShareJobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that represents summary details for the first ‘RUNNABLE` job in a quota share.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#earliest_time_at_position ⇒ Integer
The Unix timestamp (in milliseconds) for when the job transitioned to its current position in the quota share.
-
#job_arn ⇒ String
The ARN for a job in a named quota share.
Instance Attribute Details
#earliest_time_at_position ⇒ Integer
The Unix timestamp (in milliseconds) for when the job transitioned to its current position in the quota share.
5959 5960 5961 5962 5963 5964 |
# File 'lib/aws-sdk-batch/types.rb', line 5959 class FrontOfQuotaShareJobSummary < Struct.new( :job_arn, :earliest_time_at_position) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The ARN for a job in a named quota share.
5959 5960 5961 5962 5963 5964 |
# File 'lib/aws-sdk-batch/types.rb', line 5959 class FrontOfQuotaShareJobSummary < Struct.new( :job_arn, :earliest_time_at_position) SENSITIVE = [] include Aws::Structure end |