Class: Aws::Batch::Types::InstanceLaunchTemplateUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::InstanceLaunchTemplateUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The instance launch configuration for updating an Amazon ECS Managed
Instances capacity provider. You cannot change capacityOptionType or
fipsEnabled after the compute environment is created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservations ⇒ Types::CapacityReservationRequest
The updated capacity reservation configuration.
-
#ec2_instance_profile_arn ⇒ String
The updated Amazon Resource Name (ARN) of the Amazon EC2 instance profile for the managed instances.
-
#instance_metadata_tags_propagation ⇒ Boolean
Specifies whether instance tags are accessible from the instance metadata service (IMDS).
-
#instance_requirements ⇒ Types::InstanceRequirementsRequest
The updated instance type requirements for the capacity provider.
-
#local_storage_configuration ⇒ Types::ManagedInstancesLocalStorageConfiguration
The updated local storage configuration.
-
#monitoring ⇒ String
The updated monitoring level.
-
#network_configuration ⇒ Types::ManagedInstancesNetworkConfiguration
The updated network configuration for the managed instances.
-
#storage_configuration ⇒ Types::ManagedInstancesStorageConfiguration
The updated storage configuration for the managed instances.
Instance Attribute Details
#capacity_reservations ⇒ Types::CapacityReservationRequest
The updated capacity reservation configuration.
6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-batch/types.rb', line 6479 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :instance_requirements, :storage_configuration, :monitoring, :capacity_reservations, :instance_metadata_tags_propagation, :local_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#ec2_instance_profile_arn ⇒ String
The updated Amazon Resource Name (ARN) of the Amazon EC2 instance profile for the managed instances.
6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-batch/types.rb', line 6479 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :instance_requirements, :storage_configuration, :monitoring, :capacity_reservations, :instance_metadata_tags_propagation, :local_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_metadata_tags_propagation ⇒ Boolean
Specifies whether instance tags are accessible from the instance metadata service (IMDS).
6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-batch/types.rb', line 6479 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :instance_requirements, :storage_configuration, :monitoring, :capacity_reservations, :instance_metadata_tags_propagation, :local_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_requirements ⇒ Types::InstanceRequirementsRequest
The updated instance type requirements for the capacity provider.
6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-batch/types.rb', line 6479 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :instance_requirements, :storage_configuration, :monitoring, :capacity_reservations, :instance_metadata_tags_propagation, :local_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#local_storage_configuration ⇒ Types::ManagedInstancesLocalStorageConfiguration
The updated local storage configuration.
6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-batch/types.rb', line 6479 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :instance_requirements, :storage_configuration, :monitoring, :capacity_reservations, :instance_metadata_tags_propagation, :local_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#monitoring ⇒ String
The updated monitoring level. Valid values are BASIC and
DETAILED.
6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-batch/types.rb', line 6479 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :instance_requirements, :storage_configuration, :monitoring, :capacity_reservations, :instance_metadata_tags_propagation, :local_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::ManagedInstancesNetworkConfiguration
The updated network configuration for the managed instances.
6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-batch/types.rb', line 6479 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :instance_requirements, :storage_configuration, :monitoring, :capacity_reservations, :instance_metadata_tags_propagation, :local_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#storage_configuration ⇒ Types::ManagedInstancesStorageConfiguration
The updated storage configuration for the managed instances.
6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/aws-sdk-batch/types.rb', line 6479 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :instance_requirements, :storage_configuration, :monitoring, :capacity_reservations, :instance_metadata_tags_propagation, :local_storage_configuration) SENSITIVE = [] include Aws::Structure end |