Class: Aws::Batch::Types::JobSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

An object that represents summary details of a job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#array_propertiesTypes::ArrayPropertiesSummary

The array properties of the job, if it’s an array job.



6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_usageArray<Types::JobCapacityUsageSummary>

The configured capacity usage information for this job, including the unit of measure and quantity of resources.

Returns:



6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#containerTypes::ContainerSummary

An object that represents the details of the container that’s associated with the job.



6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#created_atInteger

The Unix timestamp (in milliseconds) for when the job was created. For non-array jobs and parent array jobs, this is when the job entered the ‘SUBMITTED` state (at the time [SubmitJob] was called). For array child jobs, this is when the child job was spawned by its parent and entered the `PENDING` state.

[1]: docs.aws.amazon.com/batch/latest/APIReference/API_SubmitJob.html

Returns:

  • (Integer)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The Amazon Resource Name (ARN) of the job.

Returns:

  • (String)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#job_definitionString

The Amazon Resource Name (ARN) of the job definition.

Returns:

  • (String)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID.

Returns:

  • (String)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The job name.

Returns:

  • (String)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#node_propertiesTypes::NodePropertiesSummary

The node properties for a single node in a job summary list.

<note markdown=“1”> This isn’t applicable to jobs that are running on Fargate resources.

</note>


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_atInteger

The Unix timestamp (in milliseconds) for when the job was scheduled for execution. For more information on job statues, see [Service job status] in the *Batch User Guide*.

[1]: docs.aws.amazon.com/batch/latest/userguide/service-job-status.html

Returns:

  • (Integer)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#share_identifierString

The share identifier for the fairshare scheduling queue that this job is associated with.

Returns:

  • (String)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#started_atInteger

The Unix timestamp for when the job was started. More specifically, it’s when the job transitioned from the ‘STARTING` state to the `RUNNING` state.

Returns:

  • (Integer)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status for the job.

Returns:

  • (String)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

A short, human-readable string to provide more details for the current status of the job.

Returns:

  • (String)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atInteger

The Unix timestamp for when the job was stopped. More specifically, it’s when the job transitioned from the ‘RUNNING` state to a terminal state, such as `SUCCEEDED` or `FAILED`.

Returns:

  • (Integer)


6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
# File 'lib/aws-sdk-batch/types.rb', line 6828

class JobSummary < Struct.new(
  :job_arn,
  :job_id,
  :job_name,
  :capacity_usage,
  :created_at,
  :scheduled_at,
  :share_identifier,
  :status,
  :status_reason,
  :started_at,
  :stopped_at,
  :container,
  :array_properties,
  :node_properties,
  :job_definition)
  SENSITIVE = []
  include Aws::Structure
end