Class: Aws::Batch::Types::JobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::JobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that represents summary details of a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#array_properties ⇒ Types::ArrayPropertiesSummary
The array properties of the job, if it’s an array job.
-
#capacity_usage ⇒ Array<Types::JobCapacityUsageSummary>
The configured capacity usage information for this job, including the unit of measure and quantity of resources.
-
#container ⇒ Types::ContainerSummary
An object that represents the details of the container that’s associated with the job.
-
#created_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the job was created.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
-
#job_definition ⇒ String
The Amazon Resource Name (ARN) of the job definition.
-
#job_id ⇒ String
The job ID.
-
#job_name ⇒ String
The job name.
-
#node_properties ⇒ Types::NodePropertiesSummary
The node properties for a single node in a job summary list.
-
#scheduled_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the job was scheduled for execution.
-
#share_identifier ⇒ String
The share identifier for the fairshare scheduling queue that this job is associated with.
-
#started_at ⇒ Integer
The Unix timestamp for when the job was started.
-
#status ⇒ String
The current status for the job.
-
#status_reason ⇒ String
A short, human-readable string to provide more details for the current status of the job.
-
#stopped_at ⇒ Integer
The Unix timestamp for when the job was stopped.
Instance Attribute Details
#array_properties ⇒ Types::ArrayPropertiesSummary
The array properties of the job, if it’s an array job.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#capacity_usage ⇒ Array<Types::JobCapacityUsageSummary>
The configured capacity usage information for this job, including the unit of measure and quantity of resources.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#container ⇒ Types::ContainerSummary
An object that represents the details of the container that’s associated with the job.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the job was created. For non-array jobs and parent array jobs, this is when the job entered the SUBMITTED state (at the time [SubmitJob] was called). For array child jobs, this is when the child job was spawned by its parent and entered the PENDING state.
[1]: docs.aws.amazon.com/batch/latest/APIReference/API_SubmitJob.html
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#job_definition ⇒ String
The Amazon Resource Name (ARN) of the job definition.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The job name.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#node_properties ⇒ Types::NodePropertiesSummary
The node properties for a single node in a job summary list.
<note markdown=“1”> This isn’t applicable to jobs that are running on Fargate resources.
</note>
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#scheduled_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the job was scheduled for execution. For more information on job statues, see [Service job status] in the *Batch User Guide*.
[1]: docs.aws.amazon.com/batch/latest/userguide/service-job-status.html
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#share_identifier ⇒ String
The share identifier for the fairshare scheduling queue that this job is associated with.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Integer
The Unix timestamp for when the job was started. More specifically, it’s when the job transitioned from the STARTING state to the RUNNING state.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status for the job.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A short, human-readable string to provide more details for the current status of the job.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Integer
The Unix timestamp for when the job was stopped. More specifically, it’s when the job transitioned from the RUNNING state to a terminal state, such as SUCCEEDED or FAILED.
6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 |
# File 'lib/aws-sdk-batch/types.rb', line 6442 class JobSummary < Struct.new( :job_arn, :job_id, :job_name, :capacity_usage, :created_at, :scheduled_at, :share_identifier, :status, :status_reason, :started_at, :stopped_at, :container, :array_properties, :node_properties, :job_definition) SENSITIVE = [] include Aws::Structure end |