Class: Aws::Batch::Types::ListConsumableResourcesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumable_resourcesArray<Types::ConsumableResourceSummary>

A list of consumable resources that match the request.



7266
7267
7268
7269
7270
7271
# File 'lib/aws-sdk-batch/types.rb', line 7266

class ListConsumableResourcesResponse < Struct.new(
  :consumable_resources,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value to include in a future ListConsumableResources request. When the results of a ListConsumableResources request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.

Returns:

  • (String)


7266
7267
7268
7269
7270
7271
# File 'lib/aws-sdk-batch/types.rb', line 7266

class ListConsumableResourcesResponse < Struct.new(
  :consumable_resources,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end