Class: Aws::Batch::Types::ListJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ListJobsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Contains the parameters for ListJobs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#array_job_id ⇒ String
The job ID for an array job.
-
#filters ⇒ Array<Types::KeyValuesPair>
The filter to apply to the query.
-
#job_queue ⇒ String
The name or full Amazon Resource Name (ARN) of the job queue used to list jobs.
-
#job_status ⇒ String
The job status used to filter jobs in the specified queue.
-
#max_results ⇒ Integer
The maximum number of results returned by
ListJobsin a paginated output. -
#multi_node_job_id ⇒ String
The job ID for a multi-node parallel job.
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedListJobsrequest wheremaxResultswas used and the results exceeded the value of that parameter.
Instance Attribute Details
#array_job_id ⇒ String
The job ID for an array job. Specifying an array job ID with this parameter lists all child jobs from within the specified array.
7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 |
# File 'lib/aws-sdk-batch/types.rb', line 7272 class ListJobsRequest < Struct.new( :job_queue, :array_job_id, :multi_node_job_id, :job_status, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::KeyValuesPair>
The filter to apply to the query. Only one filter can be used at a time. When the filter is used, jobStatus is ignored with the exception that SHARE_IDENTIFIER and jobStatus can be used together. The filter doesn’t apply to child jobs in an array or multi-node parallel (MNP) jobs. The results are sorted by the createdAt field, with the most recent jobs being first.
<note markdown=“1”> The SHARE_IDENTIFIER filter and the jobStatus field can be used together to filter results.
</note>
JOB_NAME
: The value of the filter is a case-insensitive match for the job
name. If the value ends with an asterisk (*), the filter matches
any job name that begins with the string before the '*'. This
corresponds to the `jobName` value. For example, `test1` matches
both `Test1` and `test1`, and `test1*` matches both `test1` and
`Test10`. When the `JOB_NAME` filter is used, the results are
grouped by the job name and version.
JOB_DEFINITION
: The value for the filter is the name or Amazon Resource Name (ARN)
of the job definition. This corresponds to the `jobDefinition`
value. The value is case sensitive. When the value for the filter
is the job definition name, the results include all the jobs that
used any revision of that job definition name. If the value ends
with an asterisk (*), the filter matches any job definition name
that begins with the string before the '*'. For example, `jd1`
matches only `jd1`, and `jd1*` matches both `jd1` and `jd1A`. The
version of the job definition that's used doesn't affect the
sort order. When the `JOB_DEFINITION` filter is used and the ARN
is used (which is in the form
`arn:${Partition}:batch:${Region}:${Account}:job-definition/${JobDefinitionName}:${Revision}`),
the results include jobs that used the specified revision of the
job definition. Asterisk (*) isn't supported when the ARN is
used.
BEFORE_CREATED_AT
: The value for the filter is the time that’s before the job was
created. This corresponds to the `createdAt` value. The value is a
string representation of the number of milliseconds since 00:00:00
UTC (midnight) on January 1, 1970.
AFTER_CREATED_AT
: The value for the filter is the time that’s after the job was
created. This corresponds to the `createdAt` value. The value is a
string representation of the number of milliseconds since 00:00:00
UTC (midnight) on January 1, 1970.
SHARE_IDENTIFIER
: The value for the filter is the fairshare scheduling share
identifier.
7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 |
# File 'lib/aws-sdk-batch/types.rb', line 7272 class ListJobsRequest < Struct.new( :job_queue, :array_job_id, :multi_node_job_id, :job_status, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#job_queue ⇒ String
The name or full Amazon Resource Name (ARN) of the job queue used to list jobs.
7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 |
# File 'lib/aws-sdk-batch/types.rb', line 7272 class ListJobsRequest < Struct.new( :job_queue, :array_job_id, :multi_node_job_id, :job_status, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The job status used to filter jobs in the specified queue. If the filters parameter is specified, the jobStatus parameter is ignored and jobs with any status are returned. The exception is the SHARE_IDENTIFIER filter and jobStatus can be used together. If you don’t specify a status, only RUNNING jobs are returned.
<note markdown=“1”> Array job parents are updated to PENDING when any child job is updated to RUNNABLE and remain in PENDING status while child jobs are running. To view these jobs, filter by PENDING status until all child jobs reach a terminal state.
</note>
7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 |
# File 'lib/aws-sdk-batch/types.rb', line 7272 class ListJobsRequest < Struct.new( :job_queue, :array_job_id, :multi_node_job_id, :job_status, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results returned by ListJobs in a paginated output. When this parameter is used, ListJobs returns up to maxResults results in a single page and a nextToken response element, if applicable. The remaining results of the initial request can be seen by sending another ListJobs request with the returned nextToken value.
The following outlines key parameters and limitations:
-
The minimum value is 1.
-
When
--job-statusis used, Batch returns up to 1000 values. -
When
--filtersis used, Batch returns up to 100 values. -
If neither parameter is used, then
ListJobsreturns up to 1000 results (jobs that are in theRUNNINGstatus) and anextTokenvalue, if applicable.
7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 |
# File 'lib/aws-sdk-batch/types.rb', line 7272 class ListJobsRequest < Struct.new( :job_queue, :array_job_id, :multi_node_job_id, :job_status, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#multi_node_job_id ⇒ String
The job ID for a multi-node parallel job. Specifying a multi-node parallel job ID with this parameter lists all nodes that are associated with the specified job.
7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 |
# File 'lib/aws-sdk-batch/types.rb', line 7272 class ListJobsRequest < Struct.new( :job_queue, :array_job_id, :multi_node_job_id, :job_status, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated ListJobs request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.
<note markdown=“1”> Treat this token as an opaque identifier that’s only used to retrieve the next items in a list and not for other programmatic purposes.
</note>
7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 |
# File 'lib/aws-sdk-batch/types.rb', line 7272 class ListJobsRequest < Struct.new( :job_queue, :array_job_id, :multi_node_job_id, :job_status, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |