Class: Aws::Batch::Types::ListJobsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_summary_listArray<Types::JobSummary>

A list of job summaries that match the request.

Returns:



7297
7298
7299
7300
7301
7302
# File 'lib/aws-sdk-batch/types.rb', line 7297

class ListJobsResponse < Struct.new(
  :job_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value to include in a future ListJobs request. When the results of a ListJobs request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.

Returns:

  • (String)


7297
7298
7299
7300
7301
7302
# File 'lib/aws-sdk-batch/types.rb', line 7297

class ListJobsResponse < Struct.new(
  :job_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end