Class: Aws::Batch::Types::ListJobsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ListJobsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_summary_list ⇒ Array<Types::JobSummary>
A list of job summaries that match the request.
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListJobsrequest.
Instance Attribute Details
#job_summary_list ⇒ Array<Types::JobSummary>
A list of job summaries that match the request.
8127 8128 8129 8130 8131 8132 |
# File 'lib/aws-sdk-batch/types.rb', line 8127 class ListJobsResponse < Struct.new( :job_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future ListJobs request.
When the results of a ListJobs request exceed maxResults, this
value can be used to retrieve the next page of results. This value
is null when there are no more results to return.
8127 8128 8129 8130 8131 8132 |
# File 'lib/aws-sdk-batch/types.rb', line 8127 class ListJobsResponse < Struct.new( :job_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |