Class: Aws::Batch::Types::ListQuotaSharesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ListQuotaSharesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_queue ⇒ String
The name or full Amazon Resource Name (ARN) of the job queue used to list quota shares.
-
#max_results ⇒ Integer
The maximum number of results returned by
ListQuotaSharesin paginated output. -
#next_token ⇒ String
The
nextTokenvalue that’s returned from a previous paginatedListQuotaSharesrequest wheremaxResultswas used and the results exceeded the value of that parameter.
Instance Attribute Details
#job_queue ⇒ String
The name or full Amazon Resource Name (ARN) of the job queue used to list quota shares.
7632 7633 7634 7635 7636 7637 7638 |
# File 'lib/aws-sdk-batch/types.rb', line 7632 class ListQuotaSharesRequest < Struct.new( :job_queue, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results returned by ListQuotaShares in paginated output. When this parameter is used, ListQuotaShares only returns maxResults results in a single page and a nextToken response element. You can see the remaining results of the initial request by sending another ListQuotaShares request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn’t used, ListQuotaShares returns up to 100 results and a nextToken value if applicable.
7632 7633 7634 7635 7636 7637 7638 |
# File 'lib/aws-sdk-batch/types.rb', line 7632 class ListQuotaSharesRequest < Struct.new( :job_queue, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value that’s returned from a previous paginated ListQuotaShares request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.
<note markdown=“1”> Treat this token as an opaque identifier that’s only used to retrieve the next items in a list and not for other programmatic purposes.
</note>
7632 7633 7634 7635 7636 7637 7638 |
# File 'lib/aws-sdk-batch/types.rb', line 7632 class ListQuotaSharesRequest < Struct.new( :job_queue, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |