Class: Aws::Batch::Types::ListSchedulingPoliciesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The nextToken value to include in a future ListSchedulingPolicies request. When the results of a ListSchedulingPolicies request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.

Returns:

  • (String)


7356
7357
7358
7359
7360
7361
# File 'lib/aws-sdk-batch/types.rb', line 7356

class ListSchedulingPoliciesResponse < Struct.new(
  :scheduling_policies,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#scheduling_policiesArray<Types::SchedulingPolicyListingDetail>

A list of scheduling policies that match the request.



7356
7357
7358
7359
7360
7361
# File 'lib/aws-sdk-batch/types.rb', line 7356

class ListSchedulingPoliciesResponse < Struct.new(
  :scheduling_policies,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end