Class: Aws::Batch::Types::ListServiceJobsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ListServiceJobsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_summary_list ⇒ Array<Types::ServiceJobSummary>
A list of service job summaries.
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListServiceJobsrequest.
Instance Attribute Details
#job_summary_list ⇒ Array<Types::ServiceJobSummary>
A list of service job summaries.
7474 7475 7476 7477 7478 7479 |
# File 'lib/aws-sdk-batch/types.rb', line 7474 class ListServiceJobsResponse < Struct.new( :job_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future ListServiceJobs request. When the results of a ListServiceJobs request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
7474 7475 7476 7477 7478 7479 |
# File 'lib/aws-sdk-batch/types.rb', line 7474 class ListServiceJobsResponse < Struct.new( :job_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |