Class: Aws::Batch::Types::ManagedInstancesNetworkConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ManagedInstancesNetworkConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The network configuration for Amazon ECS Managed Instances. Specifies the VPC subnets and security groups where instances are launched.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_groups ⇒ Array<String>
The VPC security groups to associate with the managed instances.
-
#subnets ⇒ Array<String>
The VPC subnets where managed instances are launched.
Instance Attribute Details
#security_groups ⇒ Array<String>
The VPC security groups to associate with the managed instances.
8465 8466 8467 8468 8469 8470 |
# File 'lib/aws-sdk-batch/types.rb', line 8465 class ManagedInstancesNetworkConfiguration < Struct.new( :subnets, :security_groups) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<String>
The VPC subnets where managed instances are launched. If your subnets don't provide public IP addresses, they must have a NAT gateway for outbound internet access.
8465 8466 8467 8468 8469 8470 |
# File 'lib/aws-sdk-batch/types.rb', line 8465 class ManagedInstancesNetworkConfiguration < Struct.new( :subnets, :security_groups) SENSITIVE = [] include Aws::Structure end |