Class: Aws::Batch::Types::QueueSnapshotCapacityUsage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The configured capacity usage for a job queue snapshot, including the unit of measure and quantity of resources being used.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_unitString

The unit of measure for the capacity usage. For compute jobs, this is VCPU for Amazon EC2 and cpu for Amazon EKS. For service jobs, this is the instance type.

Returns:

  • (String)


8482
8483
8484
8485
8486
8487
# File 'lib/aws-sdk-batch/types.rb', line 8482

class QueueSnapshotCapacityUsage < Struct.new(
  :capacity_unit,
  :quantity)
  SENSITIVE = []
  include Aws::Structure
end

#quantityFloat

The quantity of capacity being used in the queue snapshot, measured in the units specified by capacityUnit.

Returns:

  • (Float)


8482
8483
8484
8485
8486
8487
# File 'lib/aws-sdk-batch/types.rb', line 8482

class QueueSnapshotCapacityUsage < Struct.new(
  :capacity_unit,
  :quantity)
  SENSITIVE = []
  include Aws::Structure
end