Class: Aws::Batch::Types::QueueSnapshotCapacityUsage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::QueueSnapshotCapacityUsage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The configured capacity usage for a job queue snapshot, including the unit of measure and quantity of resources being used.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_unit ⇒ String
The unit of measure for the capacity usage.
-
#quantity ⇒ Float
The quantity of capacity being used in the queue snapshot, measured in the units specified by
capacityUnit.
Instance Attribute Details
#capacity_unit ⇒ String
The unit of measure for the capacity usage. For compute jobs, this
is VCPU for Amazon EC2 and cpu for Amazon EKS. For service jobs,
this is the instance type.
8431 8432 8433 8434 8435 8436 |
# File 'lib/aws-sdk-batch/types.rb', line 8431 class QueueSnapshotCapacityUsage < Struct.new( :capacity_unit, :quantity) SENSITIVE = [] include Aws::Structure end |
#quantity ⇒ Float
The quantity of capacity being used in the queue snapshot, measured
in the units specified by capacityUnit.
8431 8432 8433 8434 8435 8436 |
# File 'lib/aws-sdk-batch/types.rb', line 8431 class QueueSnapshotCapacityUsage < Struct.new( :capacity_unit, :quantity) SENSITIVE = [] include Aws::Structure end |