Class: Aws::Batch::Types::QueueSnapshotCapacityUsage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The configured capacity usage for a job queue snapshot, including the unit of measure and quantity of resources being used.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_unitString

The unit of measure for the capacity usage. For compute jobs, this is VCPU for Amazon EC2 and cpu for Amazon EKS. For service jobs, this is NUM_INSTANCES.

Returns:

  • (String)


7922
7923
7924
7925
7926
7927
# File 'lib/aws-sdk-batch/types.rb', line 7922

class QueueSnapshotCapacityUsage < Struct.new(
  :capacity_unit,
  :quantity)
  SENSITIVE = []
  include Aws::Structure
end

#quantityFloat

The quantity of capacity being used in the queue snapshot, measured in the units specified by capacityUnit.

Returns:

  • (Float)


7922
7923
7924
7925
7926
7927
# File 'lib/aws-sdk-batch/types.rb', line 7922

class QueueSnapshotCapacityUsage < Struct.new(
  :capacity_unit,
  :quantity)
  SENSITIVE = []
  include Aws::Structure
end