Class: Aws::Batch::Types::RetryStrategy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

The retry strategy that's associated with a job. For more information, see Automated job retries in the Batch User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attemptsInteger

The number of times to move a job to the RUNNABLE status. You can specify between 1 and 10 attempts. If the value of attempts is greater than one, the job is retried on failure the same number of attempts as the value.

Returns:

  • (Integer)


9104
9105
9106
9107
9108
9109
# File 'lib/aws-sdk-batch/types.rb', line 9104

class RetryStrategy < Struct.new(
  :attempts,
  :evaluate_on_exit)
  SENSITIVE = []
  include Aws::Structure
end

#evaluate_on_exitArray<Types::EvaluateOnExit>

Array of up to 5 objects that specify the conditions where jobs are retried or failed. If this parameter is specified, then the attempts parameter must also be specified. If none of the listed conditions match, then the job is retried.

Returns:



9104
9105
9106
9107
9108
9109
# File 'lib/aws-sdk-batch/types.rb', line 9104

class RetryStrategy < Struct.new(
  :attempts,
  :evaluate_on_exit)
  SENSITIVE = []
  include Aws::Structure
end