Class: Aws::Batch::Types::ServiceEnvironmentDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ServiceEnvironmentDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Detailed information about a service environment, including its configuration, state, and capacity limits.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_limits ⇒ Array<Types::CapacityLimit>
The capacity limits for the service environment.
-
#service_environment_arn ⇒ String
The Amazon Resource Name (ARN) of the service environment.
-
#service_environment_name ⇒ String
The name of the service environment.
-
#service_environment_type ⇒ String
The type of service environment.
-
#state ⇒ String
The state of the service environment.
-
#status ⇒ String
The current status of the service environment.
-
#tags ⇒ Hash<String,String>
The tags associated with the service environment.
Instance Attribute Details
#capacity_limits ⇒ Array<Types::CapacityLimit>
The capacity limits for the service environment. This defines the maximum resources that can be used by service jobs in this environment.
9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 |
# File 'lib/aws-sdk-batch/types.rb', line 9362 class ServiceEnvironmentDetail < Struct.new( :service_environment_name, :service_environment_arn, :service_environment_type, :state, :status, :capacity_limits, :tags) SENSITIVE = [] include Aws::Structure end |
#service_environment_arn ⇒ String
The Amazon Resource Name (ARN) of the service environment.
9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 |
# File 'lib/aws-sdk-batch/types.rb', line 9362 class ServiceEnvironmentDetail < Struct.new( :service_environment_name, :service_environment_arn, :service_environment_type, :state, :status, :capacity_limits, :tags) SENSITIVE = [] include Aws::Structure end |
#service_environment_name ⇒ String
The name of the service environment.
9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 |
# File 'lib/aws-sdk-batch/types.rb', line 9362 class ServiceEnvironmentDetail < Struct.new( :service_environment_name, :service_environment_arn, :service_environment_type, :state, :status, :capacity_limits, :tags) SENSITIVE = [] include Aws::Structure end |
#service_environment_type ⇒ String
The type of service environment. For SageMaker Training jobs, this
value is SAGEMAKER_TRAINING.
9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 |
# File 'lib/aws-sdk-batch/types.rb', line 9362 class ServiceEnvironmentDetail < Struct.new( :service_environment_name, :service_environment_arn, :service_environment_type, :state, :status, :capacity_limits, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the service environment. Valid values are ENABLED and
DISABLED.
9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 |
# File 'lib/aws-sdk-batch/types.rb', line 9362 class ServiceEnvironmentDetail < Struct.new( :service_environment_name, :service_environment_arn, :service_environment_type, :state, :status, :capacity_limits, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the service environment.
9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 |
# File 'lib/aws-sdk-batch/types.rb', line 9362 class ServiceEnvironmentDetail < Struct.new( :service_environment_name, :service_environment_arn, :service_environment_type, :state, :status, :capacity_limits, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the service environment. Each tag consists of a key and an optional value. For more information, see Tagging your Batch resources.
9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 |
# File 'lib/aws-sdk-batch/types.rb', line 9362 class ServiceEnvironmentDetail < Struct.new( :service_environment_name, :service_environment_arn, :service_environment_type, :state, :status, :capacity_limits, :tags) SENSITIVE = [] include Aws::Structure end |