Class: Aws::Batch::Types::ServiceJobPreemptionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ServiceJobPreemptionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Specifies the service job behavior when preempted.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#preemption_retries_before_termination ⇒ Integer
The number of times a service job can be retried after it is preempted.
Instance Attribute Details
#preemption_retries_before_termination ⇒ Integer
The number of times a service job can be retried after it is preempted. A job will be terminated when preemption retries have been exhausted. If this field is unset, preempted jobs will be requeued an unlimited number of times.
9399 9400 9401 9402 9403 |
# File 'lib/aws-sdk-batch/types.rb', line 9399 class ServiceJobPreemptionConfiguration < Struct.new( :preemption_retries_before_termination) SENSITIVE = [] include Aws::Structure end |