Class: Aws::Batch::Types::ServiceJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Summary information about a service job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_usageArray<Types::ServiceJobCapacityUsageSummary>

The capacity usage information for this service job, including the unit of measure and quantity of resources being used.



9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atInteger

The Unix timestamp (in milliseconds) for when the service job was created.

Returns:

  • (Integer)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The Amazon Resource Name (ARN) of the service job.

Returns:

  • (String)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID for the service job.

Returns:

  • (String)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the service job.

Returns:

  • (String)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#latest_attemptTypes::LatestServiceJobAttempt

Information about the latest attempt for the service job.



9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#quota_share_nameString

The quota share for the service job.

Returns:

  • (String)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_atInteger

The Unix timestamp (in milliseconds) for when the service job was scheduled for execution.

Returns:

  • (Integer)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_job_typeString

The type of service job. For SageMaker Training jobs, this value is ‘SAGEMAKER_TRAINING`.

Returns:

  • (String)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#share_identifierString

The share identifier for the job.

Returns:

  • (String)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atInteger

The Unix timestamp (in milliseconds) for when the service job was started.

Returns:

  • (Integer)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the service job.

Returns:

  • (String)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

A short string to provide more details on the current status of the service job.

Returns:

  • (String)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atInteger

The Unix timestamp (in milliseconds) for when the service job stopped running.

Returns:

  • (Integer)


9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
# File 'lib/aws-sdk-batch/types.rb', line 9553

class ServiceJobSummary < Struct.new(
  :latest_attempt,
  :capacity_usage,
  :created_at,
  :job_arn,
  :job_id,
  :job_name,
  :scheduled_at,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :status,
  :status_reason,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end