Class: Aws::Batch::Types::ServiceJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::ServiceJobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Summary information about a service job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_usage ⇒ Array<Types::ServiceJobCapacityUsageSummary>
The capacity usage information for this service job, including the unit of measure and quantity of resources being used.
-
#created_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was created.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the service job.
-
#job_id ⇒ String
The job ID for the service job.
-
#job_name ⇒ String
The name of the service job.
-
#latest_attempt ⇒ Types::LatestServiceJobAttempt
Information about the latest attempt for the service job.
-
#quota_share_name ⇒ String
The quota share for the service job.
-
#scheduled_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was scheduled for execution.
-
#service_job_type ⇒ String
The type of service job.
-
#share_identifier ⇒ String
The share identifier for the job.
-
#started_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was started.
-
#status ⇒ String
The current status of the service job.
-
#status_reason ⇒ String
A short string to provide more details on the current status of the service job.
-
#stopped_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job stopped running.
Instance Attribute Details
#capacity_usage ⇒ Array<Types::ServiceJobCapacityUsageSummary>
The capacity usage information for this service job, including the unit of measure and quantity of resources being used.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was created.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the service job.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID for the service job.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the service job.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#latest_attempt ⇒ Types::LatestServiceJobAttempt
Information about the latest attempt for the service job.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#quota_share_name ⇒ String
The quota share for the service job.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#scheduled_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was scheduled for execution.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#service_job_type ⇒ String
The type of service job. For SageMaker Training jobs, this value is ‘SAGEMAKER_TRAINING`.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#share_identifier ⇒ String
The share identifier for the job.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job was started.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the service job.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A short string to provide more details on the current status of the service job.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Integer
The Unix timestamp (in milliseconds) for when the service job stopped running.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/aws-sdk-batch/types.rb', line 9553 class ServiceJobSummary < Struct.new( :latest_attempt, :capacity_usage, :created_at, :job_arn, :job_id, :job_name, :scheduled_at, :service_job_type, :share_identifier, :quota_share_name, :status, :status_reason, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |