Class: Aws::Batch::Types::SubmitServiceJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::SubmitServiceJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique identifier for the request.
-
#job_name ⇒ String
The name of the service job.
-
#job_queue ⇒ String
The job queue into which the service job is submitted.
-
#preemption_configuration ⇒ Types::ServiceJobPreemptionConfiguration
Specifies the service job behavior when preempted.
-
#quota_share_name ⇒ String
The quota share for the service job.
-
#retry_strategy ⇒ Types::ServiceJobRetryStrategy
The retry strategy to use for failed service jobs that are submitted with this service job request.
-
#scheduling_priority ⇒ Integer
The scheduling priority of the service job.
-
#service_job_type ⇒ String
The type of service job.
-
#service_request_payload ⇒ String
The request, in JSON, for the service that the SubmitServiceJob operation is queueing.
-
#share_identifier ⇒ String
The share identifier for the service job.
-
#tags ⇒ Hash<String,String>
The tags that you apply to the service job request.
-
#timeout_config ⇒ Types::ServiceJobTimeout
The timeout configuration for the service job.
Instance Attribute Details
#client_token ⇒ String
A unique identifier for the request. This token is used to ensure idempotency of requests. If this parameter is specified and two submit requests with identical payloads and ‘clientToken`s are received, these requests are considered the same request and the second request is rejected.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the service job. It can be up to 128 characters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), and underscores (_).
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#job_queue ⇒ String
The job queue into which the service job is submitted. You can specify either the name or the ARN of the queue. The job queue must have the type ‘SAGEMAKER_TRAINING`.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#preemption_configuration ⇒ Types::ServiceJobPreemptionConfiguration
Specifies the service job behavior when preempted.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#quota_share_name ⇒ String
The quota share for the service job. Don’t specify this parameter if the job queue doesn’t have a quota share scheduling policy. If the job queue has a quota share scheduling policy, then this parameter must be specified.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#retry_strategy ⇒ Types::ServiceJobRetryStrategy
The retry strategy to use for failed service jobs that are submitted with this service job request.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#scheduling_priority ⇒ Integer
The scheduling priority of the service job. Valid values are integers between 0 and 9999.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#service_job_type ⇒ String
The type of service job. For SageMaker Training jobs, specify ‘SAGEMAKER_TRAINING`.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#service_request_payload ⇒ String
The request, in JSON, for the service that the SubmitServiceJob operation is queueing.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#share_identifier ⇒ String
The share identifier for the service job. Don’t specify this parameter if the job queue doesn’t have a fair-share scheduling policy. If the job queue has a fair-share scheduling policy, then this parameter must be specified.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags that you apply to the service job request. Each tag consists of a key and an optional value. For more information, see [Tagging your Batch resources].
[1]: docs.aws.amazon.com/batch/latest/userguide/using-tags.html
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#timeout_config ⇒ Types::ServiceJobTimeout
The timeout configuration for the service job. If none is specified, Batch defers to the default timeout of the underlying service handling the job.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-batch/types.rb', line 10018 class SubmitServiceJobRequest < Struct.new( :job_name, :job_queue, :retry_strategy, :scheduling_priority, :service_request_payload, :service_job_type, :share_identifier, :quota_share_name, :preemption_configuration, :timeout_config, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |