Class: Aws::Batch::Types::SubmitServiceJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique identifier for the request. This token is used to ensure idempotency of requests. If this parameter is specified and two submit requests with identical payloads and ‘clientToken`s are received, these requests are considered the same request and the second request is rejected.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the service job. It can be up to 128 characters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), and underscores (_).

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#job_queueString

The job queue into which the service job is submitted. You can specify either the name or the ARN of the queue. The job queue must have the type ‘SAGEMAKER_TRAINING`.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#preemption_configurationTypes::ServiceJobPreemptionConfiguration

Specifies the service job behavior when preempted.



9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#quota_share_nameString

The quota share for the service job. Don’t specify this parameter if the job queue doesn’t have a quota share scheduling policy. If the job queue has a quota share scheduling policy, then this parameter must be specified.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#retry_strategyTypes::ServiceJobRetryStrategy

The retry strategy to use for failed service jobs that are submitted with this service job request.



9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#scheduling_priorityInteger

The scheduling priority of the service job. Valid values are integers between 0 and 9999.

Returns:

  • (Integer)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_job_typeString

The type of service job. For SageMaker Training jobs, specify ‘SAGEMAKER_TRAINING`.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_request_payloadString

The request, in JSON, for the service that the SubmitServiceJob operation is queueing.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#share_identifierString

The share identifier for the service job. Don’t specify this parameter if the job queue doesn’t have a fair-share scheduling policy. If the job queue has a fair-share scheduling policy, then this parameter must be specified.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags that you apply to the service job request. Each tag consists of a key and an optional value. For more information, see [Tagging your Batch resources].

[1]: docs.aws.amazon.com/batch/latest/userguide/using-tags.html

Returns:

  • (Hash<String,String>)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_configTypes::ServiceJobTimeout

The timeout configuration for the service job. If none is specified, Batch defers to the default timeout of the underlying service handling the job.



9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
# File 'lib/aws-sdk-batch/types.rb', line 9928

class SubmitServiceJobRequest < Struct.new(
  :job_name,
  :job_queue,
  :retry_strategy,
  :scheduling_priority,
  :service_request_payload,
  :service_job_type,
  :share_identifier,
  :quota_share_name,
  :preemption_configuration,
  :timeout_config,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end