Class: Aws::Batch::Types::TerminateJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::TerminateJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Contains the parameters for TerminateJob.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The Batch job ID of the job to terminate.
-
#reason ⇒ String
A message to attach to the job that explains the reason for canceling it.
Instance Attribute Details
#job_id ⇒ String
The Batch job ID of the job to terminate.
11365 11366 11367 11368 11369 11370 |
# File 'lib/aws-sdk-batch/types.rb', line 11365 class TerminateJobRequest < Struct.new( :job_id, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A message to attach to the job that explains the reason for canceling it. This message is returned by future DescribeJobs operations on the job. It is also recorded in the Batch activity logs.
This parameter has as limit of 1024 characters.
11365 11366 11367 11368 11369 11370 |
# File 'lib/aws-sdk-batch/types.rb', line 11365 class TerminateJobRequest < Struct.new( :job_id, :reason) SENSITIVE = [] include Aws::Structure end |