Class: Aws::Batch::Types::TerminateJobsErrorDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::TerminateJobsErrorDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
An object that contains the details of a job that couldn't be
terminated by a TerminateJobs operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
An error code that identifies the reason the job couldn't be terminated.
-
#job ⇒ String
The Batch job ID of the job that couldn't be terminated.
-
#message ⇒ String
A message that describes the reason the job couldn't be terminated.
Instance Attribute Details
#code ⇒ String
An error code that identifies the reason the job couldn't be terminated. Valid values are:
-
ValidationException– A job identifier in the request is malformed or isn't valid. -
ClientException– The request failed because of a client error. -
ThrottlingException– The request was throttled. Retry the request. -
ServerException– An internal error occurred. Retry the request. -
AccessDenied– The caller isn't authorized to perform the action on the specified job.
11511 11512 11513 11514 11515 11516 11517 |
# File 'lib/aws-sdk-batch/types.rb', line 11511 class TerminateJobsErrorDetail < Struct.new( :job, :code, :message) SENSITIVE = [] include Aws::Structure end |
#job ⇒ String
The Batch job ID of the job that couldn't be terminated.
11511 11512 11513 11514 11515 11516 11517 |
# File 'lib/aws-sdk-batch/types.rb', line 11511 class TerminateJobsErrorDetail < Struct.new( :job, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message that describes the reason the job couldn't be terminated.
11511 11512 11513 11514 11515 11516 11517 |
# File 'lib/aws-sdk-batch/types.rb', line 11511 class TerminateJobsErrorDetail < Struct.new( :job, :code, :message) SENSITIVE = [] include Aws::Structure end |