Class: Aws::Batch::Types::TerminateJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::TerminateJobsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Specifies the jobs to terminate and the reason for the termination.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#jobs ⇒ Array<String>
An array of up to 50 Batch job IDs of the jobs to terminate.
-
#reason ⇒ String
A message to attach to the job that explains the reason for terminating it.
Instance Attribute Details
#jobs ⇒ Array<String>
An array of up to 50 Batch job IDs of the jobs to terminate.
11536 11537 11538 11539 11540 11541 |
# File 'lib/aws-sdk-batch/types.rb', line 11536 class TerminateJobsRequest < Struct.new( :jobs, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A message to attach to the job that explains the reason for terminating it. This message is returned by future DescribeJobs operations on the job. It is also recorded in the Batch activity logs.
This parameter has a limit of 1024 characters.
11536 11537 11538 11539 11540 11541 |
# File 'lib/aws-sdk-batch/types.rb', line 11536 class TerminateJobsRequest < Struct.new( :jobs, :reason) SENSITIVE = [] include Aws::Structure end |