Class: Aws::Batch::Types::TerminateServiceJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::TerminateServiceJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The service job ID of the service job to terminate.
-
#reason ⇒ String
A message to attach to the service job that explains the reason for canceling it.
Instance Attribute Details
#job_id ⇒ String
The service job ID of the service job to terminate.
11388 11389 11390 11391 11392 11393 |
# File 'lib/aws-sdk-batch/types.rb', line 11388 class TerminateServiceJobRequest < Struct.new( :job_id, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A message to attach to the service job that explains the reason for
canceling it. This message is returned by DescribeServiceJob
operations on the service job.
11388 11389 11390 11391 11392 11393 |
# File 'lib/aws-sdk-batch/types.rb', line 11388 class TerminateServiceJobRequest < Struct.new( :job_id, :reason) SENSITIVE = [] include Aws::Structure end |