Class: Aws::Batch::Types::TerminateServiceJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::TerminateServiceJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The service job ID of the service job to terminate.
-
#reason ⇒ String
A message to attach to the service job that explains the reason for canceling it.
Instance Attribute Details
#job_id ⇒ String
The service job ID of the service job to terminate.
10997 10998 10999 11000 11001 11002 |
# File 'lib/aws-sdk-batch/types.rb', line 10997 class TerminateServiceJobRequest < Struct.new( :job_id, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A message to attach to the service job that explains the reason for
canceling it. This message is returned by DescribeServiceJob
operations on the service job.
10997 10998 10999 11000 11001 11002 |
# File 'lib/aws-sdk-batch/types.rb', line 10997 class TerminateServiceJobRequest < Struct.new( :job_id, :reason) SENSITIVE = [] include Aws::Structure end |