Class: Aws::Batch::Types::UpdateManagedInstancesProviderConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::UpdateManagedInstancesProviderConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
The configuration for updating an Amazon ECS Managed Instances
capacity provider. Used in UpdateComputeEnvironment requests. The
capacityOptionType and fipsEnabled fields cannot be changed on
update.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#infrastructure_optimization ⇒ Types::InfrastructureOptimization
The updated infrastructure optimization configuration.
-
#infrastructure_role_arn ⇒ String
The updated Amazon Resource Name (ARN) of the IAM role that Amazon ECS assumes to manage Amazon EC2 instances on your behalf.
-
#instance_launch_template ⇒ Types::InstanceLaunchTemplateUpdate
The updated instance launch configuration for the Amazon ECS Managed Instances capacity provider.
-
#propagate_tags ⇒ String
Specifies whether tags on the capacity provider are propagated to the Amazon EC2 instances it launches.
Instance Attribute Details
#infrastructure_optimization ⇒ Types::InfrastructureOptimization
The updated infrastructure optimization configuration.
11849 11850 11851 11852 11853 11854 11855 11856 |
# File 'lib/aws-sdk-batch/types.rb', line 11849 class UpdateManagedInstancesProviderConfiguration < Struct.new( :propagate_tags, :infrastructure_role_arn, :instance_launch_template, :infrastructure_optimization) SENSITIVE = [] include Aws::Structure end |
#infrastructure_role_arn ⇒ String
The updated Amazon Resource Name (ARN) of the IAM role that Amazon ECS assumes to manage Amazon EC2 instances on your behalf.
11849 11850 11851 11852 11853 11854 11855 11856 |
# File 'lib/aws-sdk-batch/types.rb', line 11849 class UpdateManagedInstancesProviderConfiguration < Struct.new( :propagate_tags, :infrastructure_role_arn, :instance_launch_template, :infrastructure_optimization) SENSITIVE = [] include Aws::Structure end |
#instance_launch_template ⇒ Types::InstanceLaunchTemplateUpdate
The updated instance launch configuration for the Amazon ECS Managed Instances capacity provider.
11849 11850 11851 11852 11853 11854 11855 11856 |
# File 'lib/aws-sdk-batch/types.rb', line 11849 class UpdateManagedInstancesProviderConfiguration < Struct.new( :propagate_tags, :infrastructure_role_arn, :instance_launch_template, :infrastructure_optimization) SENSITIVE = [] include Aws::Structure end |
#propagate_tags ⇒ String
Specifies whether tags on the capacity provider are propagated to the Amazon EC2 instances it launches. Valid values:
-
CAPACITY_PROVIDER— Propagates tags to instances. -
NONE— Does not propagate tags to instances.
11849 11850 11851 11852 11853 11854 11855 11856 |
# File 'lib/aws-sdk-batch/types.rb', line 11849 class UpdateManagedInstancesProviderConfiguration < Struct.new( :propagate_tags, :infrastructure_role_arn, :instance_launch_template, :infrastructure_optimization) SENSITIVE = [] include Aws::Structure end |