Class: Aws::Batch::Types::UpdatePolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::UpdatePolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Specifies the infrastructure update policy for the Amazon EC2 compute environment. For more information about infrastructure updates, see Updating compute environments in the Batch User Guide.
The updatePolicy property applies only to Amazon EC2 managed compute
environments. Batch doesn't support updatePolicy for Fargate
compute environments. If you specify it for a Fargate compute
environment, Batch ignores it.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_execution_timeout_minutes ⇒ Integer
Specifies the job timeout (in minutes) when the compute environment infrastructure is updated.
-
#terminate_jobs_on_update ⇒ Boolean
Specifies whether jobs are automatically terminated when the compute environment infrastructure is updated.
Instance Attribute Details
#job_execution_timeout_minutes ⇒ Integer
Specifies the job timeout (in minutes) when the compute environment infrastructure is updated. The default value is 30. The maximum value is 7200.
jobExecutionTimeoutMinutes during infrastructure
updates delays the replacement of instances with new instances that
include updates such as security patches, but provides more time for
jobs to execute. Consider the security implications of this tradeoff
when setting timeout values.
11892 11893 11894 11895 11896 11897 |
# File 'lib/aws-sdk-batch/types.rb', line 11892 class UpdatePolicy < Struct.new( :terminate_jobs_on_update, :job_execution_timeout_minutes) SENSITIVE = [] include Aws::Structure end |
#terminate_jobs_on_update ⇒ Boolean
Specifies whether jobs are automatically terminated when the compute
environment infrastructure is updated. The default value is false.
11892 11893 11894 11895 11896 11897 |
# File 'lib/aws-sdk-batch/types.rb', line 11892 class UpdatePolicy < Struct.new( :terminate_jobs_on_update, :job_execution_timeout_minutes) SENSITIVE = [] include Aws::Structure end |