Class: Aws::Batch::Types::UpdateServiceJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Batch::Types::UpdateServiceJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-batch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The Batch job ID of the job to update.
-
#scheduling_priority ⇒ Integer
The scheduling priority for the job.
Instance Attribute Details
#job_id ⇒ String
The Batch job ID of the job to update.
11357 11358 11359 11360 11361 11362 |
# File 'lib/aws-sdk-batch/types.rb', line 11357 class UpdateServiceJobRequest < Struct.new( :job_id, :scheduling_priority) SENSITIVE = [] include Aws::Structure end |
#scheduling_priority ⇒ Integer
The scheduling priority for the job. This only affects jobs in job queues with a quota-share or fair-share scheduling policy. Jobs with a higher scheduling priority are scheduled before jobs with a lower scheduling priority within a share.
The minimum supported value is 0 and the maximum supported value is 9999.
11357 11358 11359 11360 11361 11362 |
# File 'lib/aws-sdk-batch/types.rb', line 11357 class UpdateServiceJobRequest < Struct.new( :job_id, :scheduling_priority) SENSITIVE = [] include Aws::Structure end |