Class: Aws::Batch::Types::Volume

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-batch/types.rb

Overview

A data volume that's used in a job's container properties.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#efs_volume_configurationTypes::EFSVolumeConfiguration

This parameter is specified when you're using an Amazon Elastic File System file system for job storage. Jobs that are running on Fargate resources must specify a platformVersion of at least 1.4.0.



12108
12109
12110
12111
12112
12113
12114
12115
# File 'lib/aws-sdk-batch/types.rb', line 12108

class Volume < Struct.new(
  :host,
  :name,
  :efs_volume_configuration,
  :s3files_volume_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#hostTypes::Host

The contents of the host parameter determine whether your data volume persists on the host container instance and where it's stored. If the host parameter is empty, then the Docker daemon assigns a host path for your data volume. However, the data isn't guaranteed to persist after the containers that are associated with it stop running.

This parameter isn't applicable to jobs that are running on Fargate resources and shouldn't be provided.

Returns:



12108
12109
12110
12111
12112
12113
12114
12115
# File 'lib/aws-sdk-batch/types.rb', line 12108

class Volume < Struct.new(
  :host,
  :name,
  :efs_volume_configuration,
  :s3files_volume_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the volume. It can be up to 255 characters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), and underscores (_). This name is referenced in the sourceVolume parameter of container definition mountPoints.

Returns:

  • (String)


12108
12109
12110
12111
12112
12113
12114
12115
# File 'lib/aws-sdk-batch/types.rb', line 12108

class Volume < Struct.new(
  :host,
  :name,
  :efs_volume_configuration,
  :s3files_volume_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#s3files_volume_configurationTypes::S3FilesVolumeConfiguration

This parameter is specified when you're using an S3Files file system for job storage.



12108
12109
12110
12111
12112
12113
12114
12115
# File 'lib/aws-sdk-batch/types.rb', line 12108

class Volume < Struct.new(
  :host,
  :name,
  :efs_volume_configuration,
  :s3files_volume_configuration)
  SENSITIVE = []
  include Aws::Structure
end